/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.Imap.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SETTINGSADAPTOR_H
#define SETTINGSADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "settings.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Akonadi.Imap.Settings
 */
class SettingsAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Akonadi.Imap.Settings")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Akonadi.Imap.Settings\">\n"
"    <method name=\"save\"/>\n"
"    <method name=\"name\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setName\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"imapServer\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setImapServer\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"imapPort\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setImapPort\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"userName\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setUserName\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"safety\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setSafety\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"overrideEncryption\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setOverrideEncryption\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"authentication\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setAuthentication\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"subscriptionEnabled\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setSubscriptionEnabled\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"sessionTimeout\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setSessionTimeout\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"useProxy\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setUseProxy\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"disconnectedModeEnabled\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setDisconnectedModeEnabled\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"intervalCheckEnabled\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setIntervalCheckEnabled\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"intervalCheckTime\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setIntervalCheckTime\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"retrieveMetadataOnFolderListing\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setRetrieveMetadataOnFolderListing\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"automaticExpungeEnabled\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setAutomaticExpungeEnabled\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"trashCollection\">\n"
"      <arg direction=\"out\" type=\"x\"/>\n"
"    </method>\n"
"    <method name=\"setTrashCollection\">\n"
"      <arg direction=\"in\" type=\"x\"/>\n"
"    </method>\n"
"    <method name=\"trashCollectionMigrated\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setTrashCollectionMigrated\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"useDefaultIdentity\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setUseDefaultIdentity\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"accountIdentity\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setAccountIdentity\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"knownMailBoxes\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"setKnownMailBoxes\">\n"
"      <arg direction=\"in\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"idleRidPath\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"setIdleRidPath\">\n"
"      <arg direction=\"in\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"sieveSupport\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setSieveSupport\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"sieveReuseConfig\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setSieveReuseConfig\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"sievePort\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setSievePort\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"sieveAlternateUrl\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setSieveAlternateUrl\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"alternateAuthentication\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setAlternateAuthentication\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"sieveVacationFilename\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setSieveVacationFilename\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"sieveCustomUsername\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setSieveCustomUsername\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"sieveCustomAuthentification\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setSieveCustomAuthentification\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"activitiesEnabled\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setActivitiesEnabled\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"activities\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"setActivities\">\n"
"      <arg direction=\"in\" type=\"as\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    SettingsAdaptor(Settings *parent);
    ~SettingsAdaptor() override;

    inline Settings *parent() const
    { return static_cast<Settings *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    int accountIdentity();
    QStringList activities();
    bool activitiesEnabled();
    int alternateAuthentication();
    int authentication();
    bool automaticExpungeEnabled();
    bool disconnectedModeEnabled();
    QStringList idleRidPath();
    int imapPort();
    QString imapServer();
    bool intervalCheckEnabled();
    int intervalCheckTime();
    QStringList knownMailBoxes();
    QString name();
    QString overrideEncryption();
    bool retrieveMetadataOnFolderListing();
    QString safety();
    void save();
    int sessionTimeout();
    void setAccountIdentity(int in0);
    void setActivities(const QStringList &in0);
    void setActivitiesEnabled(bool in0);
    void setAlternateAuthentication(int in0);
    void setAuthentication(int in0);
    void setAutomaticExpungeEnabled(bool in0);
    void setDisconnectedModeEnabled(bool in0);
    void setIdleRidPath(const QStringList &in0);
    void setImapPort(int in0);
    void setImapServer(const QString &in0);
    void setIntervalCheckEnabled(bool in0);
    void setIntervalCheckTime(int in0);
    void setKnownMailBoxes(const QStringList &in0);
    void setName(const QString &in0);
    void setOverrideEncryption(const QString &in0);
    void setRetrieveMetadataOnFolderListing(bool in0);
    void setSafety(const QString &in0);
    void setSessionTimeout(int in0);
    void setSieveAlternateUrl(const QString &in0);
    void setSieveCustomAuthentification(const QString &in0);
    void setSieveCustomUsername(const QString &in0);
    void setSievePort(int in0);
    void setSieveReuseConfig(bool in0);
    void setSieveSupport(bool in0);
    void setSieveVacationFilename(const QString &in0);
    void setSubscriptionEnabled(bool in0);
    void setTrashCollection(qlonglong in0);
    void setTrashCollectionMigrated(bool in0);
    void setUseDefaultIdentity(bool in0);
    void setUseProxy(bool in0);
    void setUserName(const QString &in0);
    QString sieveAlternateUrl();
    QString sieveCustomAuthentification();
    QString sieveCustomUsername();
    int sievePort();
    bool sieveReuseConfig();
    bool sieveSupport();
    QString sieveVacationFilename();
    bool subscriptionEnabled();
    qlonglong trashCollection();
    bool trashCollectionMigrated();
    bool useDefaultIdentity();
    bool useProxy();
    QString userName();
Q_SIGNALS: // SIGNALS
};

#endif
