/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.EwsMta.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "ewsmtasettingsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class SettingsAdaptor
 */

SettingsAdaptor::SettingsAdaptor(EwsMtaSettings *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

SettingsAdaptor::~SettingsAdaptor()
{
    // destructor
}

QString SettingsAdaptor::ewsResource()
{
    // handle method call org.kde.Akonadi.EwsMta.Settings.ewsResource
    return parent()->ewsResource();
}

void SettingsAdaptor::save()
{
    // handle method call org.kde.Akonadi.EwsMta.Settings.save
    parent()->save();
}

void SettingsAdaptor::setEwsResource(const QString &in0)
{
    // handle method call org.kde.Akonadi.EwsMta.Settings.setEwsResource
    parent()->setEwsResource(in0);
}


#include "moc_ewsmtasettingsadaptor.cpp"
