/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.Ews.Resource.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef EWSRESOURCEADAPTOR_H
#define EWSRESOURCEADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "ewsresource.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Akonadi.Ews.Resource
 */
class EwsResourceAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Akonadi.Ews.Resource")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Akonadi.Ews.Resource\">\n"
"    <signal name=\"messageSent\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"id\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"error\"/>\n"
"    </signal>\n"
"    <method name=\"clearCollectionSyncState\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"collectionId\"/>\n"
"    </method>\n"
"    <method name=\"clearFolderTreeSyncState\"/>\n"
"    <method name=\"setInitialReconnectTimeout\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"timeout\"/>\n"
"    </method>\n"
"    <method name=\"sendMessage\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"id\"/>\n"
"      <arg direction=\"in\" type=\"ay\" name=\"content\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    EwsResourceAdaptor(EwsResource *parent);
    ~EwsResourceAdaptor() override;

    inline EwsResource *parent() const
    { return static_cast<EwsResource *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void clearCollectionSyncState(int collectionId);
    void clearFolderTreeSyncState();
    void sendMessage(const QString &id, const QByteArray &content);
    void setInitialReconnectTimeout(int timeout);
Q_SIGNALS: // SIGNALS
    void messageSent(const QString &id, const QString &error);
};

#endif
