// This file is generated by kconfig_compiler_kf6 from davgroupwareresource.kcfg.
// All changes you do to this file will be lost.

#include "settingsbase.h"

#include <klocalizedstring.h>

SettingsBase::SettingsBase( KSharedConfig::Ptr config )
  : KConfigSkeleton( std::move( config ) )
{
  setCurrentGroup( QStringLiteral( "General" ) );

  mSettingsVersionItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "settingsVersion" ), mSettingsVersion, 1 );
  mSettingsVersionItem->setLabel( i18n("Settings Version") );
  addItem( mSettingsVersionItem, QStringLiteral( "settingsVersion" ) );
  mDisplayNameItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "displayName" ), mDisplayName );
  mDisplayNameItem->setLabel( i18n("Display name") );
  addItem( mDisplayNameItem, QStringLiteral( "displayName" ) );
  mRefreshIntervalItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "refreshInterval" ), mRefreshInterval, 5 );
  mRefreshIntervalItem->setLabel( i18n("Refresh every") );
  addItem( mRefreshIntervalItem, QStringLiteral( "refreshInterval" ) );
  mRemoteUrlsItem = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "remoteUrls" ), mRemoteUrls );
  mRemoteUrlsItem->setLabel( i18n("Remote URLs") );
  addItem( mRemoteUrlsItem, QStringLiteral( "remoteUrls" ) );
  mDefaultUsernameItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "defaultUsername" ), mDefaultUsername );
  mDefaultUsernameItem->setLabel( i18n("User name") );
  addItem( mDefaultUsernameItem, QStringLiteral( "defaultUsername" ) );
  mLimitSyncRangeItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "limitSyncRange" ), mLimitSyncRange, true );
  mLimitSyncRangeItem->setLabel( i18n("Limit the data retrieval to the specified time range") );
  addItem( mLimitSyncRangeItem, QStringLiteral( "limitSyncRange" ) );
  mSyncRangeStartNumberItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "syncRangeStartNumber" ), mSyncRangeStartNumber, QStringLiteral( "3" ) );
  mSyncRangeStartNumberItem->setLabel( i18n("Period for which to retrieve data, quantity") );
  addItem( mSyncRangeStartNumberItem, QStringLiteral( "syncRangeStartNumber" ) );
  mSyncRangeStartTypeItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "syncRangeStartType" ), mSyncRangeStartType, QStringLiteral( "M" ) );
  mSyncRangeStartTypeItem->setLabel( i18n("Period for which to retrieve data, type") );
  addItem( mSyncRangeStartTypeItem, QStringLiteral( "syncRangeStartType" ) );
  mCollectionsUrlsMappingsItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "collectionsUrlsMappings" ), mCollectionsUrlsMappings );
  mCollectionsUrlsMappingsItem->setLabel( i18n("String representation of the mappings between discovered collections and configured URLs") );
  addItem( mCollectionsUrlsMappingsItem, QStringLiteral( "collectionsUrlsMappings" ) );
  mReadOnlyItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "readOnly" ), mReadOnly, false );
  mReadOnlyItem->setLabel( i18n("Do not change the actual backend data.") );
  addItem( mReadOnlyItem, QStringLiteral( "readOnly" ) );
}

SettingsBase::~SettingsBase()
{
}

