/********************************************************************************
** Form generated from reading UI file 'configwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGWIDGET_H
#define UI_CONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kpasswordlineedit.h"

QT_BEGIN_NAMESPACE

class Ui_ConfigWidget
{
public:
    QFormLayout *formLayout;
    QLabel *label_6;
    QLineEdit *kcfg_displayName;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout;
    QSpinBox *kcfg_refreshInterval;
    QLabel *label_3;
    QSpacerItem *horizontalSpacer;
    QLabel *label;
    QHBoxLayout *horizontalLayout_2;
    QLineEdit *kcfg_defaultUsername;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout_4;
    KPasswordLineEdit *password;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *kcfg_limitSyncRange;
    QHBoxLayout *horizontalLayout_6;
    QLabel *label_5;
    QSpinBox *kcfg_syncRangeStartNumber;
    QComboBox *syncRangeStartType;
    QSpacerItem *horizontalSpacer_4;
    QLabel *label_41;
    QHBoxLayout *horizontalLayout_3;
    QTreeView *configuredUrls;
    QVBoxLayout *verticalLayout;
    QPushButton *addButton;
    QPushButton *searchButton;
    QPushButton *removeButton;
    QPushButton *editButton;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *ConfigWidget)
    {
        if (ConfigWidget->objectName().isEmpty())
            ConfigWidget->setObjectName("ConfigWidget");
        ConfigWidget->resize(534, 547);
        formLayout = new QFormLayout(ConfigWidget);
        formLayout->setObjectName("formLayout");
        formLayout->setContentsMargins(0, 0, 0, 0);
        label_6 = new QLabel(ConfigWidget);
        label_6->setObjectName("label_6");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_6);

        kcfg_displayName = new QLineEdit(ConfigWidget);
        kcfg_displayName->setObjectName("kcfg_displayName");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_displayName);

        label_2 = new QLabel(ConfigWidget);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_refreshInterval = new QSpinBox(ConfigWidget);
        kcfg_refreshInterval->setObjectName("kcfg_refreshInterval");
        kcfg_refreshInterval->setValue(5);

        horizontalLayout->addWidget(kcfg_refreshInterval);

        label_3 = new QLabel(ConfigWidget);
        label_3->setObjectName("label_3");

        horizontalLayout->addWidget(label_3);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        label = new QLabel(ConfigWidget);
        label->setObjectName("label");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        kcfg_defaultUsername = new QLineEdit(ConfigWidget);
        kcfg_defaultUsername->setObjectName("kcfg_defaultUsername");

        horizontalLayout_2->addWidget(kcfg_defaultUsername);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        horizontalLayout_2->setStretch(0, 2);
        horizontalLayout_2->setStretch(1, 1);

        formLayout->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        label_4 = new QLabel(ConfigWidget);
        label_4->setObjectName("label_4");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_4);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        password = new KPasswordLineEdit(ConfigWidget);
        password->setObjectName("password");

        horizontalLayout_4->addWidget(password);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_3);

        horizontalLayout_4->setStretch(0, 2);
        horizontalLayout_4->setStretch(1, 1);

        formLayout->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout_4);

        kcfg_limitSyncRange = new QCheckBox(ConfigWidget);
        kcfg_limitSyncRange->setObjectName("kcfg_limitSyncRange");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_limitSyncRange);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        label_5 = new QLabel(ConfigWidget);
        label_5->setObjectName("label_5");
        label_5->setEnabled(false);

        horizontalLayout_6->addWidget(label_5);

        kcfg_syncRangeStartNumber = new QSpinBox(ConfigWidget);
        kcfg_syncRangeStartNumber->setObjectName("kcfg_syncRangeStartNumber");
        kcfg_syncRangeStartNumber->setEnabled(false);
        kcfg_syncRangeStartNumber->setMinimum(1);

        horizontalLayout_6->addWidget(kcfg_syncRangeStartNumber);

        syncRangeStartType = new QComboBox(ConfigWidget);
        syncRangeStartType->setObjectName("syncRangeStartType");
        syncRangeStartType->setEnabled(false);

        horizontalLayout_6->addWidget(syncRangeStartType);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_4);


        formLayout->setLayout(5, QFormLayout::ItemRole::FieldRole, horizontalLayout_6);

        label_41 = new QLabel(ConfigWidget);
        label_41->setObjectName("label_41");

        formLayout->setWidget(6, QFormLayout::ItemRole::SpanningRole, label_41);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        configuredUrls = new QTreeView(ConfigWidget);
        configuredUrls->setObjectName("configuredUrls");

        horizontalLayout_3->addWidget(configuredUrls);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        addButton = new QPushButton(ConfigWidget);
        addButton->setObjectName("addButton");

        verticalLayout->addWidget(addButton);

        searchButton = new QPushButton(ConfigWidget);
        searchButton->setObjectName("searchButton");

        verticalLayout->addWidget(searchButton);

        removeButton = new QPushButton(ConfigWidget);
        removeButton->setObjectName("removeButton");

        verticalLayout->addWidget(removeButton);

        editButton = new QPushButton(ConfigWidget);
        editButton->setObjectName("editButton");

        verticalLayout->addWidget(editButton);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);


        horizontalLayout_3->addLayout(verticalLayout);


        formLayout->setLayout(7, QFormLayout::ItemRole::SpanningRole, horizontalLayout_3);


        retranslateUi(ConfigWidget);
        QObject::connect(kcfg_limitSyncRange, &QCheckBox::toggled, label_5, &QLabel::setEnabled);
        QObject::connect(kcfg_limitSyncRange, &QCheckBox::toggled, kcfg_syncRangeStartNumber, &QSpinBox::setEnabled);
        QObject::connect(kcfg_limitSyncRange, &QCheckBox::toggled, syncRangeStartType, &QComboBox::setEnabled);

        QMetaObject::connectSlotsByName(ConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *ConfigWidget)
    {
        label_6->setText(tr2i18n("Display name:", nullptr));
        label_2->setText(tr2i18n("Refresh every:", nullptr));
        kcfg_refreshInterval->setSpecialValueText(tr2i18n("Never", nullptr));
        label_3->setText(tr2i18n("minutes", nullptr));
        label->setText(tr2i18n("Username:", nullptr));
        label_4->setText(tr2i18n("Password:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_limitSyncRange->setToolTip(tr2i18n("Select this to reduce the load on the server and speed-up your syncs", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_limitSyncRange->setWhatsThis(tr2i18n("Limiting the time span range will lessen the load on the remote server and speed-up your initial sync.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_limitSyncRange->setText(tr2i18n("Limit retrieval time range", nullptr));
        label_5->setText(tr2i18n("Only sync data more recent than", nullptr));
        label_41->setText(tr2i18n("Server Configuration:", nullptr));
        addButton->setText(tr2i18n("Add", nullptr));
        searchButton->setText(tr2i18n("Search", nullptr));
        removeButton->setText(tr2i18n("Remove", nullptr));
        editButton->setText(tr2i18n("Edit", nullptr));
        (void)ConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class ConfigWidget: public Ui_ConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGWIDGET_H

