/********************************************************************************
** Form generated from reading UI file 'singlefileresourceconfigwidget_desktop.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SINGLEFILERESOURCECONFIGWIDGET_DESKTOP_H
#define UI_SINGLEFILERESOURCECONFIGWIDGET_DESKTOP_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_SingleFileResourceConfigWidget
{
public:
    QGridLayout *gridLayout_2;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *tabLayout;
    QFormLayout *formLayout;
    QLabel *filenameLabel;
    KUrlRequester *kcfg_Path;
    QLabel *pathLabel;
    QLabel *displayNameLabel;
    QLineEdit *kcfg_DisplayName;
    QCheckBox *kcfg_ReadOnly;
    QLabel *readOnlyLabel;
    QCheckBox *kcfg_MonitorFile;
    QLabel *monitoringLabel;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_PeriodicUpdate;
    QSpinBox *kcfg_UpdatePeriod;
    QSpacerItem *horizontalSpacer;
    QLabel *periodicUpdateLabel;
    KMessageWidget *statusLabel;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *SingleFileResourceConfigWidget)
    {
        if (SingleFileResourceConfigWidget->objectName().isEmpty())
            SingleFileResourceConfigWidget->setObjectName("SingleFileResourceConfigWidget");
        SingleFileResourceConfigWidget->resize(900, 700);
        SingleFileResourceConfigWidget->setMinimumSize(QSize(450, 350));
        gridLayout_2 = new QGridLayout(SingleFileResourceConfigWidget);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(SingleFileResourceConfigWidget);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        tabLayout = new QVBoxLayout(tab);
        tabLayout->setObjectName("tabLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        filenameLabel = new QLabel(tab);
        filenameLabel->setObjectName("filenameLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, filenameLabel);

        kcfg_Path = new KUrlRequester(tab);
        kcfg_Path->setObjectName("kcfg_Path");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_Path);

        pathLabel = new QLabel(tab);
        pathLabel->setObjectName("pathLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(pathLabel->sizePolicy().hasHeightForWidth());
        pathLabel->setSizePolicy(sizePolicy);
        pathLabel->setWordWrap(true);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, pathLabel);

        displayNameLabel = new QLabel(tab);
        displayNameLabel->setObjectName("displayNameLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, displayNameLabel);

        kcfg_DisplayName = new QLineEdit(tab);
        kcfg_DisplayName->setObjectName("kcfg_DisplayName");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_DisplayName);

        kcfg_ReadOnly = new QCheckBox(tab);
        kcfg_ReadOnly->setObjectName("kcfg_ReadOnly");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_ReadOnly);

        readOnlyLabel = new QLabel(tab);
        readOnlyLabel->setObjectName("readOnlyLabel");
        sizePolicy.setHeightForWidth(readOnlyLabel->sizePolicy().hasHeightForWidth());
        readOnlyLabel->setSizePolicy(sizePolicy);
        readOnlyLabel->setVisible(true);
        readOnlyLabel->setWordWrap(true);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, readOnlyLabel);

        kcfg_MonitorFile = new QCheckBox(tab);
        kcfg_MonitorFile->setObjectName("kcfg_MonitorFile");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, kcfg_MonitorFile);

        monitoringLabel = new QLabel(tab);
        monitoringLabel->setObjectName("monitoringLabel");
        sizePolicy.setHeightForWidth(monitoringLabel->sizePolicy().hasHeightForWidth());
        monitoringLabel->setSizePolicy(sizePolicy);
        monitoringLabel->setWordWrap(true);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, monitoringLabel);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_PeriodicUpdate = new QCheckBox(tab);
        kcfg_PeriodicUpdate->setObjectName("kcfg_PeriodicUpdate");

        horizontalLayout->addWidget(kcfg_PeriodicUpdate);

        kcfg_UpdatePeriod = new QSpinBox(tab);
        kcfg_UpdatePeriod->setObjectName("kcfg_UpdatePeriod");
        kcfg_UpdatePeriod->setEnabled(false);
        kcfg_UpdatePeriod->setMaximum(1440);
        kcfg_UpdatePeriod->setValue(60);

        horizontalLayout->addWidget(kcfg_UpdatePeriod);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        formLayout->setLayout(7, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        periodicUpdateLabel = new QLabel(tab);
        periodicUpdateLabel->setObjectName("periodicUpdateLabel");
        sizePolicy.setHeightForWidth(periodicUpdateLabel->sizePolicy().hasHeightForWidth());
        periodicUpdateLabel->setSizePolicy(sizePolicy);
        periodicUpdateLabel->setWordWrap(true);

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, periodicUpdateLabel);


        tabLayout->addLayout(formLayout);

        statusLabel = new KMessageWidget(tab);
        statusLabel->setObjectName("statusLabel");

        tabLayout->addWidget(statusLabel);

        verticalSpacer_2 = new QSpacerItem(20, 138, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        tabLayout->addItem(verticalSpacer_2);

        tabWidget->addTab(tab, QString());

        gridLayout_2->addWidget(tabWidget, 0, 0, 1, 1);

#if QT_CONFIG(shortcut)
        filenameLabel->setBuddy(kcfg_Path);
        pathLabel->setBuddy(kcfg_Path);
        displayNameLabel->setBuddy(kcfg_DisplayName);
        readOnlyLabel->setBuddy(kcfg_ReadOnly);
        monitoringLabel->setBuddy(kcfg_MonitorFile);
        periodicUpdateLabel->setBuddy(kcfg_PeriodicUpdate);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SingleFileResourceConfigWidget);
        QObject::connect(kcfg_PeriodicUpdate, &QCheckBox::toggled, kcfg_UpdatePeriod, &QSpinBox::setEnabled);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(SingleFileResourceConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *SingleFileResourceConfigWidget)
    {
        filenameLabel->setText(tr2i18n("File or URL:", nullptr));
        pathLabel->setText(tr2i18n("Select a local file or a remote URL to download a file from. A new local file will be created if it doesn't exist.", nullptr));
        displayNameLabel->setText(tr2i18n("Display Name:", nullptr));
        kcfg_ReadOnly->setText(tr2i18n("Read only", nullptr));
        readOnlyLabel->setText(tr2i18n("When read-only mode is enabled, no changes will be written. Read-only mode is automatically enabled when the selected file does not support write access or when displaying a calendar from remote URL.", nullptr));
        kcfg_MonitorFile->setText(tr2i18n("Monitor for &changes", nullptr));
        monitoringLabel->setText(tr2i18n("Changes made by other applications will reload the file when monitoring is enabled. Backups will be created to avoid conflicts when possible. Monitoring is not available for remote URLs.", nullptr));
        kcfg_PeriodicUpdate->setText(tr2i18n("Automatically &update every", nullptr));
        kcfg_UpdatePeriod->setSuffix(tr2i18n(" minutes", nullptr));
        periodicUpdateLabel->setText(tr2i18n("Periodically updates the file. Can be used when monitoring is not available (e.g. for remote calendars).", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("File", nullptr));
        (void)SingleFileResourceConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class SingleFileResourceConfigWidget: public Ui_SingleFileResourceConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SINGLEFILERESOURCECONFIGWIDGET_DESKTOP_H

