// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "mixedmaildirresource_debug.h"


Q_LOGGING_CATEGORY(MIXEDMAILDIRRESOURCE_LOG, "org.kde.pim.mixedmaildirresource", QtInfoMsg)

