/****************************************************************************
** Meta object code from reading C++ file 'settingsadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "settingsadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'settingsadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15SettingsAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto SettingsAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN15SettingsAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SettingsAdaptor",
        "D-Bus Interface",
        "org.kde.Akonadi.Mbox.Settings",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Akonadi.Mbox.Settings\">\n    <method "
        "name=\"save\"/>\n    <method name=\"path\">\n      <arg direction="
        "\"out\" type=\"s\"/>\n    </method>\n    <method name=\"setPath\">"
        "\n      <arg direction=\"in\" type=\"s\"/>\n    </method>\n    <me"
        "thod name=\"displayName\">\n      <arg direction=\"out\" type=\"s\""
        "/>\n    </method>\n    <method name=\"setDisplayName\">\n      <ar"
        "g direction=\"in\" type=\"s\"/>\n    </method>\n    <method name=\""
        "readOnly\">\n      <arg direction=\"out\" type=\"b\"/>\n    </meth"
        "od>\n    <method name=\"setReadOnly\">\n      <arg direction=\"in\""
        " type=\"b\"/>\n    </method>\n    <method name=\"monitorFile\">\n "
        "     <arg direction=\"out\" type=\"b\"/>\n    </method>\n    <meth"
        "od name=\"setMonitorFile\">\n      <arg direction=\"in\" type=\"b\""
        "/>\n    </method>\n    <method name=\"periodicUpdate\">\n      <ar"
        "g direction=\"out\" type=\"b\"/>\n    </method>\n    <method name="
        "\"setPeriodicUpdate\">\n      <arg direction=\"in\" type=\"b\"/>\n"
        "    </method>\n    <method name=\"updatePeriod\">\n      <arg dire"
        "ction=\"out\" type=\"i\"/>\n    </method>\n    <method name=\"setU"
        "pdatePeriod\">\n      <arg direction=\"in\" type=\"i\"/>\n    </me"
        "thod>\n    <method name=\"lockfileMethod\">\n      <arg direction="
        "\"out\" type=\"i\"/>\n    </method>\n    <method name=\"setLockfil"
        "eMethod\">\n      <arg direction=\"in\" type=\"i\"/>\n    </method"
        ">\n    <method name=\"lockfile\">\n      <arg direction=\"out\" ty"
        "pe=\"s\"/>\n    </method>\n    <method name=\"setLockfile\">\n    "
        "  <arg direction=\"in\" type=\"s\"/>\n    </method>\n    <method n"
        "ame=\"compactFrequency\">\n      <arg direction=\"out\" type=\"i\""
        "/>\n    </method>\n    <method name=\"setCompactFrequency\">\n    "
        "  <arg direction=\"in\" type=\"i\"/>\n    </method>\n    <method n"
        "ame=\"messageCount\">\n      <arg direction=\"out\" type=\"u\"/>\n"
        "    </method>\n    <method name=\"setMessageCount\">\n      <arg d"
        "irection=\"in\" type=\"u\"/>\n    </method>\n  </interface>\n",
        "compactFrequency",
        "",
        "displayName",
        "lockfile",
        "lockfileMethod",
        "messageCount",
        "monitorFile",
        "path",
        "periodicUpdate",
        "readOnly",
        "save",
        "setCompactFrequency",
        "in0",
        "setDisplayName",
        "setLockfile",
        "setLockfileMethod",
        "setMessageCount",
        "setMonitorFile",
        "setPath",
        "setPeriodicUpdate",
        "setReadOnly",
        "setUpdatePeriod",
        "updatePeriod"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'compactFrequency'
        QtMocHelpers::SlotData<int()>(5, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'displayName'
        QtMocHelpers::SlotData<QString()>(7, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'lockfile'
        QtMocHelpers::SlotData<QString()>(8, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'lockfileMethod'
        QtMocHelpers::SlotData<int()>(9, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'messageCount'
        QtMocHelpers::SlotData<uint()>(10, 6, QMC::AccessPublic, QMetaType::UInt),
        // Slot 'monitorFile'
        QtMocHelpers::SlotData<bool()>(11, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'path'
        QtMocHelpers::SlotData<QString()>(12, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'periodicUpdate'
        QtMocHelpers::SlotData<bool()>(13, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'readOnly'
        QtMocHelpers::SlotData<bool()>(14, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setCompactFrequency'
        QtMocHelpers::SlotData<void(int)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'setDisplayName'
        QtMocHelpers::SlotData<void(const QString &)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'setLockfile'
        QtMocHelpers::SlotData<void(const QString &)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'setLockfileMethod'
        QtMocHelpers::SlotData<void(int)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'setMessageCount'
        QtMocHelpers::SlotData<void(uint)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 17 },
        }}),
        // Slot 'setMonitorFile'
        QtMocHelpers::SlotData<void(bool)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'setPath'
        QtMocHelpers::SlotData<void(const QString &)>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'setPeriodicUpdate'
        QtMocHelpers::SlotData<void(bool)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'setReadOnly'
        QtMocHelpers::SlotData<void(bool)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'setUpdatePeriod'
        QtMocHelpers::SlotData<void(int)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'updatePeriod'
        QtMocHelpers::SlotData<int()>(27, 6, QMC::AccessPublic, QMetaType::Int),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<SettingsAdaptor, qt_meta_tag_ZN15SettingsAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SettingsAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.metaTypes,
    nullptr
} };

void SettingsAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SettingsAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { int _r = _t->compactFrequency();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->displayName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->lockfile();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { int _r = _t->lockfileMethod();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 4: { uint _r = _t->messageCount();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->monitorFile();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->path();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->periodicUpdate();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->readOnly();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->save(); break;
        case 10: _t->setCompactFrequency((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->setDisplayName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->setLockfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->setLockfileMethod((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->setMessageCount((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 15: _t->setMonitorFile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->setPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->setPeriodicUpdate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->setReadOnly((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->setUpdatePeriod((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: { int _r = _t->updatePeriod();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *SettingsAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SettingsAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int SettingsAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}
QT_WARNING_POP
