/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.OpenXchange.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "settingsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class SettingsAdaptor
 */

SettingsAdaptor::SettingsAdaptor(Settings *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

SettingsAdaptor::~SettingsAdaptor()
{
    // destructor
}

QString SettingsAdaptor::baseUrl()
{
    // handle method call org.kde.Akonadi.OpenXchange.Settings.baseUrl
    return parent()->baseUrl();
}

qulonglong SettingsAdaptor::foldersLastSync()
{
    // handle method call org.kde.Akonadi.OpenXchange.Settings.foldersLastSync
    return parent()->foldersLastSync();
}

QString SettingsAdaptor::objectsLastSync()
{
    // handle method call org.kde.Akonadi.OpenXchange.Settings.objectsLastSync
    return parent()->objectsLastSync();
}

QString SettingsAdaptor::password()
{
    // handle method call org.kde.Akonadi.OpenXchange.Settings.password
    return parent()->password();
}

void SettingsAdaptor::save()
{
    // handle method call org.kde.Akonadi.OpenXchange.Settings.save
    parent()->save();
}

void SettingsAdaptor::setBaseUrl(const QString &in0)
{
    // handle method call org.kde.Akonadi.OpenXchange.Settings.setBaseUrl
    parent()->setBaseUrl(in0);
}

void SettingsAdaptor::setFoldersLastSync(qulonglong in0)
{
    // handle method call org.kde.Akonadi.OpenXchange.Settings.setFoldersLastSync
    parent()->setFoldersLastSync(in0);
}

void SettingsAdaptor::setObjectsLastSync(const QString &in0)
{
    // handle method call org.kde.Akonadi.OpenXchange.Settings.setObjectsLastSync
    parent()->setObjectsLastSync(in0);
}

void SettingsAdaptor::setPassword(const QString &in0)
{
    // handle method call org.kde.Akonadi.OpenXchange.Settings.setPassword
    parent()->setPassword(in0);
}

void SettingsAdaptor::setUseIncrementalUpdates(bool in0)
{
    // handle method call org.kde.Akonadi.OpenXchange.Settings.setUseIncrementalUpdates
    parent()->setUseIncrementalUpdates(in0);
}

void SettingsAdaptor::setUsername(const QString &in0)
{
    // handle method call org.kde.Akonadi.OpenXchange.Settings.setUsername
    parent()->setUsername(in0);
}

bool SettingsAdaptor::useIncrementalUpdates()
{
    // handle method call org.kde.Akonadi.OpenXchange.Settings.useIncrementalUpdates
    return parent()->useIncrementalUpdates();
}

QString SettingsAdaptor::username()
{
    // handle method call org.kde.Akonadi.OpenXchange.Settings.username
    return parent()->username();
}


#include "moc_settingsadaptor.cpp"
