/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.Mbox.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "settingsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class SettingsAdaptor
 */

SettingsAdaptor::SettingsAdaptor(Settings *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

SettingsAdaptor::~SettingsAdaptor()
{
    // destructor
}

int SettingsAdaptor::compactFrequency()
{
    // handle method call org.kde.Akonadi.Mbox.Settings.compactFrequency
    return parent()->compactFrequency();
}

QString SettingsAdaptor::displayName()
{
    // handle method call org.kde.Akonadi.Mbox.Settings.displayName
    return parent()->displayName();
}

QString SettingsAdaptor::lockfile()
{
    // handle method call org.kde.Akonadi.Mbox.Settings.lockfile
    return parent()->lockfile();
}

int SettingsAdaptor::lockfileMethod()
{
    // handle method call org.kde.Akonadi.Mbox.Settings.lockfileMethod
    return parent()->lockfileMethod();
}

uint SettingsAdaptor::messageCount()
{
    // handle method call org.kde.Akonadi.Mbox.Settings.messageCount
    return parent()->messageCount();
}

bool SettingsAdaptor::monitorFile()
{
    // handle method call org.kde.Akonadi.Mbox.Settings.monitorFile
    return parent()->monitorFile();
}

QString SettingsAdaptor::path()
{
    // handle method call org.kde.Akonadi.Mbox.Settings.path
    return parent()->path();
}

bool SettingsAdaptor::periodicUpdate()
{
    // handle method call org.kde.Akonadi.Mbox.Settings.periodicUpdate
    return parent()->periodicUpdate();
}

bool SettingsAdaptor::readOnly()
{
    // handle method call org.kde.Akonadi.Mbox.Settings.readOnly
    return parent()->readOnly();
}

void SettingsAdaptor::save()
{
    // handle method call org.kde.Akonadi.Mbox.Settings.save
    parent()->save();
}

void SettingsAdaptor::setCompactFrequency(int in0)
{
    // handle method call org.kde.Akonadi.Mbox.Settings.setCompactFrequency
    parent()->setCompactFrequency(in0);
}

void SettingsAdaptor::setDisplayName(const QString &in0)
{
    // handle method call org.kde.Akonadi.Mbox.Settings.setDisplayName
    parent()->setDisplayName(in0);
}

void SettingsAdaptor::setLockfile(const QString &in0)
{
    // handle method call org.kde.Akonadi.Mbox.Settings.setLockfile
    parent()->setLockfile(in0);
}

void SettingsAdaptor::setLockfileMethod(int in0)
{
    // handle method call org.kde.Akonadi.Mbox.Settings.setLockfileMethod
    parent()->setLockfileMethod(in0);
}

void SettingsAdaptor::setMessageCount(uint in0)
{
    // handle method call org.kde.Akonadi.Mbox.Settings.setMessageCount
    parent()->setMessageCount(in0);
}

void SettingsAdaptor::setMonitorFile(bool in0)
{
    // handle method call org.kde.Akonadi.Mbox.Settings.setMonitorFile
    parent()->setMonitorFile(in0);
}

void SettingsAdaptor::setPath(const QString &in0)
{
    // handle method call org.kde.Akonadi.Mbox.Settings.setPath
    parent()->setPath(in0);
}

void SettingsAdaptor::setPeriodicUpdate(bool in0)
{
    // handle method call org.kde.Akonadi.Mbox.Settings.setPeriodicUpdate
    parent()->setPeriodicUpdate(in0);
}

void SettingsAdaptor::setReadOnly(bool in0)
{
    // handle method call org.kde.Akonadi.Mbox.Settings.setReadOnly
    parent()->setReadOnly(in0);
}

void SettingsAdaptor::setUpdatePeriod(int in0)
{
    // handle method call org.kde.Akonadi.Mbox.Settings.setUpdatePeriod
    parent()->setUpdatePeriod(in0);
}

int SettingsAdaptor::updatePeriod()
{
    // handle method call org.kde.Akonadi.Mbox.Settings.updatePeriod
    return parent()->updatePeriod();
}


#include "moc_settingsadaptor.cpp"
