/********************************************************************************
** Form generated from reading UI file 'searchdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHDIALOG_H
#define UI_SEARCHDIALOG_H

#include <QtCore/QLocale>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SearchDialog
{
public:
    QVBoxLayout *verticalLayout;
    QRadioButton *useDefaultCreds;
    QRadioButton *useSpecificCreds;
    QGroupBox *credentialsGroup;
    QFormLayout *formLayout_2;
    QLabel *label_4;
    QLineEdit *username;
    QLabel *label_5;
    QLineEdit *password;
    QFormLayout *formLayout;
    QLabel *label;
    QLineEdit *searchUrl;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout;
    QComboBox *searchType;
    QLineEdit *searchParam;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *searchButton;
    QSpacerItem *horizontalSpacer_2;
    QListView *searchResults;

    void setupUi(QWidget *SearchDialog)
    {
        if (SearchDialog->objectName().isEmpty())
            SearchDialog->setObjectName("SearchDialog");
        SearchDialog->resize(557, 670);
        SearchDialog->setLocale(QLocale(QLocale::English, QLocale::UnitedStates));
        verticalLayout = new QVBoxLayout(SearchDialog);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        useDefaultCreds = new QRadioButton(SearchDialog);
        useDefaultCreds->setObjectName("useDefaultCreds");
        useDefaultCreds->setChecked(true);

        verticalLayout->addWidget(useDefaultCreds);

        useSpecificCreds = new QRadioButton(SearchDialog);
        useSpecificCreds->setObjectName("useSpecificCreds");

        verticalLayout->addWidget(useSpecificCreds);

        credentialsGroup = new QGroupBox(SearchDialog);
        credentialsGroup->setObjectName("credentialsGroup");
        formLayout_2 = new QFormLayout(credentialsGroup);
        formLayout_2->setObjectName("formLayout_2");
        label_4 = new QLabel(credentialsGroup);
        label_4->setObjectName("label_4");
        label_4->setLocale(QLocale(QLocale::English, QLocale::UnitedStates));

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_4);

        username = new QLineEdit(credentialsGroup);
        username->setObjectName("username");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, username);

        label_5 = new QLabel(credentialsGroup);
        label_5->setObjectName("label_5");
        label_5->setLocale(QLocale(QLocale::English, QLocale::UnitedStates));

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_5);

        password = new QLineEdit(credentialsGroup);
        password->setObjectName("password");
        password->setEchoMode(QLineEdit::Password);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, password);


        verticalLayout->addWidget(credentialsGroup);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label = new QLabel(SearchDialog);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        searchUrl = new QLineEdit(SearchDialog);
        searchUrl->setObjectName("searchUrl");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, searchUrl);

        label_2 = new QLabel(SearchDialog);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        searchType = new QComboBox(SearchDialog);
        searchType->addItem(QString());
        searchType->addItem(QString());
        searchType->setObjectName("searchType");

        horizontalLayout->addWidget(searchType);

        searchParam = new QLineEdit(SearchDialog);
        searchParam->setObjectName("searchParam");

        horizontalLayout->addWidget(searchParam);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout);


        verticalLayout->addLayout(formLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        searchButton = new QPushButton(SearchDialog);
        searchButton->setObjectName("searchButton");

        horizontalLayout_2->addWidget(searchButton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout_2);

        searchResults = new QListView(SearchDialog);
        searchResults->setObjectName("searchResults");
        searchResults->setEditTriggers(QAbstractItemView::NoEditTriggers);
        searchResults->setSelectionMode(QAbstractItemView::ExtendedSelection);
        searchResults->setIconSize(QSize(24, 24));
        searchResults->setSpacing(2);

        verticalLayout->addWidget(searchResults);


        retranslateUi(SearchDialog);
        QObject::connect(searchParam, &QLineEdit::returnPressed, searchButton, qOverload<>(&QPushButton::animateClick));
        QObject::connect(useSpecificCreds, &QRadioButton::toggled, credentialsGroup, &QGroupBox::setVisible);

        QMetaObject::connectSlotsByName(SearchDialog);
    } // setupUi

    void retranslateUi(QWidget *SearchDialog)
    {
        useDefaultCreds->setText(tr2i18n("Use global creden&tials", nullptr));
        useSpecificCreds->setText(tr2i18n("Use specific credentials", nullptr));
        credentialsGroup->setTitle(tr2i18n("Credentials", nullptr));
#if QT_CONFIG(tooltip)
        label_4->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Username", nullptr));
#if QT_CONFIG(tooltip)
        label_5->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        label_5->setText(tr2i18n("Password", nullptr));
        label->setText(tr2i18n("Search URL", nullptr));
        label_2->setText(tr2i18n("Search for", nullptr));
        searchType->setItemText(0, tr2i18n("a person named", nullptr));
        searchType->setItemText(1, tr2i18n("a contact with email", nullptr));

        searchButton->setText(tr2i18n("Search", nullptr));
        (void)SearchDialog;
    } // retranslateUi

};

namespace Ui {
    class SearchDialog: public Ui_SearchDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SEARCHDIALOG_H

