/********************************************************************************
** Form generated from reading UI file 'ewsmtaconfigdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EWSMTACONFIGDIALOG_H
#define UI_EWSMTACONFIGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "Akonadi/AgentInstanceWidget"

QT_BEGIN_NAMESPACE

class Ui_SetupServerView
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *accountLabel;
    QLineEdit *accountName;
    QLabel *recourceLabel;
    Akonadi::AgentInstanceWidget *resourceWidget;

    void setupUi(QWidget *SetupServerView)
    {
        if (SetupServerView->objectName().isEmpty())
            SetupServerView->setObjectName("SetupServerView");
        SetupServerView->resize(553, 421);
        verticalLayout = new QVBoxLayout(SetupServerView);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        accountLabel = new QLabel(SetupServerView);
        accountLabel->setObjectName("accountLabel");

        verticalLayout->addWidget(accountLabel);

        accountName = new QLineEdit(SetupServerView);
        accountName->setObjectName("accountName");

        verticalLayout->addWidget(accountName);

        recourceLabel = new QLabel(SetupServerView);
        recourceLabel->setObjectName("recourceLabel");

        verticalLayout->addWidget(recourceLabel);

        resourceWidget = new Akonadi::AgentInstanceWidget(SetupServerView);
        resourceWidget->setObjectName("resourceWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(resourceWidget->sizePolicy().hasHeightForWidth());
        resourceWidget->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(resourceWidget);


        retranslateUi(SetupServerView);

        QMetaObject::connectSlotsByName(SetupServerView);
    } // setupUi

    void retranslateUi(QWidget *SetupServerView)
    {
        SetupServerView->setWindowTitle(tr2i18n("EWS Mail Transport Configuration", nullptr));
        accountLabel->setText(tr2i18n("Account Name:", nullptr));
        recourceLabel->setText(tr2i18n("Parent Exchange account:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SetupServerView: public Ui_SetupServerView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EWSMTACONFIGDIALOG_H

