/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.davGroupware.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "settingsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class SettingsAdaptor
 */

SettingsAdaptor::SettingsAdaptor(Settings *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

SettingsAdaptor::~SettingsAdaptor()
{
    // destructor
}

QString SettingsAdaptor::collectionsUrlsMappings()
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.collectionsUrlsMappings
    return parent()->collectionsUrlsMappings();
}

QString SettingsAdaptor::defaultUsername()
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.defaultUsername
    return parent()->defaultUsername();
}

QString SettingsAdaptor::displayName()
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.displayName
    return parent()->displayName();
}

bool SettingsAdaptor::limitSyncRange()
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.limitSyncRange
    return parent()->limitSyncRange();
}

bool SettingsAdaptor::readOnly()
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.readOnly
    return parent()->readOnly();
}

int SettingsAdaptor::refreshInterval()
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.refreshInterval
    return parent()->refreshInterval();
}

QStringList SettingsAdaptor::remoteUrls()
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.remoteUrls
    return parent()->remoteUrls();
}

void SettingsAdaptor::save()
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.save
    parent()->save();
}

void SettingsAdaptor::setCollectionsUrlsMappings(const QString &in0)
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.setCollectionsUrlsMappings
    parent()->setCollectionsUrlsMappings(in0);
}

void SettingsAdaptor::setDefaultUsername(const QString &in0)
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.setDefaultUsername
    parent()->setDefaultUsername(in0);
}

void SettingsAdaptor::setDisplayName(const QString &in0)
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.setDisplayName
    parent()->setDisplayName(in0);
}

void SettingsAdaptor::setLimitSyncRange(bool in0)
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.setLimitSyncRange
    parent()->setLimitSyncRange(in0);
}

void SettingsAdaptor::setReadOnly(bool in0)
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.setReadOnly
    parent()->setReadOnly(in0);
}

void SettingsAdaptor::setRefreshInterval(int in0)
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.setRefreshInterval
    parent()->setRefreshInterval(in0);
}

void SettingsAdaptor::setRemoteUrls(const QStringList &in0)
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.setRemoteUrls
    parent()->setRemoteUrls(in0);
}

void SettingsAdaptor::setSettingsVersion(int in0)
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.setSettingsVersion
    parent()->setSettingsVersion(in0);
}

void SettingsAdaptor::setSyncRangeStartNumber(const QString &in0)
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.setSyncRangeStartNumber
    parent()->setSyncRangeStartNumber(in0);
}

void SettingsAdaptor::setSyncRangeStartType(const QString &in0)
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.setSyncRangeStartType
    parent()->setSyncRangeStartType(in0);
}

int SettingsAdaptor::settingsVersion()
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.settingsVersion
    return parent()->settingsVersion();
}

QString SettingsAdaptor::syncRangeStartNumber()
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.syncRangeStartNumber
    return parent()->syncRangeStartNumber();
}

QString SettingsAdaptor::syncRangeStartType()
{
    // handle method call org.kde.Akonadi.davGroupware.Settings.syncRangeStartType
    return parent()->syncRangeStartType();
}


#include "moc_settingsadaptor.cpp"
