/********************************************************************************
** Form generated from reading UI file 'popsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_POPSETTINGS_H
#define UI_POPSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "Akonadi/CollectionRequester"
#include "kpasswordlineedit.h"
#include "kseparator.h"
#include "ktitlewidget.h"

QT_BEGIN_NAMESPACE

class Ui_PopPage
{
public:
    QGridLayout *gridLayout_2;
    QLabel *titleLabel;
    KSeparator *kseparator;
    QTabWidget *tabWidget;
    QWidget *page1;
    QFormLayout *formLayout_3;
    KTitleWidget *ktitlewidget_4;
    QLabel *label_2;
    QLineEdit *nameEdit;
    QLabel *label_5;
    QLineEdit *hostEdit;
    QLabel *label_3;
    QLineEdit *loginEdit;
    QLabel *passwordLabel;
    KPasswordLineEdit *passwordEdit;
    KTitleWidget *ktitlewidget_5;
    QCheckBox *intervalCheck;
    QLabel *intervalLabel;
    QSpinBox *intervalSpin;
    KTitleWidget *ktitlewidget_3;
    QSpacerItem *verticalSpacer;
    QWidget *page2;
    QFormLayout *formLayout_2;
    KTitleWidget *ktitlewidget;
    QSpacerItem *horizontalSpacer;
    QGridLayout *gridLayout_3;
    QCheckBox *leaveOnServerCheck;
    QCheckBox *leaveOnServerDaysCheck;
    QSpinBox *leaveOnServerDaysSpin;
    QCheckBox *leaveOnServerCountCheck;
    QSpinBox *leaveOnServerCountSpin;
    QCheckBox *leaveOnServerSizeCheck;
    QSpinBox *leaveOnServerSizeSpin;
    QCheckBox *usePipeliningCheck;
    QFormLayout *formLayout_4;
    QLabel *label_8;
    Akonadi::CollectionRequester *folderRequester;
    QLabel *preCommandLabel;
    QLineEdit *precommand;
    KTitleWidget *ktitlewidget_2;
    QStackedWidget *checkCapabilitiesStack;
    QWidget *page;
    QFormLayout *formLayout;
    QPushButton *checkCapabilities;
    QLabel *label_11;
    QHBoxLayout *horizontalLayout_2;
    QRadioButton *encryptionNone;
    QRadioButton *encryptionSSL;
    QRadioButton *encryptionTLS;
    QLabel *imapInfo;
    QLabel *label_13;
    QSpinBox *portEdit;
    QLabel *label_12;
    QComboBox *authCombo;
    QCheckBox *proxyCheck;
    QSpacerItem *verticalSpacer_2;
    QWidget *page_2;
    QVBoxLayout *verticalLayout_4;
    QProgressBar *checkCapabilitiesProgress;

    void setupUi(QWidget *PopPage)
    {
        if (PopPage->objectName().isEmpty())
            PopPage->setObjectName("PopPage");
        PopPage->resize(753, 725);
        gridLayout_2 = new QGridLayout(PopPage);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        titleLabel = new QLabel(PopPage);
        titleLabel->setObjectName("titleLabel");
        QFont font;
        font.setBold(true);
        titleLabel->setFont(font);

        gridLayout_2->addWidget(titleLabel, 0, 0, 1, 1);

        kseparator = new KSeparator(PopPage);
        kseparator->setObjectName("kseparator");

        gridLayout_2->addWidget(kseparator, 1, 0, 1, 1);

        tabWidget = new QTabWidget(PopPage);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setEnabled(true);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy);
        tabWidget->setMovable(false);
        page1 = new QWidget();
        page1->setObjectName("page1");
        formLayout_3 = new QFormLayout(page1);
        formLayout_3->setObjectName("formLayout_3");
        ktitlewidget_4 = new KTitleWidget(page1);
        ktitlewidget_4->setObjectName("ktitlewidget_4");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::SpanningRole, ktitlewidget_4);

        label_2 = new QLabel(page1);
        label_2->setObjectName("label_2");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        nameEdit = new QLineEdit(page1);
        nameEdit->setObjectName("nameEdit");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, nameEdit);

        label_5 = new QLabel(page1);
        label_5->setObjectName("label_5");

        formLayout_3->setWidget(2, QFormLayout::ItemRole::LabelRole, label_5);

        hostEdit = new QLineEdit(page1);
        hostEdit->setObjectName("hostEdit");

        formLayout_3->setWidget(2, QFormLayout::ItemRole::FieldRole, hostEdit);

        label_3 = new QLabel(page1);
        label_3->setObjectName("label_3");

        formLayout_3->setWidget(3, QFormLayout::ItemRole::LabelRole, label_3);

        loginEdit = new QLineEdit(page1);
        loginEdit->setObjectName("loginEdit");

        formLayout_3->setWidget(3, QFormLayout::ItemRole::FieldRole, loginEdit);

        passwordLabel = new QLabel(page1);
        passwordLabel->setObjectName("passwordLabel");

        formLayout_3->setWidget(4, QFormLayout::ItemRole::LabelRole, passwordLabel);

        passwordEdit = new KPasswordLineEdit(page1);
        passwordEdit->setObjectName("passwordEdit");

        formLayout_3->setWidget(4, QFormLayout::ItemRole::FieldRole, passwordEdit);

        ktitlewidget_5 = new KTitleWidget(page1);
        ktitlewidget_5->setObjectName("ktitlewidget_5");

        formLayout_3->setWidget(5, QFormLayout::ItemRole::SpanningRole, ktitlewidget_5);

        intervalCheck = new QCheckBox(page1);
        intervalCheck->setObjectName("intervalCheck");

        formLayout_3->setWidget(6, QFormLayout::ItemRole::FieldRole, intervalCheck);

        intervalLabel = new QLabel(page1);
        intervalLabel->setObjectName("intervalLabel");

        formLayout_3->setWidget(7, QFormLayout::ItemRole::LabelRole, intervalLabel);

        intervalSpin = new QSpinBox(page1);
        intervalSpin->setObjectName("intervalSpin");
        intervalSpin->setMinimum(1);
        intervalSpin->setMaximum(10000000);
        intervalSpin->setValue(5);

        formLayout_3->setWidget(7, QFormLayout::ItemRole::FieldRole, intervalSpin);

        ktitlewidget_3 = new KTitleWidget(page1);
        ktitlewidget_3->setObjectName("ktitlewidget_3");

        formLayout_3->setWidget(8, QFormLayout::ItemRole::SpanningRole, ktitlewidget_3);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout_3->setItem(9, QFormLayout::ItemRole::LabelRole, verticalSpacer);

        tabWidget->addTab(page1, QString());
        page2 = new QWidget();
        page2->setObjectName("page2");
        formLayout_2 = new QFormLayout(page2);
        formLayout_2->setObjectName("formLayout_2");
        ktitlewidget = new KTitleWidget(page2);
        ktitlewidget->setObjectName("ktitlewidget");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::SpanningRole, ktitlewidget);

        horizontalSpacer = new QSpacerItem(101, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        formLayout_2->setItem(1, QFormLayout::ItemRole::LabelRole, horizontalSpacer);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName("gridLayout_3");
        leaveOnServerCheck = new QCheckBox(page2);
        leaveOnServerCheck->setObjectName("leaveOnServerCheck");

        gridLayout_3->addWidget(leaveOnServerCheck, 0, 0, 1, 1);

        leaveOnServerDaysCheck = new QCheckBox(page2);
        leaveOnServerDaysCheck->setObjectName("leaveOnServerDaysCheck");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(leaveOnServerDaysCheck->sizePolicy().hasHeightForWidth());
        leaveOnServerDaysCheck->setSizePolicy(sizePolicy1);

        gridLayout_3->addWidget(leaveOnServerDaysCheck, 1, 0, 1, 1);

        leaveOnServerDaysSpin = new QSpinBox(page2);
        leaveOnServerDaysSpin->setObjectName("leaveOnServerDaysSpin");
        leaveOnServerDaysSpin->setEnabled(true);
        leaveOnServerDaysSpin->setMinimum(0);
        leaveOnServerDaysSpin->setMaximum(365);
        leaveOnServerDaysSpin->setValue(1);

        gridLayout_3->addWidget(leaveOnServerDaysSpin, 1, 1, 1, 1);

        leaveOnServerCountCheck = new QCheckBox(page2);
        leaveOnServerCountCheck->setObjectName("leaveOnServerCountCheck");

        gridLayout_3->addWidget(leaveOnServerCountCheck, 2, 0, 1, 1);

        leaveOnServerCountSpin = new QSpinBox(page2);
        leaveOnServerCountSpin->setObjectName("leaveOnServerCountSpin");
        leaveOnServerCountSpin->setEnabled(true);
        leaveOnServerCountSpin->setMinimum(0);
        leaveOnServerCountSpin->setMaximum(999999);
        leaveOnServerCountSpin->setValue(99);

        gridLayout_3->addWidget(leaveOnServerCountSpin, 2, 1, 1, 1);

        leaveOnServerSizeCheck = new QCheckBox(page2);
        leaveOnServerSizeCheck->setObjectName("leaveOnServerSizeCheck");

        gridLayout_3->addWidget(leaveOnServerSizeCheck, 3, 0, 1, 1);

        leaveOnServerSizeSpin = new QSpinBox(page2);
        leaveOnServerSizeSpin->setObjectName("leaveOnServerSizeSpin");
        leaveOnServerSizeSpin->setEnabled(true);
        leaveOnServerSizeSpin->setMinimum(1);
        leaveOnServerSizeSpin->setMaximum(999999);
        leaveOnServerSizeSpin->setValue(10);

        gridLayout_3->addWidget(leaveOnServerSizeSpin, 3, 1, 1, 1);

        usePipeliningCheck = new QCheckBox(page2);
        usePipeliningCheck->setObjectName("usePipeliningCheck");

        gridLayout_3->addWidget(usePipeliningCheck, 4, 0, 1, 1);


        formLayout_2->setLayout(1, QFormLayout::ItemRole::FieldRole, gridLayout_3);

        formLayout_4 = new QFormLayout();
        formLayout_4->setObjectName("formLayout_4");
        formLayout_4->setSizeConstraint(QLayout::SetMinimumSize);
        formLayout_4->setHorizontalSpacing(4);
        formLayout_4->setVerticalSpacing(4);
        label_8 = new QLabel(page2);
        label_8->setObjectName("label_8");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, label_8);

        folderRequester = new Akonadi::CollectionRequester(page2);
        folderRequester->setObjectName("folderRequester");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::FieldRole, folderRequester);

        preCommandLabel = new QLabel(page2);
        preCommandLabel->setObjectName("preCommandLabel");

        formLayout_4->setWidget(1, QFormLayout::ItemRole::LabelRole, preCommandLabel);

        precommand = new QLineEdit(page2);
        precommand->setObjectName("precommand");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(precommand->sizePolicy().hasHeightForWidth());
        precommand->setSizePolicy(sizePolicy2);
        precommand->setProperty("showClearButton", QVariant(true));

        formLayout_4->setWidget(1, QFormLayout::ItemRole::FieldRole, precommand);


        formLayout_2->setLayout(3, QFormLayout::ItemRole::SpanningRole, formLayout_4);

        ktitlewidget_2 = new KTitleWidget(page2);
        ktitlewidget_2->setObjectName("ktitlewidget_2");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::SpanningRole, ktitlewidget_2);

        checkCapabilitiesStack = new QStackedWidget(page2);
        checkCapabilitiesStack->setObjectName("checkCapabilitiesStack");
        page = new QWidget();
        page->setObjectName("page");
        formLayout = new QFormLayout(page);
        formLayout->setObjectName("formLayout");
        checkCapabilities = new QPushButton(page);
        checkCapabilities->setObjectName("checkCapabilities");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, checkCapabilities);

        label_11 = new QLabel(page);
        label_11->setObjectName("label_11");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_11);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        encryptionNone = new QRadioButton(page);
        encryptionNone->setObjectName("encryptionNone");
        encryptionNone->setChecked(true);

        horizontalLayout_2->addWidget(encryptionNone);

        encryptionSSL = new QRadioButton(page);
        encryptionSSL->setObjectName("encryptionSSL");

        horizontalLayout_2->addWidget(encryptionSSL);

        encryptionTLS = new QRadioButton(page);
        encryptionTLS->setObjectName("encryptionTLS");

        horizontalLayout_2->addWidget(encryptionTLS);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        imapInfo = new QLabel(page);
        imapInfo->setObjectName("imapInfo");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, imapInfo);

        label_13 = new QLabel(page);
        label_13->setObjectName("label_13");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_13);

        portEdit = new QSpinBox(page);
        portEdit->setObjectName("portEdit");
        portEdit->setMinimum(1);
        portEdit->setMaximum(65534);
        portEdit->setValue(110);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, portEdit);

        label_12 = new QLabel(page);
        label_12->setObjectName("label_12");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_12);

        authCombo = new QComboBox(page);
        authCombo->setObjectName("authCombo");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, authCombo);

        proxyCheck = new QCheckBox(page);
        proxyCheck->setObjectName("proxyCheck");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, proxyCheck);

        verticalSpacer_2 = new QSpacerItem(20, 78, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(6, QFormLayout::ItemRole::FieldRole, verticalSpacer_2);

        checkCapabilitiesStack->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        verticalLayout_4 = new QVBoxLayout(page_2);
        verticalLayout_4->setObjectName("verticalLayout_4");
        checkCapabilitiesProgress = new QProgressBar(page_2);
        checkCapabilitiesProgress->setObjectName("checkCapabilitiesProgress");
        checkCapabilitiesProgress->setValue(0);

        verticalLayout_4->addWidget(checkCapabilitiesProgress);

        checkCapabilitiesStack->addWidget(page_2);

        formLayout_2->setWidget(5, QFormLayout::ItemRole::SpanningRole, checkCapabilitiesStack);

        tabWidget->addTab(page2, QString());

        gridLayout_2->addWidget(tabWidget, 2, 0, 1, 1);

#if QT_CONFIG(shortcut)
        label_2->setBuddy(nameEdit);
        label_5->setBuddy(hostEdit);
        label_3->setBuddy(loginEdit);
        passwordLabel->setBuddy(passwordEdit);
        preCommandLabel->setBuddy(precommand);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(tabWidget, nameEdit);
        QWidget::setTabOrder(nameEdit, hostEdit);
        QWidget::setTabOrder(hostEdit, loginEdit);
        QWidget::setTabOrder(loginEdit, passwordEdit);
        QWidget::setTabOrder(passwordEdit, leaveOnServerCheck);
        QWidget::setTabOrder(leaveOnServerCheck, leaveOnServerDaysCheck);
        QWidget::setTabOrder(leaveOnServerDaysCheck, leaveOnServerDaysSpin);
        QWidget::setTabOrder(leaveOnServerDaysSpin, leaveOnServerCountCheck);
        QWidget::setTabOrder(leaveOnServerCountCheck, leaveOnServerCountSpin);
        QWidget::setTabOrder(leaveOnServerCountSpin, leaveOnServerSizeCheck);
        QWidget::setTabOrder(leaveOnServerSizeCheck, leaveOnServerSizeSpin);
        QWidget::setTabOrder(leaveOnServerSizeSpin, usePipeliningCheck);
        QWidget::setTabOrder(usePipeliningCheck, precommand);
        QWidget::setTabOrder(precommand, checkCapabilities);
        QWidget::setTabOrder(checkCapabilities, encryptionNone);
        QWidget::setTabOrder(encryptionNone, encryptionSSL);
        QWidget::setTabOrder(encryptionSSL, encryptionTLS);
        QWidget::setTabOrder(encryptionTLS, portEdit);
        QWidget::setTabOrder(portEdit, authCombo);

        retranslateUi(PopPage);

        tabWidget->setCurrentIndex(0);
        checkCapabilitiesStack->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(PopPage);
    } // setupUi

    void retranslateUi(QWidget *PopPage)
    {
        titleLabel->setText(tr2i18n("Account Type: POP Account", nullptr));
        ktitlewidget_4->setText(tr2i18n("Account Information", nullptr));
#if QT_CONFIG(whatsthis)
        label_2->setWhatsThis(tr2i18n("Your Internet Service Provider gave you a <em>user name</em> which is used to authenticate you with their servers. It usually is the first part of your email address (the part before <em>@</em>).", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_2->setText(tr2i18n("Account &name:", nullptr));
#if QT_CONFIG(tooltip)
        nameEdit->setToolTip(tr2i18n("Name displayed in the list of accounts", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        nameEdit->setWhatsThis(tr2i18n("Account name: This defines the name displayed in the account list.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_5->setText(tr2i18n("Incoming &mail server:", nullptr));
#if QT_CONFIG(tooltip)
        hostEdit->setToolTip(tr2i18n("Address of the mail POP3 server", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        hostEdit->setWhatsThis(tr2i18n("The address of the POP3 server, e.g. pop3.yourprovider.org. You should get this address from your mail provider.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_3->setText(tr2i18n("Use&rname:", nullptr));
#if QT_CONFIG(tooltip)
        loginEdit->setToolTip(tr2i18n("The username that identifies you against the mail server", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        loginEdit->setWhatsThis(tr2i18n("Your Internet Service Provider gave you a <em>user name</em> which is used to authenticate you with their servers. It usually is the first part of your email address (the part before <em>@</em>).", nullptr));
#endif // QT_CONFIG(whatsthis)
        passwordLabel->setText(tr2i18n("P&assword:", nullptr));
#if QT_CONFIG(tooltip)
        passwordEdit->setToolTip(tr2i18n("Password for access to the mail server", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        passwordEdit->setWhatsThis(tr2i18n("Password: The password given to you by your mail provider.", nullptr));
#endif // QT_CONFIG(whatsthis)
        ktitlewidget_5->setText(tr2i18n("Mail Checking Options", nullptr));
#if QT_CONFIG(tooltip)
        intervalCheck->setToolTip(tr2i18n("If active, the POP3 account will be checked for new mail every x minutes", nullptr));
#endif // QT_CONFIG(tooltip)
        intervalCheck->setText(tr2i18n("Enable &interval mail checking", nullptr));
        intervalLabel->setText(tr2i18n("Check mail interval:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(page1), tr2i18n("General", nullptr));
        ktitlewidget->setText(tr2i18n("POP Settings", nullptr));
#if QT_CONFIG(tooltip)
        leaveOnServerCheck->setToolTip(tr2i18n("If checked the message is not deleted from the mail server", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        leaveOnServerCheck->setWhatsThis(tr2i18n("Check this option if you want to fetch only copies of the mails and leave the original mails on the server.", nullptr));
#endif // QT_CONFIG(whatsthis)
        leaveOnServerCheck->setText(tr2i18n("Lea&ve fetched messages on the server", nullptr));
#if QT_CONFIG(tooltip)
        leaveOnServerDaysCheck->setToolTip(tr2i18n("The original message is deleted from the server after x days", nullptr));
#endif // QT_CONFIG(tooltip)
        leaveOnServerDaysCheck->setText(tr2i18n("Days to leave messages on the server:", nullptr));
#if QT_CONFIG(tooltip)
        leaveOnServerCountCheck->setToolTip(tr2i18n("Only the x most recent messages are kept on the server", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        leaveOnServerCountCheck->setWhatsThis(tr2i18n("Check this option if you want to only keep the x most recent messages on the server and delete all older.", nullptr));
#endif // QT_CONFIG(whatsthis)
        leaveOnServerCountCheck->setText(tr2i18n("Number of messages to keep:", nullptr));
#if QT_CONFIG(tooltip)
        leaveOnServerSizeCheck->setToolTip(tr2i18n("Keep most recent messages within the quota and delete oldest", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        leaveOnServerSizeCheck->setWhatsThis(tr2i18n("If active, most recent messages are kept until the quota is reached and oldest messages are deleted.", nullptr));
#endif // QT_CONFIG(whatsthis)
        leaveOnServerSizeCheck->setText(tr2i18n("Maximum megabytes to keep:", nullptr));
        leaveOnServerSizeSpin->setSuffix(tr2i18n(" MB", nullptr));
        usePipeliningCheck->setText(tr2i18n("&Use pipelining for faster mail download", nullptr));
        label_8->setText(tr2i18n("Destination folder:", nullptr));
        preCommandLabel->setText(tr2i18n("Pre-com&mand:", nullptr));
#if QT_CONFIG(tooltip)
        precommand->setToolTip(tr2i18n("Command that is executed before checking mail", nullptr));
#endif // QT_CONFIG(tooltip)
        ktitlewidget_2->setText(tr2i18n("Connection Settings", nullptr));
        checkCapabilities->setText(tr2i18n("Auto Detect", nullptr));
        label_11->setText(tr2i18n("Encryption:", nullptr));
        encryptionNone->setText(tr2i18n("None", nullptr));
        encryptionSSL->setText(tr2i18n("SSL/TLS", nullptr));
        encryptionTLS->setText(tr2i18n("STA&RTTLS", nullptr));
        imapInfo->setText(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Noto Sans'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Sans Serif'; font-weight:600;\">SSL/TLS</span><span style=\" font-family:'Sans Serif';\"> is safe POP over port 995;</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Sans Serif'; font-weight:600;\">STARTTLS</span><span style=\" font-family:'Sans Serif';\"> will operate on port 110 and switch to a secure connection directly after connecting;</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; ma"
                        "rgin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Sans Serif'; font-weight:600;\">None</span><span style=\" font-family:'Sans Serif';\"> will connect to port 110 but not switch to a secure connection. This setting is not recommended.</span></p></body></html>", nullptr));
        label_13->setText(tr2i18n("Port:", nullptr));
        label_12->setText(tr2i18n("Authentication:", nullptr));
#if QT_CONFIG(tooltip)
        proxyCheck->setToolTip(tr2i18n("If checked, the system proxy settings will be used to connect to the mail server.", nullptr));
#endif // QT_CONFIG(tooltip)
        proxyCheck->setText(tr2i18n("Connect using the system proxy settings", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(page2), tr2i18n("Advanced", nullptr));
        (void)PopPage;
    } // retranslateUi

};

namespace Ui {
    class PopPage: public Ui_PopPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // POPSETTINGS_H

