/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.Ews.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef EWSSETTINGSADAPTOR_H
#define EWSSETTINGSADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "ewssettings.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Akonadi.Ews.Settings
 */
class EwsSettingsAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Akonadi.Ews.Settings")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Akonadi.Ews.Settings\">\n"
"    <method name=\"save\"/>\n"
"    <method name=\"baseUrl\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setBaseUrl\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"username\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setUsername\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"domain\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setDomain\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"hasDomain\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setHasDomain\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"email\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setEmail\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"autoDiscovery\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setAutoDiscovery\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"pollInterval\">\n"
"      <arg direction=\"out\" type=\"d\"/>\n"
"    </method>\n"
"    <method name=\"setPollInterval\">\n"
"      <arg direction=\"in\" type=\"d\"/>\n"
"    </method>\n"
"    <method name=\"retrievalMethod\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setRetrievalMethod\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"serverSubscription\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setServerSubscription\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"serverSubscriptionList\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"setServerSubscriptionList\">\n"
"      <arg direction=\"in\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"enableNTLMv2\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setEnableNTLMv2\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"userAgent\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setUserAgent\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"authMode\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setAuthMode\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"oAuth2AppId\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setOAuth2AppId\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"oAuth2ReturnUri\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setOAuth2ReturnUri\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"pKeyCert\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setPKeyCert\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"pKeyKey\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setPKeyKey\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"folderSyncState\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setFolderSyncState\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"eventSubscriptionId\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setEventSubscriptionId\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"eventSubscriptionWatermark\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setEventSubscriptionWatermark\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    EwsSettingsAdaptor(EwsSettings *parent);
    ~EwsSettingsAdaptor() override;

    inline EwsSettings *parent() const
    { return static_cast<EwsSettings *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QString authMode();
    bool autoDiscovery();
    QString baseUrl();
    QString domain();
    QString email();
    bool enableNTLMv2();
    QString eventSubscriptionId();
    QString eventSubscriptionWatermark();
    QString folderSyncState();
    bool hasDomain();
    QString oAuth2AppId();
    QString oAuth2ReturnUri();
    QString pKeyCert();
    QString pKeyKey();
    double pollInterval();
    int retrievalMethod();
    void save();
    bool serverSubscription();
    QStringList serverSubscriptionList();
    void setAuthMode(const QString &in0);
    void setAutoDiscovery(bool in0);
    void setBaseUrl(const QString &in0);
    void setDomain(const QString &in0);
    void setEmail(const QString &in0);
    void setEnableNTLMv2(bool in0);
    void setEventSubscriptionId(const QString &in0);
    void setEventSubscriptionWatermark(const QString &in0);
    void setFolderSyncState(const QString &in0);
    void setHasDomain(bool in0);
    void setOAuth2AppId(const QString &in0);
    void setOAuth2ReturnUri(const QString &in0);
    void setPKeyCert(const QString &in0);
    void setPKeyKey(const QString &in0);
    void setPollInterval(double in0);
    void setRetrievalMethod(int in0);
    void setServerSubscription(bool in0);
    void setServerSubscriptionList(const QStringList &in0);
    void setUserAgent(const QString &in0);
    void setUsername(const QString &in0);
    QString userAgent();
    QString username();
Q_SIGNALS: // SIGNALS
};

#endif
