/****************************************************************************
** Meta object code from reading C++ file 'ewsresource.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdepim-runtime-26.04.2/resources/ews/ewsresource.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ewsresource.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11EwsResourceE_t {};
} // unnamed namespace

template <> constexpr inline auto EwsResource::qt_create_metaobjectdata<qt_meta_tag_ZN11EwsResourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EwsResource",
        "D-Bus Interface",
        "org.kde.Akonadi.Ews.Resource",
        "messageSent",
        "",
        "id",
        "error",
        "configure",
        "WId",
        "windowId",
        "clearCollectionSyncState",
        "collectionId",
        "clearFolderTreeSyncState",
        "setInitialReconnectTimeout",
        "timeout",
        "retrieveCollections",
        "retrieveItems",
        "Akonadi::Collection",
        "collection",
        "Akonadi::Item::List",
        "items",
        "QSet<QByteArray>",
        "parts",
        "retrieveTags",
        "dumpResourceToString",
        "fetchFoldersJobFinished",
        "KJob*",
        "job",
        "fetchFoldersIncrJobFinished",
        "itemFetchJobFinished",
        "getItemsRequestFinished",
        "itemChangeRequestFinished",
        "itemModifyFlagsRequestFinished",
        "itemMoveRequestFinished",
        "itemDeleteRequestFinished",
        "itemCreateRequestFinished",
        "itemSendRequestFinished",
        "folderCreateRequestFinished",
        "folderMoveRequestFinished",
        "folderUpdateRequestFinished",
        "folderDeleteRequestFinished",
        "delayedInit",
        "foldersModifiedEvent",
        "EwsId::List",
        "folders",
        "foldersModifiedCollectionSyncFinished",
        "folderTreeModifiedEvent",
        "fullSyncRequestedEvent",
        "rootFolderFetchFinished",
        "specialFoldersFetchFinished",
        "itemsTagChangeFinished",
        "globalTagChangeFinished",
        "globalTagsRetrievalFinished",
        "adjustInboxRemoteIdFetchFinished",
        "rootCollectionFetched",
        "connectionError",
        "reloadConfig",
        "authSucceeded",
        "authFailed",
        "requestAuthFailed",
        "emitReadyStatus",
        "adjustRootCollectionName",
        "newName",
        "sendMessage",
        "content",
        "messageSendRequestFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'messageSent'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'configure'
        QtMocHelpers::SlotData<void(WId)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'clearCollectionSyncState'
        QtMocHelpers::SlotData<void(int)>(10, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'clearFolderTreeSyncState'
        QtMocHelpers::SlotData<void()>(12, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'setInitialReconnectTimeout'
        QtMocHelpers::SlotData<void(int)>(13, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'retrieveCollections'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'retrieveItems'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(16, 4, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'retrieveItems'
        QtMocHelpers::SlotData<bool(const Akonadi::Item::List &, const QSet<QByteArray> &)>(16, 4, QMC::AccessProtected, QMetaType::Bool, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Slot 'retrieveTags'
        QtMocHelpers::SlotData<void()>(23, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'dumpResourceToString'
        QtMocHelpers::SlotData<QString() const>(24, 4, QMC::AccessProtected, QMetaType::QString),
        // Slot 'fetchFoldersJobFinished'
        QtMocHelpers::SlotData<void(KJob *)>(25, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'fetchFoldersIncrJobFinished'
        QtMocHelpers::SlotData<void(KJob *)>(28, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'itemFetchJobFinished'
        QtMocHelpers::SlotData<void(KJob *)>(29, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'getItemsRequestFinished'
        QtMocHelpers::SlotData<void(KJob *)>(30, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'itemChangeRequestFinished'
        QtMocHelpers::SlotData<void(KJob *)>(31, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'itemModifyFlagsRequestFinished'
        QtMocHelpers::SlotData<void(KJob *)>(32, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'itemMoveRequestFinished'
        QtMocHelpers::SlotData<void(KJob *)>(33, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'itemDeleteRequestFinished'
        QtMocHelpers::SlotData<void(KJob *)>(34, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'itemCreateRequestFinished'
        QtMocHelpers::SlotData<void(KJob *)>(35, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'itemSendRequestFinished'
        QtMocHelpers::SlotData<void(KJob *)>(36, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'folderCreateRequestFinished'
        QtMocHelpers::SlotData<void(KJob *)>(37, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'folderMoveRequestFinished'
        QtMocHelpers::SlotData<void(KJob *)>(38, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'folderUpdateRequestFinished'
        QtMocHelpers::SlotData<void(KJob *)>(39, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'folderDeleteRequestFinished'
        QtMocHelpers::SlotData<void(KJob *)>(40, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'delayedInit'
        QtMocHelpers::SlotData<void()>(41, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'foldersModifiedEvent'
        QtMocHelpers::SlotData<void(const EwsId::List &)>(42, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 43, 44 },
        }}),
        // Slot 'foldersModifiedCollectionSyncFinished'
        QtMocHelpers::SlotData<void(KJob *)>(45, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'folderTreeModifiedEvent'
        QtMocHelpers::SlotData<void()>(46, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fullSyncRequestedEvent'
        QtMocHelpers::SlotData<void()>(47, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'rootFolderFetchFinished'
        QtMocHelpers::SlotData<void(KJob *)>(48, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'specialFoldersFetchFinished'
        QtMocHelpers::SlotData<void(KJob *)>(49, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'itemsTagChangeFinished'
        QtMocHelpers::SlotData<void(KJob *)>(50, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'globalTagChangeFinished'
        QtMocHelpers::SlotData<void(KJob *)>(51, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'globalTagsRetrievalFinished'
        QtMocHelpers::SlotData<void(KJob *)>(52, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'adjustInboxRemoteIdFetchFinished'
        QtMocHelpers::SlotData<void(KJob *)>(53, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'rootCollectionFetched'
        QtMocHelpers::SlotData<void(KJob *)>(54, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'connectionError'
        QtMocHelpers::SlotData<void()>(55, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'reloadConfig'
        QtMocHelpers::SlotData<void()>(56, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'authSucceeded'
        QtMocHelpers::SlotData<void()>(57, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'authFailed'
        QtMocHelpers::SlotData<void(const QString &)>(58, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'requestAuthFailed'
        QtMocHelpers::SlotData<void()>(59, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'emitReadyStatus'
        QtMocHelpers::SlotData<void()>(60, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'adjustRootCollectionName'
        QtMocHelpers::SlotData<void(const QString &)>(61, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 62 },
        }}),
        // Slot 'sendMessage'
        QtMocHelpers::SlotData<void(const QString &, const QByteArray &)>(63, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QByteArray, 64 },
        }}),
        // Slot 'messageSendRequestFinished'
        QtMocHelpers::SlotData<void(KJob *)>(65, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<EwsResource, qt_meta_tag_ZN11EwsResourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject EwsResource::staticMetaObject = { {
    QMetaObject::SuperData::link<Akonadi::ResourceWidgetBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11EwsResourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11EwsResourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11EwsResourceE_t>.metaTypes,
    nullptr
} };

void EwsResource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EwsResource *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->messageSent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->configure((*reinterpret_cast<std::add_pointer_t<WId>>(_a[1]))); break;
        case 2: _t->clearCollectionSyncState((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->clearFolderTreeSyncState(); break;
        case 4: _t->setInitialReconnectTimeout((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->retrieveCollections(); break;
        case 6: _t->retrieveItems((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 7: { bool _r = _t->retrieveItems((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->retrieveTags(); break;
        case 9: { QString _r = _t->dumpResourceToString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->fetchFoldersJobFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 11: _t->fetchFoldersIncrJobFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 12: _t->itemFetchJobFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 13: _t->getItemsRequestFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 14: _t->itemChangeRequestFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 15: _t->itemModifyFlagsRequestFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 16: _t->itemMoveRequestFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 17: _t->itemDeleteRequestFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 18: _t->itemCreateRequestFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 19: _t->itemSendRequestFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 20: _t->folderCreateRequestFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 21: _t->folderMoveRequestFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 22: _t->folderUpdateRequestFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 23: _t->folderDeleteRequestFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 24: _t->delayedInit(); break;
        case 25: _t->foldersModifiedEvent((*reinterpret_cast<std::add_pointer_t<EwsId::List>>(_a[1]))); break;
        case 26: _t->foldersModifiedCollectionSyncFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 27: _t->folderTreeModifiedEvent(); break;
        case 28: _t->fullSyncRequestedEvent(); break;
        case 29: _t->rootFolderFetchFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 30: _t->specialFoldersFetchFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 31: _t->itemsTagChangeFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 32: _t->globalTagChangeFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 33: _t->globalTagsRetrievalFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 34: _t->adjustInboxRemoteIdFetchFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 35: _t->rootCollectionFetched((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 36: _t->connectionError(); break;
        case 37: _t->reloadConfig(); break;
        case 38: _t->authSucceeded(); break;
        case 39: _t->authFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 40: _t->requestAuthFailed(); break;
        case 41: _t->emitReadyStatus(); break;
        case 42: _t->adjustRootCollectionName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 43: _t->sendMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 44: _t->messageSendRequestFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< EwsId::List >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 44:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EwsResource::*)(const QString & , const QString & )>(_a, &EwsResource::messageSent, 0))
            return;
    }
}

const QMetaObject *EwsResource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EwsResource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11EwsResourceE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Akonadi::AgentBase::ObserverV3"))
        return static_cast< Akonadi::AgentBase::ObserverV3*>(this);
    if (!strcmp(_clname, "Akonadi::AgentBase::TagObserver"))
        return static_cast< Akonadi::AgentBase::TagObserver*>(this);
    if (!strcmp(_clname, "Akonadi::TransportResourceBase"))
        return static_cast< Akonadi::TransportResourceBase*>(this);
    return Akonadi::ResourceWidgetBase::qt_metacast(_clname);
}

int EwsResource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Akonadi::ResourceWidgetBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    return _id;
}

// SIGNAL 0
void EwsResource::messageSent(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
QT_WARNING_POP
