/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.MailDispatcherAgent.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef MAILDISPATCHERAGENTADAPTOR_H
#define MAILDISPATCHERAGENTADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "maildispatcheragent.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Akonadi.MailDispatcherAgent
 */
class MailDispatcherAgentAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Akonadi.MailDispatcherAgent")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Akonadi.MailDispatcherAgent\">\n"
"    <signal name=\"itemDispatchStarted\"/>\n"
"  </interface>\n"
        "")
public:
    MailDispatcherAgentAdaptor(MailDispatcherAgent *parent);
    ~MailDispatcherAgentAdaptor() override;

    inline MailDispatcherAgent *parent() const
    { return static_cast<MailDispatcherAgent *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
    void itemDispatchStarted();
};

#endif
