/********************************************************************************
** Form generated from reading UI file 'compactpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COMPACTPAGE_H
#define UI_COMPACTPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CompactPage
{
public:
    QGridLayout *gridLayout_2;
    QLabel *label;
    QSpacerItem *horizontalSpacer;
    QPushButton *compactButton;
    QSpacerItem *verticalSpacer;
    QLabel *messageLabel;
    QGroupBox *kcfg_CompactFrequency;
    QGridLayout *gridLayout_3;
    QRadioButton *never;
    QRadioButton *per_x_messages;
    QSpinBox *kcfg_MessageCount;

    void setupUi(QWidget *CompactPage)
    {
        if (CompactPage->objectName().isEmpty())
            CompactPage->setObjectName("CompactPage");
        CompactPage->resize(362, 568);
        gridLayout_2 = new QGridLayout(CompactPage);
        gridLayout_2->setObjectName("gridLayout_2");
        label = new QLabel(CompactPage);
        label->setObjectName("label");
        label->setWordWrap(true);

        gridLayout_2->addWidget(label, 0, 0, 1, 4);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 3, 0, 1, 1);

        compactButton = new QPushButton(CompactPage);
        compactButton->setObjectName("compactButton");
        compactButton->setEnabled(false);

        gridLayout_2->addWidget(compactButton, 3, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 2, 2, 1, 1);

        messageLabel = new QLabel(CompactPage);
        messageLabel->setObjectName("messageLabel");

        gridLayout_2->addWidget(messageLabel, 3, 1, 1, 1);

        kcfg_CompactFrequency = new QGroupBox(CompactPage);
        kcfg_CompactFrequency->setObjectName("kcfg_CompactFrequency");
        gridLayout_3 = new QGridLayout(kcfg_CompactFrequency);
        gridLayout_3->setObjectName("gridLayout_3");
        never = new QRadioButton(kcfg_CompactFrequency);
        never->setObjectName("never");

        gridLayout_3->addWidget(never, 1, 0, 1, 2);

        per_x_messages = new QRadioButton(kcfg_CompactFrequency);
        per_x_messages->setObjectName("per_x_messages");
        per_x_messages->setChecked(true);

        gridLayout_3->addWidget(per_x_messages, 2, 0, 1, 1);

        kcfg_MessageCount = new QSpinBox(kcfg_CompactFrequency);
        kcfg_MessageCount->setObjectName("kcfg_MessageCount");

        gridLayout_3->addWidget(kcfg_MessageCount, 2, 1, 1, 1);


        gridLayout_2->addWidget(kcfg_CompactFrequency, 1, 0, 1, 3);


        retranslateUi(CompactPage);
        QObject::connect(per_x_messages, &QRadioButton::toggled, kcfg_MessageCount, &QSpinBox::setEnabled);

        QMetaObject::connectSlotsByName(CompactPage);
    } // setupUi

    void retranslateUi(QWidget *CompactPage)
    {
        label->setText(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">The only way to fully remove a mail from an mbox file is by removing it from the actual file. As this can be a rather expensive operation, the mbox resource keeps a list of deleted messages. Once in a while these messages are really removed from the file.</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Note:</span> The d"
                        "ownside of this is that if the file is changed by another program, the list of deleted messages cannot be trusted any longer and deleted messages might reappear.</p></body></html>", nullptr));
        compactButton->setText(tr2i18n("&Compact now", nullptr));
        messageLabel->setText(QString());
        never->setText(tr2i18n("&Never compact automatically", nullptr));
        per_x_messages->setText(tr2i18n("C&ompact every", nullptr));
        kcfg_MessageCount->setSuffix(tr2i18n("msg", nullptr));
        (void)CompactPage;
    } // retranslateUi

};

namespace Ui {
    class CompactPage: public Ui_CompactPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COMPACTPAGE_H

