/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.Google.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "settingsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class SettingsAdaptor
 */

SettingsAdaptor::SettingsAdaptor(GoogleSettings *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

SettingsAdaptor::~SettingsAdaptor()
{
    // destructor
}

QString SettingsAdaptor::account()
{
    // handle method call org.kde.Akonadi.Google.Settings.account
    return parent()->account();
}

int SettingsAdaptor::accountId()
{
    // handle method call org.kde.Akonadi.Google.Settings.accountId
    return parent()->accountId();
}

QString SettingsAdaptor::accountName()
{
    // handle method call org.kde.Akonadi.Google.Settings.accountName
    return parent()->accountName();
}

QStringList SettingsAdaptor::calendars()
{
    // handle method call org.kde.Akonadi.Google.Settings.calendars
    return parent()->calendars();
}

bool SettingsAdaptor::enableIntervalCheck()
{
    // handle method call org.kde.Akonadi.Google.Settings.enableIntervalCheck
    return parent()->enableIntervalCheck();
}

QString SettingsAdaptor::eventsSince()
{
    // handle method call org.kde.Akonadi.Google.Settings.eventsSince
    return parent()->eventsSince();
}

int SettingsAdaptor::intervalCheckTime()
{
    // handle method call org.kde.Akonadi.Google.Settings.intervalCheckTime
    return parent()->intervalCheckTime();
}

void SettingsAdaptor::save()
{
    // handle method call org.kde.Akonadi.Google.Settings.save
    parent()->save();
}

void SettingsAdaptor::setAccount(const QString &in0)
{
    // handle method call org.kde.Akonadi.Google.Settings.setAccount
    parent()->setAccount(in0);
}

void SettingsAdaptor::setAccountId(int in0)
{
    // handle method call org.kde.Akonadi.Google.Settings.setAccountId
    parent()->setAccountId(in0);
}

void SettingsAdaptor::setAccountName(const QString &in0)
{
    // handle method call org.kde.Akonadi.Google.Settings.setAccountName
    parent()->setAccountName(in0);
}

void SettingsAdaptor::setCalendars(const QStringList &in0)
{
    // handle method call org.kde.Akonadi.Google.Settings.setCalendars
    parent()->setCalendars(in0);
}

void SettingsAdaptor::setEnableIntervalCheck(bool in0)
{
    // handle method call org.kde.Akonadi.Google.Settings.setEnableIntervalCheck
    parent()->setEnableIntervalCheck(in0);
}

void SettingsAdaptor::setEventsSince(const QString &in0)
{
    // handle method call org.kde.Akonadi.Google.Settings.setEventsSince
    parent()->setEventsSince(in0);
}

void SettingsAdaptor::setIntervalCheckTime(int in0)
{
    // handle method call org.kde.Akonadi.Google.Settings.setIntervalCheckTime
    parent()->setIntervalCheckTime(in0);
}

void SettingsAdaptor::setTaskLists(const QStringList &in0)
{
    // handle method call org.kde.Akonadi.Google.Settings.setTaskLists
    parent()->setTaskLists(in0);
}

QStringList SettingsAdaptor::taskLists()
{
    // handle method call org.kde.Akonadi.Google.Settings.taskLists
    return parent()->taskLists();
}


#include "moc_settingsadaptor.cpp"
