/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.NewMailNotifier.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef NEWMAILNOTIFIERADAPTOR_H
#define NEWMAILNOTIFIERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "newmailnotifieragent.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Akonadi.NewMailNotifier
 */
class NewMailNotifierAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Akonadi.NewMailNotifier")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Akonadi.NewMailNotifier\">\n"
"    <method name=\"setEnableAgent\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"enabledAgent\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setVerboseMailNotification\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"verboseMailNotification\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"printDebug\"/>\n"
"    <method name=\"showNotNotificationHistoryDialog\">\n"
"      <arg direction=\"in\" type=\"x\" name=\"windowId\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    NewMailNotifierAdaptor(NewMailNotifierAgent *parent);
    ~NewMailNotifierAdaptor() override;

    inline NewMailNotifierAgent *parent() const
    { return static_cast<NewMailNotifierAgent *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    bool enabledAgent();
    void printDebug();
    void setEnableAgent(bool in0);
    void setVerboseMailNotification(bool in0);
    void showNotNotificationHistoryDialog(qlonglong windowId);
    bool verboseMailNotification();
Q_SIGNALS: // SIGNALS
};

#endif
