/********************************************************************************
** Form generated from reading UI file 'ewsconfigdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EWSCONFIGDIALOG_H
#define UI_EWSCONFIGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kpasswordlineedit.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_SetupServerView
{
public:
    QVBoxLayout *mainLayout;
    QTabWidget *tabWidget;
    QWidget *generalTab;
    QGridLayout *gridLayout;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *generalTabLayout;
    QGroupBox *accountInfoGroupBox;
    QFormLayout *accountInfoGroupBoxLayout;
    QLabel *accountNameLabel;
    QLineEdit *accountName;
    QLabel *emailLabel;
    QLineEdit *kcfg_Email;
    QGroupBox *authenticationGroupBox;
    QVBoxLayout *authenticationGroupBoxLayout;
    QRadioButton *authUsernameRadioButton;
    QWidget *authUsernameContainer;
    QVBoxLayout *authUsernameContainerLayout;
    QWidget *authUsernameFieldsContainer;
    QFormLayout *authUsernameFieldsContainerLayout;
    QCheckBox *kcfg_HasDomain;
    QLineEdit *kcfg_Domain;
    QLabel *usernameLabel;
    QLabel *passwordLabel;
    KPasswordLineEdit *passwordEdit;
    QLineEdit *kcfg_Username;
    QLabel *kerberosNoteLabel;
    QRadioButton *authOAuth2RadioButton;
    QRadioButton *authInTuneRadioButton;
    QGroupBox *ewsSettingsGroupBox;
    QFormLayout *ewsSettingsGroupBoxLayout;
    QLabel *serverUrlLabel;
    QLineEdit *kcfg_BaseUrl;
    QWidget *autodiscoveryContainer;
    QHBoxLayout *autodiscoveryContainerLayout;
    QCheckBox *kcfg_AutoDiscovery;
    QPushButton *autodiscoverButton;
    QPushButton *tryConnectButton;
    QGroupBox *pkeyAuthGroupBox;
    QFormLayout *pkeyAuthGroupBoxLayout;
    QLabel *pkeyAuthCertLabel;
    KUrlRequester *pkeyAuthCert;
    QLabel *pkeyAuthKeyLabel;
    KUrlRequester *pkeyAuthKey;
    QLabel *pkeyAuthPasswordLabel;
    KPasswordLineEdit *pkeyAuthPassword;
    QSpacerItem *generalTabSpacer;
    QWidget *subscriptionTab;
    QVBoxLayout *subscriptionTabLayout;
    QWidget *advancedTab;
    QVBoxLayout *advancedTabLayout;
    QGroupBox *retrievalMethodGroupBox;
    QVBoxLayout *retrievalMethodGroupBoxLayout;
    QRadioButton *pollRadioButton;
    QWidget *pollIntervalWidget;
    QFormLayout *pollingIntervalWidgetLayout;
    QDoubleSpinBox *kcfg_PollInterval;
    QLabel *pollIntervalLabel;
    QRadioButton *streamingRadioButton;
    QGroupBox *advAuthenticationGroupBox;
    QVBoxLayout *advAuthenticationGroupBoxLayout;
    QCheckBox *kcfg_EnableNTLMv2;
    QGroupBox *userAgentGroupBox;
    QVBoxLayout *userAgentGroupBoxLayout;
    QComboBox *userAgentCombo;
    QLineEdit *userAgentEdit;
    QGroupBox *clearSyncStateGroupBox;
    QVBoxLayout *verticalLayout;
    QLabel *clearSyncStateLabel;
    QWidget *clearSyncStateBtnContainer;
    QHBoxLayout *clearSyncStateBtnContainerLayout;
    QPushButton *clearFolderTreeSyncStateButton;
    QPushButton *clearFolderItemSyncStateButton;
    QSpacerItem *verticalSpacer;
    QWidget *statusTab;
    QVBoxLayout *statusTabLayout;
    QGroupBox *serverStatusGroupBox;
    QFormLayout *serverStatusGroupBoxLayout;
    QLabel *serverStatusLabel;
    QLabel *serverStatusText;
    QLabel *serverVersionLabel;
    QLabel *serverVersionText;
    QSpacerItem *statusTabSpacer;
    QWidget *aboutTab;
    QHBoxLayout *aboutTabLayout;
    QWidget *aboutIconWidget;
    QVBoxLayout *aboutIconWidgetLayout;
    QLabel *aboutIconLabel;
    QSpacerItem *aboutIconSpacer;
    QWidget *aboutTextWidget;
    QVBoxLayout *aboutTextWidgetLayout;
    QLabel *aboutTextLabel;
    QLabel *aboutVersionLabel;
    QLabel *aboutCopyrightLabel;
    QLabel *aboutLicenseLabel;
    QLabel *aboutUrlLabel;
    QSpacerItem *aboutTextSpacer;

    void setupUi(QWidget *SetupServerView)
    {
        if (SetupServerView->objectName().isEmpty())
            SetupServerView->setObjectName("SetupServerView");
        SetupServerView->resize(602, 895);
        mainLayout = new QVBoxLayout(SetupServerView);
        mainLayout->setObjectName("mainLayout");
        tabWidget = new QTabWidget(SetupServerView);
        tabWidget->setObjectName("tabWidget");
        generalTab = new QWidget();
        generalTab->setObjectName("generalTab");
        gridLayout = new QGridLayout(generalTab);
        gridLayout->setObjectName("gridLayout");
        scrollArea = new QScrollArea(generalTab);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 545, 828));
        generalTabLayout = new QVBoxLayout(scrollAreaWidgetContents);
        generalTabLayout->setObjectName("generalTabLayout");
        accountInfoGroupBox = new QGroupBox(scrollAreaWidgetContents);
        accountInfoGroupBox->setObjectName("accountInfoGroupBox");
        accountInfoGroupBoxLayout = new QFormLayout(accountInfoGroupBox);
        accountInfoGroupBoxLayout->setObjectName("accountInfoGroupBoxLayout");
        accountNameLabel = new QLabel(accountInfoGroupBox);
        accountNameLabel->setObjectName("accountNameLabel");
        accountNameLabel->setMinimumSize(QSize(95, 0));

        accountInfoGroupBoxLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, accountNameLabel);

        accountName = new QLineEdit(accountInfoGroupBox);
        accountName->setObjectName("accountName");

        accountInfoGroupBoxLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, accountName);

        emailLabel = new QLabel(accountInfoGroupBox);
        emailLabel->setObjectName("emailLabel");

        accountInfoGroupBoxLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, emailLabel);

        kcfg_Email = new QLineEdit(accountInfoGroupBox);
        kcfg_Email->setObjectName("kcfg_Email");

        accountInfoGroupBoxLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_Email);


        generalTabLayout->addWidget(accountInfoGroupBox);

        authenticationGroupBox = new QGroupBox(scrollAreaWidgetContents);
        authenticationGroupBox->setObjectName("authenticationGroupBox");
        authenticationGroupBoxLayout = new QVBoxLayout(authenticationGroupBox);
        authenticationGroupBoxLayout->setObjectName("authenticationGroupBoxLayout");
        authUsernameRadioButton = new QRadioButton(authenticationGroupBox);
        authUsernameRadioButton->setObjectName("authUsernameRadioButton");
        authUsernameRadioButton->setChecked(true);

        authenticationGroupBoxLayout->addWidget(authUsernameRadioButton);

        authUsernameContainer = new QWidget(authenticationGroupBox);
        authUsernameContainer->setObjectName("authUsernameContainer");
        authUsernameContainerLayout = new QVBoxLayout(authUsernameContainer);
        authUsernameContainerLayout->setObjectName("authUsernameContainerLayout");
        authUsernameContainerLayout->setContentsMargins(0, 0, 0, 0);
        authUsernameFieldsContainer = new QWidget(authUsernameContainer);
        authUsernameFieldsContainer->setObjectName("authUsernameFieldsContainer");
        authUsernameFieldsContainerLayout = new QFormLayout(authUsernameFieldsContainer);
        authUsernameFieldsContainerLayout->setObjectName("authUsernameFieldsContainerLayout");
        authUsernameFieldsContainerLayout->setContentsMargins(0, 0, 0, 0);
        kcfg_HasDomain = new QCheckBox(authUsernameFieldsContainer);
        kcfg_HasDomain->setObjectName("kcfg_HasDomain");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_HasDomain->sizePolicy().hasHeightForWidth());
        kcfg_HasDomain->setSizePolicy(sizePolicy);

        authUsernameFieldsContainerLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, kcfg_HasDomain);

        kcfg_Domain = new QLineEdit(authUsernameFieldsContainer);
        kcfg_Domain->setObjectName("kcfg_Domain");
        kcfg_Domain->setEnabled(false);

        authUsernameFieldsContainerLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_Domain);

        usernameLabel = new QLabel(authUsernameFieldsContainer);
        usernameLabel->setObjectName("usernameLabel");
        usernameLabel->setMinimumSize(QSize(95, 0));
        usernameLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        authUsernameFieldsContainerLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, usernameLabel);

        passwordLabel = new QLabel(authUsernameFieldsContainer);
        passwordLabel->setObjectName("passwordLabel");

        authUsernameFieldsContainerLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, passwordLabel);

        passwordEdit = new KPasswordLineEdit(authUsernameFieldsContainer);
        passwordEdit->setObjectName("passwordEdit");

        authUsernameFieldsContainerLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, passwordEdit);

        kcfg_Username = new QLineEdit(authUsernameFieldsContainer);
        kcfg_Username->setObjectName("kcfg_Username");

        authUsernameFieldsContainerLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_Username);


        authUsernameContainerLayout->addWidget(authUsernameFieldsContainer);

        kerberosNoteLabel = new QLabel(authUsernameContainer);
        kerberosNoteLabel->setObjectName("kerberosNoteLabel");
        kerberosNoteLabel->setScaledContents(false);
        kerberosNoteLabel->setWordWrap(true);

        authUsernameContainerLayout->addWidget(kerberosNoteLabel);


        authenticationGroupBoxLayout->addWidget(authUsernameContainer);

        authOAuth2RadioButton = new QRadioButton(authenticationGroupBox);
        authOAuth2RadioButton->setObjectName("authOAuth2RadioButton");
        authOAuth2RadioButton->setEnabled(false);

        authenticationGroupBoxLayout->addWidget(authOAuth2RadioButton);

        authInTuneRadioButton = new QRadioButton(authenticationGroupBox);
        authInTuneRadioButton->setObjectName("authInTuneRadioButton");

        authenticationGroupBoxLayout->addWidget(authInTuneRadioButton);


        generalTabLayout->addWidget(authenticationGroupBox);

        ewsSettingsGroupBox = new QGroupBox(scrollAreaWidgetContents);
        ewsSettingsGroupBox->setObjectName("ewsSettingsGroupBox");
        ewsSettingsGroupBoxLayout = new QFormLayout(ewsSettingsGroupBox);
        ewsSettingsGroupBoxLayout->setObjectName("ewsSettingsGroupBoxLayout");
        serverUrlLabel = new QLabel(ewsSettingsGroupBox);
        serverUrlLabel->setObjectName("serverUrlLabel");
        serverUrlLabel->setEnabled(false);
        serverUrlLabel->setMinimumSize(QSize(95, 0));
        serverUrlLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        ewsSettingsGroupBoxLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, serverUrlLabel);

        kcfg_BaseUrl = new QLineEdit(ewsSettingsGroupBox);
        kcfg_BaseUrl->setObjectName("kcfg_BaseUrl");
        kcfg_BaseUrl->setEnabled(false);

        ewsSettingsGroupBoxLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_BaseUrl);

        autodiscoveryContainer = new QWidget(ewsSettingsGroupBox);
        autodiscoveryContainer->setObjectName("autodiscoveryContainer");
        autodiscoveryContainerLayout = new QHBoxLayout(autodiscoveryContainer);
        autodiscoveryContainerLayout->setObjectName("autodiscoveryContainerLayout");
        autodiscoveryContainerLayout->setContentsMargins(0, 0, 0, 0);
        kcfg_AutoDiscovery = new QCheckBox(autodiscoveryContainer);
        kcfg_AutoDiscovery->setObjectName("kcfg_AutoDiscovery");
        kcfg_AutoDiscovery->setChecked(true);

        autodiscoveryContainerLayout->addWidget(kcfg_AutoDiscovery);

        autodiscoverButton = new QPushButton(autodiscoveryContainer);
        autodiscoverButton->setObjectName("autodiscoverButton");

        autodiscoveryContainerLayout->addWidget(autodiscoverButton);

        tryConnectButton = new QPushButton(autodiscoveryContainer);
        tryConnectButton->setObjectName("tryConnectButton");
        tryConnectButton->setEnabled(false);

        autodiscoveryContainerLayout->addWidget(tryConnectButton);


        ewsSettingsGroupBoxLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, autodiscoveryContainer);


        generalTabLayout->addWidget(ewsSettingsGroupBox);

        pkeyAuthGroupBox = new QGroupBox(scrollAreaWidgetContents);
        pkeyAuthGroupBox->setObjectName("pkeyAuthGroupBox");
        pkeyAuthGroupBox->setEnabled(false);
        pkeyAuthGroupBoxLayout = new QFormLayout(pkeyAuthGroupBox);
        pkeyAuthGroupBoxLayout->setObjectName("pkeyAuthGroupBoxLayout");
        pkeyAuthCertLabel = new QLabel(pkeyAuthGroupBox);
        pkeyAuthCertLabel->setObjectName("pkeyAuthCertLabel");
        pkeyAuthCertLabel->setMinimumSize(QSize(95, 0));
        pkeyAuthCertLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        pkeyAuthGroupBoxLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, pkeyAuthCertLabel);

        pkeyAuthCert = new KUrlRequester(pkeyAuthGroupBox);
        pkeyAuthCert->setObjectName("pkeyAuthCert");

        pkeyAuthGroupBoxLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, pkeyAuthCert);

        pkeyAuthKeyLabel = new QLabel(pkeyAuthGroupBox);
        pkeyAuthKeyLabel->setObjectName("pkeyAuthKeyLabel");

        pkeyAuthGroupBoxLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, pkeyAuthKeyLabel);

        pkeyAuthKey = new KUrlRequester(pkeyAuthGroupBox);
        pkeyAuthKey->setObjectName("pkeyAuthKey");

        pkeyAuthGroupBoxLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, pkeyAuthKey);

        pkeyAuthPasswordLabel = new QLabel(pkeyAuthGroupBox);
        pkeyAuthPasswordLabel->setObjectName("pkeyAuthPasswordLabel");

        pkeyAuthGroupBoxLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, pkeyAuthPasswordLabel);

        pkeyAuthPassword = new KPasswordLineEdit(pkeyAuthGroupBox);
        pkeyAuthPassword->setObjectName("pkeyAuthPassword");

        pkeyAuthGroupBoxLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, pkeyAuthPassword);


        generalTabLayout->addWidget(pkeyAuthGroupBox);

        generalTabSpacer = new QSpacerItem(20, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        generalTabLayout->addItem(generalTabSpacer);

        scrollArea->setWidget(scrollAreaWidgetContents);

        gridLayout->addWidget(scrollArea, 0, 0, 1, 1);

        tabWidget->addTab(generalTab, QString());
        subscriptionTab = new QWidget();
        subscriptionTab->setObjectName("subscriptionTab");
        subscriptionTabLayout = new QVBoxLayout(subscriptionTab);
        subscriptionTabLayout->setObjectName("subscriptionTabLayout");
        tabWidget->addTab(subscriptionTab, QString());
        advancedTab = new QWidget();
        advancedTab->setObjectName("advancedTab");
        advancedTabLayout = new QVBoxLayout(advancedTab);
        advancedTabLayout->setObjectName("advancedTabLayout");
        retrievalMethodGroupBox = new QGroupBox(advancedTab);
        retrievalMethodGroupBox->setObjectName("retrievalMethodGroupBox");
        retrievalMethodGroupBoxLayout = new QVBoxLayout(retrievalMethodGroupBox);
        retrievalMethodGroupBoxLayout->setObjectName("retrievalMethodGroupBoxLayout");
        pollRadioButton = new QRadioButton(retrievalMethodGroupBox);
        pollRadioButton->setObjectName("pollRadioButton");

        retrievalMethodGroupBoxLayout->addWidget(pollRadioButton);

        pollIntervalWidget = new QWidget(retrievalMethodGroupBox);
        pollIntervalWidget->setObjectName("pollIntervalWidget");
        pollIntervalWidget->setEnabled(false);
        pollingIntervalWidgetLayout = new QFormLayout(pollIntervalWidget);
        pollingIntervalWidgetLayout->setObjectName("pollingIntervalWidgetLayout");
        pollingIntervalWidgetLayout->setContentsMargins(48, 0, 0, 0);
        kcfg_PollInterval = new QDoubleSpinBox(pollIntervalWidget);
        kcfg_PollInterval->setObjectName("kcfg_PollInterval");
        kcfg_PollInterval->setDecimals(1);
        kcfg_PollInterval->setMinimum(0.500000000000000);
        kcfg_PollInterval->setSingleStep(0.500000000000000);
        kcfg_PollInterval->setValue(1.000000000000000);

        pollingIntervalWidgetLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_PollInterval);

        pollIntervalLabel = new QLabel(pollIntervalWidget);
        pollIntervalLabel->setObjectName("pollIntervalLabel");

        pollingIntervalWidgetLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, pollIntervalLabel);


        retrievalMethodGroupBoxLayout->addWidget(pollIntervalWidget);

        streamingRadioButton = new QRadioButton(retrievalMethodGroupBox);
        streamingRadioButton->setObjectName("streamingRadioButton");
        streamingRadioButton->setChecked(true);

        retrievalMethodGroupBoxLayout->addWidget(streamingRadioButton);


        advancedTabLayout->addWidget(retrievalMethodGroupBox);

        advAuthenticationGroupBox = new QGroupBox(advancedTab);
        advAuthenticationGroupBox->setObjectName("advAuthenticationGroupBox");
        advAuthenticationGroupBoxLayout = new QVBoxLayout(advAuthenticationGroupBox);
        advAuthenticationGroupBoxLayout->setObjectName("advAuthenticationGroupBoxLayout");
        kcfg_EnableNTLMv2 = new QCheckBox(advAuthenticationGroupBox);
        kcfg_EnableNTLMv2->setObjectName("kcfg_EnableNTLMv2");

        advAuthenticationGroupBoxLayout->addWidget(kcfg_EnableNTLMv2);


        advancedTabLayout->addWidget(advAuthenticationGroupBox);

        userAgentGroupBox = new QGroupBox(advancedTab);
        userAgentGroupBox->setObjectName("userAgentGroupBox");
        userAgentGroupBox->setCheckable(true);
        userAgentGroupBox->setChecked(false);
        userAgentGroupBoxLayout = new QVBoxLayout(userAgentGroupBox);
        userAgentGroupBoxLayout->setObjectName("userAgentGroupBoxLayout");
        userAgentCombo = new QComboBox(userAgentGroupBox);
        userAgentCombo->setObjectName("userAgentCombo");

        userAgentGroupBoxLayout->addWidget(userAgentCombo);

        userAgentEdit = new QLineEdit(userAgentGroupBox);
        userAgentEdit->setObjectName("userAgentEdit");
        userAgentEdit->setEnabled(false);

        userAgentGroupBoxLayout->addWidget(userAgentEdit);


        advancedTabLayout->addWidget(userAgentGroupBox);

        clearSyncStateGroupBox = new QGroupBox(advancedTab);
        clearSyncStateGroupBox->setObjectName("clearSyncStateGroupBox");
        verticalLayout = new QVBoxLayout(clearSyncStateGroupBox);
        verticalLayout->setObjectName("verticalLayout");
        clearSyncStateLabel = new QLabel(clearSyncStateGroupBox);
        clearSyncStateLabel->setObjectName("clearSyncStateLabel");
        clearSyncStateLabel->setWordWrap(true);

        verticalLayout->addWidget(clearSyncStateLabel);

        clearSyncStateBtnContainer = new QWidget(clearSyncStateGroupBox);
        clearSyncStateBtnContainer->setObjectName("clearSyncStateBtnContainer");
        clearSyncStateBtnContainerLayout = new QHBoxLayout(clearSyncStateBtnContainer);
        clearSyncStateBtnContainerLayout->setObjectName("clearSyncStateBtnContainerLayout");
        clearSyncStateBtnContainerLayout->setContentsMargins(0, 0, 0, 0);
        clearFolderTreeSyncStateButton = new QPushButton(clearSyncStateBtnContainer);
        clearFolderTreeSyncStateButton->setObjectName("clearFolderTreeSyncStateButton");

        clearSyncStateBtnContainerLayout->addWidget(clearFolderTreeSyncStateButton);

        clearFolderItemSyncStateButton = new QPushButton(clearSyncStateBtnContainer);
        clearFolderItemSyncStateButton->setObjectName("clearFolderItemSyncStateButton");

        clearSyncStateBtnContainerLayout->addWidget(clearFolderItemSyncStateButton);


        verticalLayout->addWidget(clearSyncStateBtnContainer);


        advancedTabLayout->addWidget(clearSyncStateGroupBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        advancedTabLayout->addItem(verticalSpacer);

        tabWidget->addTab(advancedTab, QString());
        statusTab = new QWidget();
        statusTab->setObjectName("statusTab");
        statusTabLayout = new QVBoxLayout(statusTab);
        statusTabLayout->setObjectName("statusTabLayout");
        serverStatusGroupBox = new QGroupBox(statusTab);
        serverStatusGroupBox->setObjectName("serverStatusGroupBox");
        serverStatusGroupBoxLayout = new QFormLayout(serverStatusGroupBox);
        serverStatusGroupBoxLayout->setObjectName("serverStatusGroupBoxLayout");
        serverStatusLabel = new QLabel(serverStatusGroupBox);
        serverStatusLabel->setObjectName("serverStatusLabel");

        serverStatusGroupBoxLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, serverStatusLabel);

        serverStatusText = new QLabel(serverStatusGroupBox);
        serverStatusText->setObjectName("serverStatusText");
        serverStatusText->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        serverStatusGroupBoxLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, serverStatusText);

        serverVersionLabel = new QLabel(serverStatusGroupBox);
        serverVersionLabel->setObjectName("serverVersionLabel");

        serverStatusGroupBoxLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, serverVersionLabel);

        serverVersionText = new QLabel(serverStatusGroupBox);
        serverVersionText->setObjectName("serverVersionText");

        serverStatusGroupBoxLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, serverVersionText);


        statusTabLayout->addWidget(serverStatusGroupBox);

        statusTabSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        statusTabLayout->addItem(statusTabSpacer);

        tabWidget->addTab(statusTab, QString());
        aboutTab = new QWidget();
        aboutTab->setObjectName("aboutTab");
        aboutTabLayout = new QHBoxLayout(aboutTab);
        aboutTabLayout->setObjectName("aboutTabLayout");
        aboutIconWidget = new QWidget(aboutTab);
        aboutIconWidget->setObjectName("aboutIconWidget");
        aboutIconWidgetLayout = new QVBoxLayout(aboutIconWidget);
        aboutIconWidgetLayout->setObjectName("aboutIconWidgetLayout");
        aboutIconWidgetLayout->setContentsMargins(0, 0, 0, 0);
        aboutIconLabel = new QLabel(aboutIconWidget);
        aboutIconLabel->setObjectName("aboutIconLabel");
        aboutIconLabel->setPixmap(QPixmap(QString::fromUtf8("../../../../../usr/share/icons/hicolor/128x128/apps/akonadi-ews.png")));

        aboutIconWidgetLayout->addWidget(aboutIconLabel);

        aboutIconSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        aboutIconWidgetLayout->addItem(aboutIconSpacer);


        aboutTabLayout->addWidget(aboutIconWidget);

        aboutTextWidget = new QWidget(aboutTab);
        aboutTextWidget->setObjectName("aboutTextWidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(aboutTextWidget->sizePolicy().hasHeightForWidth());
        aboutTextWidget->setSizePolicy(sizePolicy1);
        aboutTextWidgetLayout = new QVBoxLayout(aboutTextWidget);
        aboutTextWidgetLayout->setObjectName("aboutTextWidgetLayout");
        aboutTextLabel = new QLabel(aboutTextWidget);
        aboutTextLabel->setObjectName("aboutTextLabel");
        aboutTextLabel->setWordWrap(true);

        aboutTextWidgetLayout->addWidget(aboutTextLabel);

        aboutVersionLabel = new QLabel(aboutTextWidget);
        aboutVersionLabel->setObjectName("aboutVersionLabel");

        aboutTextWidgetLayout->addWidget(aboutVersionLabel);

        aboutCopyrightLabel = new QLabel(aboutTextWidget);
        aboutCopyrightLabel->setObjectName("aboutCopyrightLabel");

        aboutTextWidgetLayout->addWidget(aboutCopyrightLabel);

        aboutLicenseLabel = new QLabel(aboutTextWidget);
        aboutLicenseLabel->setObjectName("aboutLicenseLabel");
        aboutLicenseLabel->setWordWrap(true);

        aboutTextWidgetLayout->addWidget(aboutLicenseLabel);

        aboutUrlLabel = new QLabel(aboutTextWidget);
        aboutUrlLabel->setObjectName("aboutUrlLabel");
        aboutUrlLabel->setOpenExternalLinks(true);

        aboutTextWidgetLayout->addWidget(aboutUrlLabel);

        aboutTextSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        aboutTextWidgetLayout->addItem(aboutTextSpacer);


        aboutTabLayout->addWidget(aboutTextWidget);

        tabWidget->addTab(aboutTab, QString());

        mainLayout->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, accountName);
        QWidget::setTabOrder(accountName, kcfg_Email);
        QWidget::setTabOrder(kcfg_Email, authUsernameRadioButton);
        QWidget::setTabOrder(authUsernameRadioButton, kcfg_HasDomain);
        QWidget::setTabOrder(kcfg_HasDomain, kcfg_Domain);
        QWidget::setTabOrder(kcfg_Domain, kcfg_Username);
        QWidget::setTabOrder(kcfg_Username, passwordEdit);
        QWidget::setTabOrder(passwordEdit, authOAuth2RadioButton);
        QWidget::setTabOrder(authOAuth2RadioButton, kcfg_AutoDiscovery);
        QWidget::setTabOrder(kcfg_AutoDiscovery, autodiscoverButton);
        QWidget::setTabOrder(autodiscoverButton, tryConnectButton);
        QWidget::setTabOrder(tryConnectButton, kcfg_BaseUrl);
        QWidget::setTabOrder(kcfg_BaseUrl, pkeyAuthCert);
        QWidget::setTabOrder(pkeyAuthCert, pkeyAuthKey);
        QWidget::setTabOrder(pkeyAuthKey, pkeyAuthPassword);
        QWidget::setTabOrder(pkeyAuthPassword, pollRadioButton);
        QWidget::setTabOrder(pollRadioButton, kcfg_PollInterval);
        QWidget::setTabOrder(kcfg_PollInterval, streamingRadioButton);
        QWidget::setTabOrder(streamingRadioButton, kcfg_EnableNTLMv2);
        QWidget::setTabOrder(kcfg_EnableNTLMv2, userAgentGroupBox);
        QWidget::setTabOrder(userAgentGroupBox, userAgentCombo);
        QWidget::setTabOrder(userAgentCombo, userAgentEdit);
        QWidget::setTabOrder(userAgentEdit, clearFolderTreeSyncStateButton);
        QWidget::setTabOrder(clearFolderTreeSyncStateButton, clearFolderItemSyncStateButton);

        retranslateUi(SetupServerView);
        QObject::connect(kcfg_AutoDiscovery, &QCheckBox::toggled, autodiscoverButton, &QPushButton::setEnabled);
        QObject::connect(kcfg_AutoDiscovery, &QCheckBox::toggled, serverUrlLabel, &QLabel::setDisabled);
        QObject::connect(kcfg_AutoDiscovery, &QCheckBox::toggled, kcfg_BaseUrl, &QLineEdit::setDisabled);
        QObject::connect(pollRadioButton, &QRadioButton::toggled, pollIntervalWidget, &QWidget::setEnabled);
        QObject::connect(kcfg_HasDomain, &QCheckBox::toggled, kcfg_Domain, &QLineEdit::setEnabled);
        QObject::connect(authUsernameRadioButton, &QRadioButton::toggled, authUsernameContainer, &QWidget::setEnabled);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(SetupServerView);
    } // setupUi

    void retranslateUi(QWidget *SetupServerView)
    {
        SetupServerView->setWindowTitle(tr2i18n("EWS Configuration", nullptr));
        accountInfoGroupBox->setTitle(tr2i18n("Account Information", nullptr));
        accountNameLabel->setText(tr2i18n("Account Name:", nullptr));
#if QT_CONFIG(whatsthis)
        accountName->setWhatsThis(tr2i18n("This is the account name that will appear in all Akonadi applications", nullptr));
#endif // QT_CONFIG(whatsthis)
        emailLabel->setText(tr2i18n("Email:", "Exchange account e-mail address"));
#if QT_CONFIG(whatsthis)
        kcfg_Email->setWhatsThis(tr2i18n("The e-mail address of this account", nullptr));
#endif // QT_CONFIG(whatsthis)
        authenticationGroupBox->setTitle(tr2i18n("Authentication", nullptr));
#if QT_CONFIG(whatsthis)
        authUsernameRadioButton->setWhatsThis(tr2i18n("<html><head/><body><p>Enables traditional username/password authentication against the Exchange server. This includes methods like Basic, NTLM or Kerberos.</p><p>This authentication method is considered to be somewhat legacy and is mostly used for smaller on-premise Exchange installations and hosted Office 365 instances, where the administrator has chosen to enable it.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        authUsernameRadioButton->setText(tr2i18n("&Username/Password", "authentication type"));
#if QT_CONFIG(whatsthis)
        kcfg_HasDomain->setWhatsThis(tr2i18n("<html><head/><body><p>Allows to specify an Active Directory domain for the user.</p><p><span style=\" font-weight:600;\">Note:</span> There is a subtle difference between &quot;empty domain&quot; and &quot;no-domain&quot;.</p><p>With an empty domain (Domain checkbox checked, empty domain in edit box) the EWS resource will pass the user with an explicitly empty domain (&quot;\\username&quot;).</p><p>With no domain set (Domain checkbox cleared) the username will be passed without the domain (&quot;username&quot;), which will cause the server to set the domain to the default one its configured with.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_HasDomain->setText(tr2i18n("Domain:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_Domain->setWhatsThis(tr2i18n("The Active Directory domain the user belongs to.", nullptr));
#endif // QT_CONFIG(whatsthis)
        usernameLabel->setText(tr2i18n("Username:", "Exchange account username/login"));
        passwordLabel->setText(tr2i18n("Password:", nullptr));
#if QT_CONFIG(whatsthis)
        passwordEdit->setWhatsThis(tr2i18n("<html><head/><body><p>The password used to login to the Exchange server.</p><p><span style=\" font-weight:600;\">Note:</span> This can be left empty when using Kerberos authentication.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        kcfg_Username->setWhatsThis(tr2i18n("<html><head/><body><p>The username used to login to the Exchange server.</p><p><span style=\" font-weight:600;\">Note:</span> This can be left empty when using Kerberos authentication.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        kerberosNoteLabel->setText(tr2i18n("<html><head/><body><p><span style=\" font-weight:600;\">Note:</span> Username and password are not needed (can be empty) when Kerberos is properly configured on your system.</p></body></html>", nullptr));
#if QT_CONFIG(whatsthis)
        authOAuth2RadioButton->setWhatsThis(tr2i18n("<html><head/><body><p>Enables more modern and stronger authentication based on OAuth2.</p><p>This type of authentication will open an organization-supplied webpage, where the user will be able to enter authentication information, which may also include multifactor authentication in form of one-time-passwords generated by tokens.</p><p>This method is mostly used for hosted Office 365 instances.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        authOAuth2RadioButton->setText(tr2i18n("OAuth&2 (Office 365)", nullptr));
#if QT_CONFIG(whatsthis)
        authInTuneRadioButton->setWhatsThis(tr2i18n("<html><head/><body><p>Enables authentication using Microsoft InTune MDM software. This is required in many corporate environments, which mandate strong authentication using device credentials and thereby require the system to be joined to the organization and managed using InTune.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        authInTuneRadioButton->setText(tr2i18n("&Microsoft InTune", nullptr));
        ewsSettingsGroupBox->setTitle(tr2i18n("EWS Settings", nullptr));
        serverUrlLabel->setText(tr2i18n("EWS URL:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_BaseUrl->setWhatsThis(tr2i18n("The Microsoft Exchange server URL used to send EWS requests.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        kcfg_AutoDiscovery->setWhatsThis(tr2i18n("<html><head/><body><p>Attempts to find out the Microsoft Exchange server address relevant to the supplied e-mail address.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_AutoDiscovery->setText(tr2i18n("Server Autodiscovery", nullptr));
        autodiscoverButton->setText(tr2i18n("Perform", nullptr));
        tryConnectButton->setText(tr2i18n("Try connect", nullptr));
#if QT_CONFIG(whatsthis)
        pkeyAuthGroupBox->setWhatsThis(tr2i18n("<html><head/><body><p>Private Key (PKey) Authentication is used as an additional authentication step to OAuth2-based authentication. It uses an X.509 certificate and private key that identifies a trusted device, which was joined to the Azure Directory using a Workplace Join.</p><p>Some administrators may mandate use of PKey authentication when connecting to Office 365 from outside of corporate network. In other cases, when multi-factor authentication is set-up, using the PKey authentication can satisfy requirements for strong authentication, in which case entering the MFA code is not required.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        pkeyAuthGroupBox->setTitle(tr2i18n("Private Key (PKey) Authentication (Office 365)", nullptr));
        pkeyAuthCertLabel->setText(tr2i18n("Certificate:", nullptr));
        pkeyAuthKeyLabel->setText(tr2i18n("Private key:", nullptr));
        pkeyAuthPasswordLabel->setText(tr2i18n("Key password:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(generalTab), tr2i18n("General", "General settings tab"));
        tabWidget->setTabText(tabWidget->indexOf(subscriptionTab), tr2i18n("Subscriptions", nullptr));
        retrievalMethodGroupBox->setTitle(tr2i18n("Retrieval", nullptr));
#if QT_CONFIG(whatsthis)
        pollRadioButton->setWhatsThis(tr2i18n("<html><head/><body><p>Periodically asks for new item change events.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        pollRadioButton->setText(tr2i18n("Po&ll for new messages", nullptr));
        kcfg_PollInterval->setSuffix(tr2i18n(" minutes", nullptr));
        pollIntervalLabel->setText(tr2i18n("Interval", nullptr));
#if QT_CONFIG(whatsthis)
        streamingRadioButton->setWhatsThis(tr2i18n("<html><head/><body><p>Streaming notifications behave similarly to push mode - a connection is kept alive and notifications about item changes are delivered instantly.</p><p><br/></p><p>This option requires Exchange server version 2010 SP1 or later.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        streamingRadioButton->setText(tr2i18n("&Use streaming notifications", nullptr));
        advAuthenticationGroupBox->setTitle(tr2i18n("Authentication", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_EnableNTLMv2->setWhatsThis(tr2i18n("<html><head/><body><p>By default KDE uses the less secure NTLMv1 authentication. Enabling this will cause the more secure NTLMv2 protocol to be used.</p><p>Some newer Microsoft Exchange servers are configured to only allow NTLMv2 authentication. In such case this option must be enabled in order to connect successfully.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_EnableNTLMv2->setText(tr2i18n("Enable NTLMv2", nullptr));
#if QT_CONFIG(whatsthis)
        userAgentGroupBox->setWhatsThis(tr2i18n("<html><head/><body><p>Some organizations restrict access to mail only to approved clients, such as Microsoft Outlook. On the server-side this is implemented by analyzing the User-Agent string and only allowing a list of approved clients.</p><p>This setting allows to emulate some well known clients as well as providing a custom User-Agent string.</p><p>Please be advised that bypassing company policies may result in personal consequences.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        userAgentGroupBox->setTitle(tr2i18n("Use custo&m User Agent", nullptr));
        clearSyncStateGroupBox->setTitle(tr2i18n("Clear Synchronization State", nullptr));
        clearSyncStateLabel->setText(tr2i18n("Resets synchronization state between Exchange and Akonadi. Use in case some items or folders are not showing up despite existing in Exchange.", nullptr));
        clearFolderTreeSyncStateButton->setText(tr2i18n("Clear Folder Tree State", nullptr));
        clearFolderItemSyncStateButton->setText(tr2i18n("Clear Folder Item State", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(advancedTab), tr2i18n("Advanced", "Advanced settings tab"));
        serverStatusGroupBox->setTitle(tr2i18n("Server Status", nullptr));
        serverStatusLabel->setText(tr2i18n("Status:", nullptr));
        serverStatusText->setText(tr2i18n("Unknown", "Unknown server status"));
        serverVersionLabel->setText(tr2i18n("Version:", nullptr));
        serverVersionText->setText(tr2i18n("Unknown", "Unknown server version"));
        tabWidget->setTabText(tabWidget->indexOf(statusTab), tr2i18n("Status", nullptr));
        aboutLicenseLabel->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(aboutTab), tr2i18n("About", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SetupServerView: public Ui_SetupServerView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EWSCONFIGDIALOG_H

