/****************************************************************************
** Meta object code from reading C++ file 'settingsadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "settingsadaptor.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'settingsadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15SettingsAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto SettingsAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN15SettingsAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SettingsAdaptor",
        "D-Bus Interface",
        "org.kde.Akonadi.POP3.Settings",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Akonadi.POP3.Settings\">\n    <method "
        "name=\"save\"/>\n    <method name=\"name\">\n      <arg direction="
        "\"out\" type=\"s\"/>\n    </method>\n    <method name=\"setName\">"
        "\n      <arg direction=\"in\" type=\"s\"/>\n    </method>\n    <me"
        "thod name=\"unitTestPassword\">\n      <arg direction=\"out\" type"
        "=\"s\"/>\n    </method>\n    <method name=\"setUnitTestPassword\">"
        "\n      <arg direction=\"in\" type=\"s\"/>\n    </method>\n    <me"
        "thod name=\"login\">\n      <arg direction=\"out\" type=\"s\"/>\n "
        "   </method>\n    <method name=\"setLogin\">\n      <arg direction"
        "=\"in\" type=\"s\"/>\n    </method>\n    <method name=\"host\">\n "
        "     <arg direction=\"out\" type=\"s\"/>\n    </method>\n    <meth"
        "od name=\"setHost\">\n      <arg direction=\"in\" type=\"s\"/>\n  "
        "  </method>\n    <method name=\"port\">\n      <arg direction=\"ou"
        "t\" type=\"u\"/>\n    </method>\n    <method name=\"setPort\">\n  "
        "    <arg direction=\"in\" type=\"u\"/>\n    </method>\n    <method"
        " name=\"authenticationMethod\">\n      <arg direction=\"out\" type"
        "=\"i\"/>\n    </method>\n    <method name=\"setAuthenticationMetho"
        "d\">\n      <arg direction=\"in\" type=\"i\"/>\n    </method>\n   "
        " <method name=\"useSSL\">\n      <arg direction=\"out\" type=\"b\""
        "/>\n    </method>\n    <method name=\"setUseSSL\">\n      <arg dir"
        "ection=\"in\" type=\"b\"/>\n    </method>\n    <method name=\"useT"
        "LS\">\n      <arg direction=\"out\" type=\"b\"/>\n    </method>\n "
        "   <method name=\"setUseTLS\">\n      <arg direction=\"in\" type=\""
        "b\"/>\n    </method>\n    <method name=\"pipelining\">\n      <arg"
        " direction=\"out\" type=\"b\"/>\n    </method>\n    <method name=\""
        "setPipelining\">\n      <arg direction=\"in\" type=\"b\"/>\n    </"
        "method>\n    <method name=\"useProxy\">\n      <arg direction=\"ou"
        "t\" type=\"b\"/>\n    </method>\n    <method name=\"setUseProxy\">"
        "\n      <arg direction=\"in\" type=\"b\"/>\n    </method>\n    <me"
        "thod name=\"leaveOnServer\">\n      <arg direction=\"out\" type=\""
        "b\"/>\n    </method>\n    <method name=\"setLeaveOnServer\">\n    "
        "  <arg direction=\"in\" type=\"b\"/>\n    </method>\n    <method n"
        "ame=\"leaveOnServerDays\">\n      <arg direction=\"out\" type=\"i\""
        "/>\n    </method>\n    <method name=\"setLeaveOnServerDays\">\n   "
        "   <arg direction=\"in\" type=\"i\"/>\n    </method>\n    <method "
        "name=\"leaveOnServerCount\">\n      <arg direction=\"out\" type=\""
        "i\"/>\n    </method>\n    <method name=\"setLeaveOnServerCount\">\n"
        "      <arg direction=\"in\" type=\"i\"/>\n    </method>\n    <meth"
        "od name=\"leaveOnServerSize\">\n      <arg direction=\"out\" type="
        "\"i\"/>\n    </method>\n    <method name=\"setLeaveOnServerSize\">"
        "\n      <arg direction=\"in\" type=\"i\"/>\n    </method>\n    <me"
        "thod name=\"filterOnServer\">\n      <arg direction=\"out\" type=\""
        "b\"/>\n    </method>\n    <method name=\"setFilterOnServer\">\n   "
        "   <arg direction=\"in\" type=\"b\"/>\n    </method>\n    <method "
        "name=\"filterCheckSize\">\n      <arg direction=\"out\" type=\"u\""
        "/>\n    </method>\n    <method name=\"setFilterCheckSize\">\n     "
        " <arg direction=\"in\" type=\"u\"/>\n    </method>\n    <method na"
        "me=\"targetCollection\">\n      <arg direction=\"out\" type=\"x\"/"
        ">\n    </method>\n    <method name=\"setTargetCollection\">\n     "
        " <arg direction=\"in\" type=\"x\"/>\n    </method>\n    <method na"
        "me=\"precommand\">\n      <arg direction=\"out\" type=\"s\"/>\n   "
        " </method>\n    <method name=\"setPrecommand\">\n      <arg direct"
        "ion=\"in\" type=\"s\"/>\n    </method>\n    <method name=\"interva"
        "lCheckEnabled\">\n      <arg direction=\"out\" type=\"b\"/>\n    <"
        "/method>\n    <method name=\"setIntervalCheckEnabled\">\n      <ar"
        "g direction=\"in\" type=\"b\"/>\n    </method>\n    <method name=\""
        "intervalCheckInterval\">\n      <arg direction=\"out\" type=\"i\"/"
        ">\n    </method>\n    <method name=\"setIntervalCheckInterval\">\n"
        "      <arg direction=\"in\" type=\"i\"/>\n    </method>\n    <meth"
        "od name=\"seenUidList\">\n      <arg direction=\"out\" type=\"as\""
        "/>\n    </method>\n    <method name=\"setSeenUidList\">\n      <ar"
        "g direction=\"in\" type=\"as\"/>\n    </method>\n    <method name="
        "\"seenUidTimeList\">\n      <arg direction=\"out\" type=\"ai\"/>\n"
        "      <annotation value=\"QList&lt;int&gt;\" name=\"org.qtproject."
        "QtDBus.QtTypeName.Out0\"/>\n    </method>\n    <method name=\"setS"
        "eenUidTimeList\">\n      <arg direction=\"in\" type=\"ai\"/>\n    "
        "  <annotation value=\"QList&lt;int&gt;\" name=\"org.qtproject.QtDB"
        "us.QtTypeName.In0\"/>\n    </method>\n    <method name=\"downloadL"
        "ater\">\n      <arg direction=\"out\" type=\"as\"/>\n    </method>"
        "\n    <method name=\"setDownloadLater\">\n      <arg direction=\"i"
        "n\" type=\"as\"/>\n    </method>\n  </interface>\n",
        "authenticationMethod",
        "",
        "downloadLater",
        "filterCheckSize",
        "filterOnServer",
        "host",
        "intervalCheckEnabled",
        "intervalCheckInterval",
        "leaveOnServer",
        "leaveOnServerCount",
        "leaveOnServerDays",
        "leaveOnServerSize",
        "login",
        "name",
        "pipelining",
        "port",
        "precommand",
        "save",
        "seenUidList",
        "seenUidTimeList",
        "QList<int>",
        "setAuthenticationMethod",
        "in0",
        "setDownloadLater",
        "setFilterCheckSize",
        "setFilterOnServer",
        "setHost",
        "setIntervalCheckEnabled",
        "setIntervalCheckInterval",
        "setLeaveOnServer",
        "setLeaveOnServerCount",
        "setLeaveOnServerDays",
        "setLeaveOnServerSize",
        "setLogin",
        "setName",
        "setPipelining",
        "setPort",
        "setPrecommand",
        "setSeenUidList",
        "setSeenUidTimeList",
        "setTargetCollection",
        "setUnitTestPassword",
        "setUseProxy",
        "setUseSSL",
        "setUseTLS",
        "targetCollection",
        "unitTestPassword",
        "useProxy",
        "useSSL",
        "useTLS"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'authenticationMethod'
        QtMocHelpers::SlotData<int()>(5, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'downloadLater'
        QtMocHelpers::SlotData<QStringList()>(7, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'filterCheckSize'
        QtMocHelpers::SlotData<uint()>(8, 6, QMC::AccessPublic, QMetaType::UInt),
        // Slot 'filterOnServer'
        QtMocHelpers::SlotData<bool()>(9, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'host'
        QtMocHelpers::SlotData<QString()>(10, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'intervalCheckEnabled'
        QtMocHelpers::SlotData<bool()>(11, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'intervalCheckInterval'
        QtMocHelpers::SlotData<int()>(12, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'leaveOnServer'
        QtMocHelpers::SlotData<bool()>(13, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'leaveOnServerCount'
        QtMocHelpers::SlotData<int()>(14, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'leaveOnServerDays'
        QtMocHelpers::SlotData<int()>(15, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'leaveOnServerSize'
        QtMocHelpers::SlotData<int()>(16, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'login'
        QtMocHelpers::SlotData<QString()>(17, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'name'
        QtMocHelpers::SlotData<QString()>(18, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'pipelining'
        QtMocHelpers::SlotData<bool()>(19, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'port'
        QtMocHelpers::SlotData<uint()>(20, 6, QMC::AccessPublic, QMetaType::UInt),
        // Slot 'precommand'
        QtMocHelpers::SlotData<QString()>(21, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'seenUidList'
        QtMocHelpers::SlotData<QStringList()>(23, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'seenUidTimeList'
        QtMocHelpers::SlotData<QList<int>()>(24, 6, QMC::AccessPublic, 0x80000000 | 25),
        // Slot 'setAuthenticationMethod'
        QtMocHelpers::SlotData<void(int)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'setDownloadLater'
        QtMocHelpers::SlotData<void(const QStringList &)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 27 },
        }}),
        // Slot 'setFilterCheckSize'
        QtMocHelpers::SlotData<void(uint)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 27 },
        }}),
        // Slot 'setFilterOnServer'
        QtMocHelpers::SlotData<void(bool)>(30, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'setHost'
        QtMocHelpers::SlotData<void(const QString &)>(31, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'setIntervalCheckEnabled'
        QtMocHelpers::SlotData<void(bool)>(32, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'setIntervalCheckInterval'
        QtMocHelpers::SlotData<void(int)>(33, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'setLeaveOnServer'
        QtMocHelpers::SlotData<void(bool)>(34, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'setLeaveOnServerCount'
        QtMocHelpers::SlotData<void(int)>(35, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'setLeaveOnServerDays'
        QtMocHelpers::SlotData<void(int)>(36, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'setLeaveOnServerSize'
        QtMocHelpers::SlotData<void(int)>(37, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'setLogin'
        QtMocHelpers::SlotData<void(const QString &)>(38, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'setName'
        QtMocHelpers::SlotData<void(const QString &)>(39, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'setPipelining'
        QtMocHelpers::SlotData<void(bool)>(40, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'setPort'
        QtMocHelpers::SlotData<void(uint)>(41, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 27 },
        }}),
        // Slot 'setPrecommand'
        QtMocHelpers::SlotData<void(const QString &)>(42, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'setSeenUidList'
        QtMocHelpers::SlotData<void(const QStringList &)>(43, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 27 },
        }}),
        // Slot 'setSeenUidTimeList'
        QtMocHelpers::SlotData<void(const QList<int> &)>(44, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 27 },
        }}),
        // Slot 'setTargetCollection'
        QtMocHelpers::SlotData<void(qlonglong)>(45, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 27 },
        }}),
        // Slot 'setUnitTestPassword'
        QtMocHelpers::SlotData<void(const QString &)>(46, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'setUseProxy'
        QtMocHelpers::SlotData<void(bool)>(47, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'setUseSSL'
        QtMocHelpers::SlotData<void(bool)>(48, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'setUseTLS'
        QtMocHelpers::SlotData<void(bool)>(49, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'targetCollection'
        QtMocHelpers::SlotData<qlonglong()>(50, 6, QMC::AccessPublic, QMetaType::LongLong),
        // Slot 'unitTestPassword'
        QtMocHelpers::SlotData<QString()>(51, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'useProxy'
        QtMocHelpers::SlotData<bool()>(52, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'useSSL'
        QtMocHelpers::SlotData<bool()>(53, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'useTLS'
        QtMocHelpers::SlotData<bool()>(54, 6, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<SettingsAdaptor, qt_meta_tag_ZN15SettingsAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SettingsAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.metaTypes,
    nullptr
} };

void SettingsAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SettingsAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { int _r = _t->authenticationMethod();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 1: { QStringList _r = _t->downloadLater();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 2: { uint _r = _t->filterCheckSize();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->filterOnServer();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->host();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->intervalCheckEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->intervalCheckInterval();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->leaveOnServer();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { int _r = _t->leaveOnServerCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: { int _r = _t->leaveOnServerDays();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: { int _r = _t->leaveOnServerSize();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->login();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->name();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->pipelining();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { uint _r = _t->port();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 15: { QString _r = _t->precommand();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->save(); break;
        case 17: { QStringList _r = _t->seenUidList();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 18: { QList<int> _r = _t->seenUidTimeList();
            if (_a[0]) *reinterpret_cast<QList<int>*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->setAuthenticationMethod((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->setDownloadLater((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 21: _t->setFilterCheckSize((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 22: _t->setFilterOnServer((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->setHost((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->setIntervalCheckEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->setIntervalCheckInterval((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->setLeaveOnServer((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->setLeaveOnServerCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->setLeaveOnServerDays((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->setLeaveOnServerSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: _t->setLogin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->setName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: _t->setPipelining((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->setPort((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 34: _t->setPrecommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 35: _t->setSeenUidList((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 36: _t->setSeenUidTimeList((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1]))); break;
        case 37: _t->setTargetCollection((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 38: _t->setUnitTestPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 39: _t->setUseProxy((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 40: _t->setUseSSL((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->setUseTLS((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 42: { qlonglong _r = _t->targetCollection();
            if (_a[0]) *reinterpret_cast<qlonglong*>(_a[0]) = std::move(_r); }  break;
        case 43: { QString _r = _t->unitTestPassword();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 44: { bool _r = _t->useProxy();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 45: { bool _r = _t->useSSL();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 46: { bool _r = _t->useTLS();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
}

const QMetaObject *SettingsAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SettingsAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int SettingsAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 47)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 47;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 47)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 47;
    }
    return _id;
}
QT_WARNING_POP
