// This file is generated by kconfig_compiler_kf6 from ewsmtaresource.kcfg.
// All changes you do to this file will be lost.
#ifndef EWSMTASETTINGS_H
#define EWSMTASETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class EwsMtaSettings : public KConfigSkeleton
{
  public:

    static EwsMtaSettings *self();
    ~EwsMtaSettings() override;

    /**
      Set Ews Resource
    */
    static
    void setEwsResource( const QString & v )
    {
      if (!self()->isEwsResourceImmutable())
        self()->mEwsResource = v;
    }

    /**
      Get Ews Resource
    */
    static
    QString ewsResource()
    {
      return self()->mEwsResource;
    }

    /**
      Is Ews Resource Immutable
    */
    static
    bool isEwsResourceImmutable()
    {
      return self()->isImmutable( QStringLiteral( "EwsResource" ) );
    }

    /**
      Get Item object corresponding to EwsResource()
    */
    ItemString *ewsResourceItem()
    {
      return mEwsResourceItem;
    }

  protected:
    EwsMtaSettings();
    friend class EwsMtaSettingsHelper;


    // General
    QString mEwsResource;

  private:
    ItemString *mEwsResourceItem;
};

#endif

