/****************************************************************************
** Meta object code from reading C++ file 'peopleconversionjob.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdepim-runtime-26.04.2/resources/google-groupware/peopleconversionjob.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'peopleconversionjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19PeopleConversionJobE_t {};
} // unnamed namespace

template <> constexpr inline auto PeopleConversionJob::qt_create_metaobjectdata<qt_meta_tag_ZN19PeopleConversionJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PeopleConversionJob",
        "finished",
        "",
        "peopleChanged",
        "reparentCollectionRemoteIdChanged",
        "newLinkedCollectionRemoteIdChanged",
        "linkedCollectionToRemoveRemoteIdChanged",
        "start",
        "setReparentCollectionRemoteId",
        "reparentCollectionRemoteId",
        "setNewLinkedCollectionRemoteId",
        "newLinkedCollectionRemoteId",
        "setLinkedCollectionToRemoveRemoteId",
        "linkedCollectionToRemoveRemoteId",
        "jobFinished",
        "KJob*",
        "job",
        "processItems",
        "people",
        "KGAPI2::People::PersonList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'peopleChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reparentCollectionRemoteIdChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newLinkedCollectionRemoteIdChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'linkedCollectionToRemoveRemoteIdChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setReparentCollectionRemoteId'
        QtMocHelpers::SlotData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'setNewLinkedCollectionRemoteId'
        QtMocHelpers::SlotData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'setLinkedCollectionToRemoveRemoteId'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'jobFinished'
        QtMocHelpers::SlotData<void(KJob *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'processItems'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'people'
        QtMocHelpers::PropertyData<KGAPI2::People::PersonList>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'reparentCollectionRemoteId'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'newLinkedCollectionRemoteId'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'linkedCollectionToRemoveRemoteId'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PeopleConversionJob, qt_meta_tag_ZN19PeopleConversionJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PeopleConversionJob::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19PeopleConversionJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19PeopleConversionJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19PeopleConversionJobE_t>.metaTypes,
    nullptr
} };

void PeopleConversionJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PeopleConversionJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished(); break;
        case 1: _t->peopleChanged(); break;
        case 2: _t->reparentCollectionRemoteIdChanged(); break;
        case 3: _t->newLinkedCollectionRemoteIdChanged(); break;
        case 4: _t->linkedCollectionToRemoveRemoteIdChanged(); break;
        case 5: _t->start(); break;
        case 6: _t->setReparentCollectionRemoteId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->setNewLinkedCollectionRemoteId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->setLinkedCollectionToRemoveRemoteId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->jobFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 10: _t->processItems(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PeopleConversionJob::*)()>(_a, &PeopleConversionJob::finished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PeopleConversionJob::*)()>(_a, &PeopleConversionJob::peopleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PeopleConversionJob::*)()>(_a, &PeopleConversionJob::reparentCollectionRemoteIdChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PeopleConversionJob::*)()>(_a, &PeopleConversionJob::newLinkedCollectionRemoteIdChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PeopleConversionJob::*)()>(_a, &PeopleConversionJob::linkedCollectionToRemoveRemoteIdChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KGAPI2::People::PersonList*>(_v) = _t->people(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->reparentCollectionRemoteId(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->newLinkedCollectionRemoteId(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->linkedCollectionToRemoveRemoteId(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setReparentCollectionRemoteId(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setNewLinkedCollectionRemoteId(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setLinkedCollectionToRemoveRemoteId(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PeopleConversionJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PeopleConversionJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19PeopleConversionJobE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PeopleConversionJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void PeopleConversionJob::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PeopleConversionJob::peopleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PeopleConversionJob::reparentCollectionRemoteIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PeopleConversionJob::newLinkedCollectionRemoteIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PeopleConversionJob::linkedCollectionToRemoveRemoteIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
