// This file is generated by kconfig_compiler_kf6 from settingsbase.kcfg.
// All changes you do to this file will be lost.

#include "settingsbase.h"

SettingsBase::SettingsBase( KSharedConfig::Ptr config )
  : KConfigSkeleton( std::move( config ) )
{
  setCurrentGroup( QStringLiteral( "General" ) );

  mAccountItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Account" ), mAccount );
  addItem( mAccountItem, QStringLiteral( "Account" ) );
  mAccountNameItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AccountName" ), mAccountName );
  addItem( mAccountNameItem, QStringLiteral( "AccountName" ) );
  mAccountIdItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "AccountId" ), mAccountId, 0 );
  addItem( mAccountIdItem, QStringLiteral( "AccountId" ) );
  mCalendarsItem = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "Calendars" ), mCalendars );
  addItem( mCalendarsItem, QStringLiteral( "Calendars" ) );
  mTaskListsItem = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "TaskLists" ), mTaskLists );
  addItem( mTaskListsItem, QStringLiteral( "TaskLists" ) );
  mEventsSinceItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "EventsSince" ), mEventsSince );
  addItem( mEventsSinceItem, QStringLiteral( "EventsSince" ) );
  mEnableIntervalCheckItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EnableIntervalCheck" ), mEnableIntervalCheck, false );
  addItem( mEnableIntervalCheckItem, QStringLiteral( "EnableIntervalCheck" ) );
  mIntervalCheckTimeItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "IntervalCheckTime" ), mIntervalCheckTime, 60 );
  addItem( mIntervalCheckTimeItem, QStringLiteral( "IntervalCheckTime" ) );
}

SettingsBase::~SettingsBase()
{
}

