/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.Ews.Resource.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "ewsresourceadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class EwsResourceAdaptor
 */

EwsResourceAdaptor::EwsResourceAdaptor(EwsResource *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

EwsResourceAdaptor::~EwsResourceAdaptor()
{
    // destructor
}

void EwsResourceAdaptor::clearCollectionSyncState(int collectionId)
{
    // handle method call org.kde.Akonadi.Ews.Resource.clearCollectionSyncState
    parent()->clearCollectionSyncState(collectionId);
}

void EwsResourceAdaptor::clearFolderTreeSyncState()
{
    // handle method call org.kde.Akonadi.Ews.Resource.clearFolderTreeSyncState
    parent()->clearFolderTreeSyncState();
}

void EwsResourceAdaptor::sendMessage(const QString &id, const QByteArray &content)
{
    // handle method call org.kde.Akonadi.Ews.Resource.sendMessage
    parent()->sendMessage(id, content);
}

void EwsResourceAdaptor::setInitialReconnectTimeout(int timeout)
{
    // handle method call org.kde.Akonadi.Ews.Resource.setInitialReconnectTimeout
    parent()->setInitialReconnectTimeout(timeout);
}


#include "moc_ewsresourceadaptor.cpp"
