/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.ICal.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "icalsettingsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ICalSettingsAdaptor
 */

ICalSettingsAdaptor::ICalSettingsAdaptor(Akonadi_ICal_Resource::Settings *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ICalSettingsAdaptor::~ICalSettingsAdaptor()
{
    // destructor
}

QString ICalSettingsAdaptor::displayName()
{
    // handle method call org.kde.Akonadi.ICal.Settings.displayName
    return parent()->displayName();
}

bool ICalSettingsAdaptor::monitorFile()
{
    // handle method call org.kde.Akonadi.ICal.Settings.monitorFile
    return parent()->monitorFile();
}

QString ICalSettingsAdaptor::path()
{
    // handle method call org.kde.Akonadi.ICal.Settings.path
    return parent()->path();
}

bool ICalSettingsAdaptor::periodicUpdate()
{
    // handle method call org.kde.Akonadi.ICal.Settings.periodicUpdate
    return parent()->periodicUpdate();
}

bool ICalSettingsAdaptor::readOnly()
{
    // handle method call org.kde.Akonadi.ICal.Settings.readOnly
    return parent()->readOnly();
}

void ICalSettingsAdaptor::save()
{
    // handle method call org.kde.Akonadi.ICal.Settings.save
    parent()->save();
}

void ICalSettingsAdaptor::setDisplayName(const QString &in0)
{
    // handle method call org.kde.Akonadi.ICal.Settings.setDisplayName
    parent()->setDisplayName(in0);
}

void ICalSettingsAdaptor::setMonitorFile(bool in0)
{
    // handle method call org.kde.Akonadi.ICal.Settings.setMonitorFile
    parent()->setMonitorFile(in0);
}

void ICalSettingsAdaptor::setPath(const QString &in0)
{
    // handle method call org.kde.Akonadi.ICal.Settings.setPath
    parent()->setPath(in0);
}

void ICalSettingsAdaptor::setPeriodicUpdate(bool in0)
{
    // handle method call org.kde.Akonadi.ICal.Settings.setPeriodicUpdate
    parent()->setPeriodicUpdate(in0);
}

void ICalSettingsAdaptor::setReadOnly(bool in0)
{
    // handle method call org.kde.Akonadi.ICal.Settings.setReadOnly
    parent()->setReadOnly(in0);
}

void ICalSettingsAdaptor::setUpdatePeriod(int in0)
{
    // handle method call org.kde.Akonadi.ICal.Settings.setUpdatePeriod
    parent()->setUpdatePeriod(in0);
}

int ICalSettingsAdaptor::updatePeriod()
{
    // handle method call org.kde.Akonadi.ICal.Settings.updatePeriod
    return parent()->updatePeriod();
}


#include "moc_icalsettingsadaptor.cpp"
