/****************************************************************************
** Meta object code from reading C++ file 'birthdaysconfigagentwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdepim-runtime-26.04.2/resources/birthdays/birthdaysconfigagentwidget.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'birthdaysconfigagentwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN26BirthdaysConfigAgentWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto BirthdaysConfigAgentWidget::qt_create_metaobjectdata<qt_meta_tag_ZN26BirthdaysConfigAgentWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BirthdaysConfigAgentWidget"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BirthdaysConfigAgentWidget, qt_meta_tag_ZN26BirthdaysConfigAgentWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BirthdaysConfigAgentWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<Akonadi::AgentConfigurationBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26BirthdaysConfigAgentWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26BirthdaysConfigAgentWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26BirthdaysConfigAgentWidgetE_t>.metaTypes,
    nullptr
} };

void BirthdaysConfigAgentWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BirthdaysConfigAgentWidget *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *BirthdaysConfigAgentWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BirthdaysConfigAgentWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26BirthdaysConfigAgentWidgetE_t>.strings))
        return static_cast<void*>(this);
    return Akonadi::AgentConfigurationBase::qt_metacast(_clname);
}

int BirthdaysConfigAgentWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Akonadi::AgentConfigurationBase::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN33BirthdaysConfigAgentWidgetFactoryE_t {};
} // unnamed namespace

template <> constexpr inline auto BirthdaysConfigAgentWidgetFactory::qt_create_metaobjectdata<qt_meta_tag_ZN33BirthdaysConfigAgentWidgetFactoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BirthdaysConfigAgentWidgetFactory"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BirthdaysConfigAgentWidgetFactory, qt_meta_tag_ZN33BirthdaysConfigAgentWidgetFactoryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BirthdaysConfigAgentWidgetFactory::staticMetaObject = { {
    QMetaObject::SuperData::link<Akonadi::AgentConfigurationFactoryBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33BirthdaysConfigAgentWidgetFactoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33BirthdaysConfigAgentWidgetFactoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN33BirthdaysConfigAgentWidgetFactoryE_t>.metaTypes,
    nullptr
} };

void BirthdaysConfigAgentWidgetFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BirthdaysConfigAgentWidgetFactory *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *BirthdaysConfigAgentWidgetFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BirthdaysConfigAgentWidgetFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33BirthdaysConfigAgentWidgetFactoryE_t>.strings))
        return static_cast<void*>(this);
    return Akonadi::AgentConfigurationFactoryBase::qt_metacast(_clname);
}

int BirthdaysConfigAgentWidgetFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Akonadi::AgentConfigurationFactoryBase::qt_metacall(_c, _id, _a);
    return _id;
}

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_BirthdaysConfigAgentWidgetFactory[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x23,  'o',  'r',  'g',  '.',  'f', 
    'r',  'e',  'e',  'd',  'e',  's',  'k',  't', 
    'o',  'p',  '.',  'A',  'k',  'o',  'n',  'a', 
    'd',  'i',  '.',  'A',  'g',  'e',  'n',  't', 
    'C',  'o',  'n',  'f',  'i',  'g', 
    // "className"
    0x03,  0x78,  0x21,  'B',  'i',  'r',  't',  'h', 
    'd',  'a',  'y',  's',  'C',  'o',  'n',  'f', 
    'i',  'g',  'A',  'g',  'e',  'n',  't',  'W', 
    'i',  'd',  'g',  'e',  't',  'F',  'a',  'c', 
    't',  'o',  'r',  'y', 
    // "MetaData"
    0x04,  0xa3,  0x78,  0x1a,  'X',  '-',  'A',  'k', 
    'o',  'n',  'a',  'd',  'i',  '-',  'A',  'g', 
    'e',  'n',  't',  'C',  'o',  'n',  'f',  'i', 
    'g',  '-',  'T',  'y',  'p',  'e',  0x78,  0x1a, 
    'a',  'k',  'o',  'n',  'a',  'd',  'i',  '_', 
    'b',  'i',  'r',  't',  'h',  'd',  'a',  'y', 
    's',  '_',  'r',  'e',  's',  'o',  'u',  'r', 
    'c',  'e',  0x71,  'X',  '-',  'A',  'k',  'o', 
    'n',  'a',  'd',  'i',  '-',  'L',  'i',  'b', 
    'r',  'a',  'r',  'y',  0x6f,  'b',  'i',  'r', 
    't',  'h',  'd',  'a',  'y',  's',  'c',  'o', 
    'n',  'f',  'i',  'g',  0x74,  'X',  '-',  'A', 
    'k',  'o',  'n',  'a',  'd',  'i',  '-',  'P', 
    'l',  'u',  'g',  'i',  'n',  'T',  'y',  'p', 
    'e',  0x6b,  'A',  'g',  'e',  'n',  't',  'C', 
    'o',  'n',  'f',  'i',  'g', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(BirthdaysConfigAgentWidgetFactory, BirthdaysConfigAgentWidgetFactory, qt_pluginMetaDataV2_BirthdaysConfigAgentWidgetFactory)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_BirthdaysConfigAgentWidgetFactory[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x23,  'o',  'r',  'g',  '.',  'f', 
    'r',  'e',  'e',  'd',  'e',  's',  'k',  't', 
    'o',  'p',  '.',  'A',  'k',  'o',  'n',  'a', 
    'd',  'i',  '.',  'A',  'g',  'e',  'n',  't', 
    'C',  'o',  'n',  'f',  'i',  'g', 
    // "className"
    0x03,  0x78,  0x21,  'B',  'i',  'r',  't',  'h', 
    'd',  'a',  'y',  's',  'C',  'o',  'n',  'f', 
    'i',  'g',  'A',  'g',  'e',  'n',  't',  'W', 
    'i',  'd',  'g',  'e',  't',  'F',  'a',  'c', 
    't',  'o',  'r',  'y', 
    // "MetaData"
    0x04,  0xa3,  0x78,  0x1a,  'X',  '-',  'A',  'k', 
    'o',  'n',  'a',  'd',  'i',  '-',  'A',  'g', 
    'e',  'n',  't',  'C',  'o',  'n',  'f',  'i', 
    'g',  '-',  'T',  'y',  'p',  'e',  0x78,  0x1a, 
    'a',  'k',  'o',  'n',  'a',  'd',  'i',  '_', 
    'b',  'i',  'r',  't',  'h',  'd',  'a',  'y', 
    's',  '_',  'r',  'e',  's',  'o',  'u',  'r', 
    'c',  'e',  0x71,  'X',  '-',  'A',  'k',  'o', 
    'n',  'a',  'd',  'i',  '-',  'L',  'i',  'b', 
    'r',  'a',  'r',  'y',  0x6f,  'b',  'i',  'r', 
    't',  'h',  'd',  'a',  'y',  's',  'c',  'o', 
    'n',  'f',  'i',  'g',  0x74,  'X',  '-',  'A', 
    'k',  'o',  'n',  'a',  'd',  'i',  '-',  'P', 
    'l',  'u',  'g',  'i',  'n',  'T',  'y',  'p', 
    'e',  0x6b,  'A',  'g',  'e',  'n',  't',  'C', 
    'o',  'n',  'f',  'i',  'g', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(BirthdaysConfigAgentWidgetFactory, BirthdaysConfigAgentWidgetFactory)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
