/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.davGroupware.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SETTINGSADAPTOR_H
#define SETTINGSADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "settings.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Akonadi.davGroupware.Settings
 */
class SettingsAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Akonadi.davGroupware.Settings")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Akonadi.davGroupware.Settings\">\n"
"    <method name=\"save\"/>\n"
"    <method name=\"settingsVersion\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setSettingsVersion\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"displayName\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setDisplayName\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"refreshInterval\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setRefreshInterval\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"remoteUrls\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"setRemoteUrls\">\n"
"      <arg direction=\"in\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"defaultUsername\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setDefaultUsername\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"limitSyncRange\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setLimitSyncRange\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"syncRangeStartNumber\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setSyncRangeStartNumber\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"syncRangeStartType\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setSyncRangeStartType\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"collectionsUrlsMappings\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setCollectionsUrlsMappings\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"readOnly\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setReadOnly\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    SettingsAdaptor(Settings *parent);
    ~SettingsAdaptor() override;

    inline Settings *parent() const
    { return static_cast<Settings *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QString collectionsUrlsMappings();
    QString defaultUsername();
    QString displayName();
    bool limitSyncRange();
    bool readOnly();
    int refreshInterval();
    QStringList remoteUrls();
    void save();
    void setCollectionsUrlsMappings(const QString &in0);
    void setDefaultUsername(const QString &in0);
    void setDisplayName(const QString &in0);
    void setLimitSyncRange(bool in0);
    void setReadOnly(bool in0);
    void setRefreshInterval(int in0);
    void setRemoteUrls(const QStringList &in0);
    void setSettingsVersion(int in0);
    void setSyncRangeStartNumber(const QString &in0);
    void setSyncRangeStartType(const QString &in0);
    int settingsVersion();
    QString syncRangeStartNumber();
    QString syncRangeStartType();
Q_SIGNALS: // SIGNALS
};

#endif
