// This file is generated by kconfig_compiler_kf6 from maildirresource.kcfg.
// All changes you do to this file will be lost.

#include "settings.h"

#include <klocalizedstring.h>

using namespace Akonadi_Maildir_Resource;

MaildirSettings::MaildirSettings( KSharedConfig::Ptr config )
  : KConfigSkeleton( std::move( config ) )
{
  setCurrentGroup( QStringLiteral( "General" ) );

  mPathItem = new KConfigSkeleton::ItemPath( currentGroup(), QStringLiteral( "Path" ), mPath, QStringLiteral( "$HOME/.local/share/local-mail/" ) );
  mPathItem->setLabel( i18n("Path to maildir") );
  addItem( mPathItem, QStringLiteral( "Path" ) );
  mTopLevelIsContainerItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TopLevelIsContainer" ), mTopLevelIsContainer, false );
  mTopLevelIsContainerItem->setLabel( i18n("Path points to a folder containing Maildirs instead of to a maildir itself.") );
  addItem( mTopLevelIsContainerItem, QStringLiteral( "TopLevelIsContainer" ) );
  mReadOnlyItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ReadOnly" ), mReadOnly, false );
  mReadOnlyItem->setLabel( i18n("Do not change the actual backend data.") );
  addItem( mReadOnlyItem, QStringLiteral( "ReadOnly" ) );
  mMonitorFilesystemItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "MonitorFilesystem" ), mMonitorFilesystem, true );
  mMonitorFilesystemItem->setLabel( i18n("MonitorFilesystem") );
  addItem( mMonitorFilesystemItem, QStringLiteral( "MonitorFilesystem" ) );
}

MaildirSettings::~MaildirSettings()
{
}

