/********************************************************************************
** Form generated from reading UI file 'setupserverview_desktop.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETUPSERVERVIEW_DESKTOP_H
#define UI_SETUPSERVERVIEW_DESKTOP_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "Akonadi/CollectionRequester"
#include "kpasswordlineedit.h"
#include "ktitlewidget.h"

QT_BEGIN_NAMESPACE

class Ui_SetupServerView
{
public:
    QHBoxLayout *horizontalLayout_6;
    QTabWidget *tabWidget;
    QWidget *tab;
    QFormLayout *formLayout;
    KTitleWidget *accountInfoLabel;
    QLabel *label_8;
    QLineEdit *accountName;
    QLabel *label;
    QLineEdit *imapServer;
    QLabel *label_2;
    QLineEdit *userName;
    QLabel *label_3;
    KPasswordLineEdit *password;
    KTitleWidget *checkOptions;
    QCheckBox *disconnectedModeEnabled;
    QCheckBox *enableMailCheckBox;
    QLabel *label_7;
    QSpinBox *checkInterval;
    QSpacerItem *verticalSpacer_2;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *managesieveCheck;
    QCheckBox *sameConfigCheck;
    QLabel *label_14;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_5;
    QSpinBox *sievePortSpin;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_6;
    QLineEdit *alternateURL;
    QGroupBox *authentication;
    QGridLayout *gridLayout;
    QLineEdit *customUsername;
    QRadioButton *noAuthentification;
    QRadioButton *customUserPassword;
    KPasswordLineEdit *customPassword;
    QRadioButton *imapUserPassword;
    QLabel *label_13;
    QLabel *label_12;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_15;
    QComboBox *authenticationAlternateCombo;
    QSpacerItem *verticalSpacer;
    QWidget *advancedTab;
    QFormLayout *formLayoutAdvanced;
    KTitleWidget *titleWidget;
    QHBoxLayout *hboxLayout;
    QCheckBox *subscriptionEnabled;
    QPushButton *subscriptionButton;
    QCheckBox *autoExpungeCheck;
    QLabel *label_11;
    Akonadi::CollectionRequester *folderRequester;
    KTitleWidget *titleWidget1;
    QHBoxLayout *hboxLayout1;
    QPushButton *testButton;
    QPushButton *showServerInfo;
    QLabel *label_9;
    QHBoxLayout *horizontalLayout;
    QRadioButton *tlsRadio;
    QRadioButton *sslRadio;
    QRadioButton *noRadio;
    QLabel *imapInfo;
    QLabel *label_4;
    QSpinBox *portSpin;
    QLabel *label_10;
    QComboBox *authenticationCombo;
    QCheckBox *useProxyCheck;
    QLabel *testInfo;
    QProgressBar *testProgress;
    QSpacerItem *verticalSpacer_3;
    QButtonGroup *customSieveGroup;
    QButtonGroup *safeImapGroup;

    void setupUi(QWidget *SetupServerView)
    {
        if (SetupServerView->objectName().isEmpty())
            SetupServerView->setObjectName("SetupServerView");
        SetupServerView->resize(467, 582);
        horizontalLayout_6 = new QHBoxLayout(SetupServerView);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalLayout_6->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(SetupServerView);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        formLayout = new QFormLayout(tab);
        formLayout->setObjectName("formLayout");
        accountInfoLabel = new KTitleWidget(tab);
        accountInfoLabel->setObjectName("accountInfoLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::SpanningRole, accountInfoLabel);

        label_8 = new QLabel(tab);
        label_8->setObjectName("label_8");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_8);

        accountName = new QLineEdit(tab);
        accountName->setObjectName("accountName");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, accountName);

        label = new QLabel(tab);
        label->setObjectName("label");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label);

        imapServer = new QLineEdit(tab);
        imapServer->setObjectName("imapServer");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, imapServer);

        label_2 = new QLabel(tab);
        label_2->setObjectName("label_2");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_2);

        userName = new QLineEdit(tab);
        userName->setObjectName("userName");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, userName);

        label_3 = new QLabel(tab);
        label_3->setObjectName("label_3");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_3);

        password = new KPasswordLineEdit(tab);
        password->setObjectName("password");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, password);

        checkOptions = new KTitleWidget(tab);
        checkOptions->setObjectName("checkOptions");

        formLayout->setWidget(5, QFormLayout::ItemRole::SpanningRole, checkOptions);

        disconnectedModeEnabled = new QCheckBox(tab);
        disconnectedModeEnabled->setObjectName("disconnectedModeEnabled");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, disconnectedModeEnabled);

        enableMailCheckBox = new QCheckBox(tab);
        enableMailCheckBox->setObjectName("enableMailCheckBox");

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, enableMailCheckBox);

        label_7 = new QLabel(tab);
        label_7->setObjectName("label_7");

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, label_7);

        checkInterval = new QSpinBox(tab);
        checkInterval->setObjectName("checkInterval");
        checkInterval->setMinimum(0);
        checkInterval->setValue(1);

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, checkInterval);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(9, QFormLayout::ItemRole::LabelRole, verticalSpacer_2);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout_3 = new QVBoxLayout(tab_2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        managesieveCheck = new QCheckBox(tab_2);
        managesieveCheck->setObjectName("managesieveCheck");

        verticalLayout_3->addWidget(managesieveCheck);

        sameConfigCheck = new QCheckBox(tab_2);
        sameConfigCheck->setObjectName("sameConfigCheck");

        verticalLayout_3->addWidget(sameConfigCheck);

        label_14 = new QLabel(tab_2);
        label_14->setObjectName("label_14");
        label_14->setWordWrap(true);

        verticalLayout_3->addWidget(label_14);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_5 = new QLabel(tab_2);
        label_5->setObjectName("label_5");

        horizontalLayout_3->addWidget(label_5);

        sievePortSpin = new QSpinBox(tab_2);
        sievePortSpin->setObjectName("sievePortSpin");
        sievePortSpin->setMaximum(65535);

        horizontalLayout_3->addWidget(sievePortSpin);


        verticalLayout_3->addLayout(horizontalLayout_3);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label_6 = new QLabel(tab_2);
        label_6->setObjectName("label_6");

        horizontalLayout_4->addWidget(label_6);

        alternateURL = new QLineEdit(tab_2);
        alternateURL->setObjectName("alternateURL");

        horizontalLayout_4->addWidget(alternateURL);


        verticalLayout_3->addLayout(horizontalLayout_4);

        authentication = new QGroupBox(tab_2);
        authentication->setObjectName("authentication");
        gridLayout = new QGridLayout(authentication);
        gridLayout->setObjectName("gridLayout");
        customUsername = new QLineEdit(authentication);
        customUsername->setObjectName("customUsername");

        gridLayout->addWidget(customUsername, 4, 1, 1, 1);

        noAuthentification = new QRadioButton(authentication);
        customSieveGroup = new QButtonGroup(SetupServerView);
        customSieveGroup->setObjectName("customSieveGroup");
        customSieveGroup->addButton(noAuthentification);
        noAuthentification->setObjectName("noAuthentification");

        gridLayout->addWidget(noAuthentification, 1, 0, 1, 2);

        customUserPassword = new QRadioButton(authentication);
        customSieveGroup->addButton(customUserPassword);
        customUserPassword->setObjectName("customUserPassword");

        gridLayout->addWidget(customUserPassword, 3, 0, 1, 2);

        customPassword = new KPasswordLineEdit(authentication);
        customPassword->setObjectName("customPassword");

        gridLayout->addWidget(customPassword, 5, 1, 1, 1);

        imapUserPassword = new QRadioButton(authentication);
        customSieveGroup->addButton(imapUserPassword);
        imapUserPassword->setObjectName("imapUserPassword");
        imapUserPassword->setChecked(true);

        gridLayout->addWidget(imapUserPassword, 0, 0, 1, 1);

        label_13 = new QLabel(authentication);
        label_13->setObjectName("label_13");

        gridLayout->addWidget(label_13, 5, 0, 1, 1);

        label_12 = new QLabel(authentication);
        label_12->setObjectName("label_12");

        gridLayout->addWidget(label_12, 4, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_15 = new QLabel(authentication);
        label_15->setObjectName("label_15");

        horizontalLayout_2->addWidget(label_15);

        authenticationAlternateCombo = new QComboBox(authentication);
        authenticationAlternateCombo->addItem(QString());
        authenticationAlternateCombo->addItem(QString());
        authenticationAlternateCombo->addItem(QString());
        authenticationAlternateCombo->addItem(QString());
        authenticationAlternateCombo->addItem(QString());
        authenticationAlternateCombo->addItem(QString());
        authenticationAlternateCombo->addItem(QString());
        authenticationAlternateCombo->addItem(QString());
        authenticationAlternateCombo->setObjectName("authenticationAlternateCombo");

        horizontalLayout_2->addWidget(authenticationAlternateCombo);


        gridLayout->addLayout(horizontalLayout_2, 6, 0, 1, 2);


        verticalLayout_3->addWidget(authentication);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        tabWidget->addTab(tab_2, QString());
        advancedTab = new QWidget();
        advancedTab->setObjectName("advancedTab");
        formLayoutAdvanced = new QFormLayout(advancedTab);
        formLayoutAdvanced->setObjectName("formLayoutAdvanced");
        titleWidget = new KTitleWidget(advancedTab);
        titleWidget->setObjectName("titleWidget");

        formLayoutAdvanced->setWidget(0, QFormLayout::ItemRole::SpanningRole, titleWidget);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        subscriptionEnabled = new QCheckBox(advancedTab);
        subscriptionEnabled->setObjectName("subscriptionEnabled");

        hboxLayout->addWidget(subscriptionEnabled);

        subscriptionButton = new QPushButton(advancedTab);
        subscriptionButton->setObjectName("subscriptionButton");
        subscriptionButton->setEnabled(false);

        hboxLayout->addWidget(subscriptionButton);


        formLayoutAdvanced->setLayout(1, QFormLayout::ItemRole::FieldRole, hboxLayout);

        autoExpungeCheck = new QCheckBox(advancedTab);
        autoExpungeCheck->setObjectName("autoExpungeCheck");

        formLayoutAdvanced->setWidget(2, QFormLayout::ItemRole::FieldRole, autoExpungeCheck);

        label_11 = new QLabel(advancedTab);
        label_11->setObjectName("label_11");

        formLayoutAdvanced->setWidget(3, QFormLayout::ItemRole::LabelRole, label_11);

        folderRequester = new Akonadi::CollectionRequester(advancedTab);
        folderRequester->setObjectName("folderRequester");

        formLayoutAdvanced->setWidget(3, QFormLayout::ItemRole::FieldRole, folderRequester);

        titleWidget1 = new KTitleWidget(advancedTab);
        titleWidget1->setObjectName("titleWidget1");

        formLayoutAdvanced->setWidget(4, QFormLayout::ItemRole::SpanningRole, titleWidget1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        testButton = new QPushButton(advancedTab);
        testButton->setObjectName("testButton");

        hboxLayout1->addWidget(testButton);

        showServerInfo = new QPushButton(advancedTab);
        showServerInfo->setObjectName("showServerInfo");

        hboxLayout1->addWidget(showServerInfo);


        formLayoutAdvanced->setLayout(5, QFormLayout::ItemRole::FieldRole, hboxLayout1);

        label_9 = new QLabel(advancedTab);
        label_9->setObjectName("label_9");

        formLayoutAdvanced->setWidget(6, QFormLayout::ItemRole::LabelRole, label_9);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        tlsRadio = new QRadioButton(advancedTab);
        safeImapGroup = new QButtonGroup(SetupServerView);
        safeImapGroup->setObjectName("safeImapGroup");
        safeImapGroup->addButton(tlsRadio);
        tlsRadio->setObjectName("tlsRadio");

        horizontalLayout->addWidget(tlsRadio);

        sslRadio = new QRadioButton(advancedTab);
        safeImapGroup->addButton(sslRadio);
        sslRadio->setObjectName("sslRadio");

        horizontalLayout->addWidget(sslRadio);

        noRadio = new QRadioButton(advancedTab);
        safeImapGroup->addButton(noRadio);
        noRadio->setObjectName("noRadio");
        noRadio->setChecked(true);

        horizontalLayout->addWidget(noRadio);


        formLayoutAdvanced->setLayout(6, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        imapInfo = new QLabel(advancedTab);
        imapInfo->setObjectName("imapInfo");

        formLayoutAdvanced->setWidget(7, QFormLayout::ItemRole::FieldRole, imapInfo);

        label_4 = new QLabel(advancedTab);
        label_4->setObjectName("label_4");

        formLayoutAdvanced->setWidget(8, QFormLayout::ItemRole::LabelRole, label_4);

        portSpin = new QSpinBox(advancedTab);
        portSpin->setObjectName("portSpin");
        portSpin->setMinimum(1);
        portSpin->setMaximum(65534);
        portSpin->setValue(143);

        formLayoutAdvanced->setWidget(8, QFormLayout::ItemRole::FieldRole, portSpin);

        label_10 = new QLabel(advancedTab);
        label_10->setObjectName("label_10");

        formLayoutAdvanced->setWidget(9, QFormLayout::ItemRole::LabelRole, label_10);

        authenticationCombo = new QComboBox(advancedTab);
        authenticationCombo->addItem(QString());
        authenticationCombo->addItem(QString());
        authenticationCombo->addItem(QString());
        authenticationCombo->addItem(QString());
        authenticationCombo->addItem(QString());
        authenticationCombo->addItem(QString());
        authenticationCombo->addItem(QString());
        authenticationCombo->addItem(QString());
        authenticationCombo->setObjectName("authenticationCombo");

        formLayoutAdvanced->setWidget(9, QFormLayout::ItemRole::FieldRole, authenticationCombo);

        useProxyCheck = new QCheckBox(advancedTab);
        useProxyCheck->setObjectName("useProxyCheck");

        formLayoutAdvanced->setWidget(10, QFormLayout::ItemRole::FieldRole, useProxyCheck);

        testInfo = new QLabel(advancedTab);
        testInfo->setObjectName("testInfo");
        QFont font;
        font.setBold(true);
        testInfo->setFont(font);
        testInfo->setAlignment(Qt::AlignCenter);
        testInfo->setWordWrap(true);

        formLayoutAdvanced->setWidget(11, QFormLayout::ItemRole::SpanningRole, testInfo);

        testProgress = new QProgressBar(advancedTab);
        testProgress->setObjectName("testProgress");
        testProgress->setValue(24);

        formLayoutAdvanced->setWidget(12, QFormLayout::ItemRole::SpanningRole, testProgress);

        verticalSpacer_3 = new QSpacerItem(20, 60, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayoutAdvanced->setItem(13, QFormLayout::ItemRole::LabelRole, verticalSpacer_3);

        tabWidget->addTab(advancedTab, QString());

        horizontalLayout_6->addWidget(tabWidget);

#if QT_CONFIG(shortcut)
        label->setBuddy(imapServer);
        label_2->setBuddy(userName);
        label_3->setBuddy(password);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SetupServerView);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(SetupServerView);
    } // setupUi

    void retranslateUi(QWidget *SetupServerView)
    {
        accountInfoLabel->setText(tr2i18n("Account Information", nullptr));
        label_8->setText(tr2i18n("Account Name:", nullptr));
#if QT_CONFIG(whatsthis)
        label->setWhatsThis(tr2i18n("Indicate the IMAP server. If you want to connect to a non-standard port for a specific encryption scheme, you can add \":port\" to indicate that. For example: \"imap.foo.com:144\".", nullptr));
#endif // QT_CONFIG(whatsthis)
        label->setText(tr2i18n("I&MAP Server:", nullptr));
#if QT_CONFIG(whatsthis)
        label_2->setWhatsThis(tr2i18n("The username.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_2->setText(tr2i18n("Use&rname:", nullptr));
#if QT_CONFIG(whatsthis)
        label_3->setWhatsThis(tr2i18n("The password.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_3->setText(tr2i18n("Password:", nullptr));
        checkOptions->setText(tr2i18n("Mail Checking Options", nullptr));
        disconnectedModeEnabled->setText(tr2i18n("&Download all messages for offline use", nullptr));
        enableMailCheckBox->setText(tr2i18n("Enable &interval mail checking", nullptr));
        label_7->setText(tr2i18n("Check mail interval:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("General", nullptr));
        managesieveCheck->setText(tr2i18n("Server supports Sieve", nullptr));
        sameConfigCheck->setText(tr2i18n("Reuse host and login configuration", nullptr));
        label_14->setText(tr2i18n("The server port changed when ManageSieve turned into a full RFC Standard. Old server implementations still use port 2000, while newer standard conform server can only be accessed via port 4190.", nullptr));
        label_5->setText(tr2i18n("Managesieve port:", nullptr));
        label_6->setText(tr2i18n("Alternate Server:", nullptr));
        authentication->setTitle(tr2i18n("Authentication", nullptr));
        noAuthentification->setText(tr2i18n("No authentication", nullptr));
        customUserPassword->setText(tr2i18n("&Username and Password", nullptr));
        imapUserPassword->setText(tr2i18n("I&MAP Username and Password", nullptr));
        label_13->setText(tr2i18n("Password:", nullptr));
        label_12->setText(tr2i18n("Username:", nullptr));
        label_15->setText(tr2i18n("Authentication:", nullptr));
        authenticationAlternateCombo->setItemText(0, tr2i18n("Clear text", "Authentication method"));
        authenticationAlternateCombo->setItemText(1, tr2i18n("LOGIN", "Authentication method"));
        authenticationAlternateCombo->setItemText(2, tr2i18n("PLAIN", "Authentication method"));
        authenticationAlternateCombo->setItemText(3, tr2i18n("CRAM-MD5", "Authentication method"));
        authenticationAlternateCombo->setItemText(4, tr2i18n("DIGEST-MD5", "Authentication method"));
        authenticationAlternateCombo->setItemText(5, tr2i18n("NTLM", "Authentication method"));
        authenticationAlternateCombo->setItemText(6, tr2i18n("GSSAPI", "Authentication method"));
        authenticationAlternateCombo->setItemText(7, tr2i18n("Anonymous", "Authentication method"));

        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Filtering", nullptr));
        titleWidget->setText(tr2i18n("IMAP Settings", nullptr));
        subscriptionEnabled->setText(tr2i18n("Enable server-side subscriptions", nullptr));
        subscriptionButton->setText(tr2i18n("Serverside Subscription\342\200\246", nullptr));
        autoExpungeCheck->setText(tr2i18n("Automaticall&y compact folders (expunges deleted messages)", nullptr));
        label_11->setText(tr2i18n("Trash folder:", nullptr));
        titleWidget1->setText(tr2i18n("Connection Settings", nullptr));
        testButton->setText(tr2i18n("Auto Detect", nullptr));
        showServerInfo->setText(tr2i18n("Server Info", nullptr));
        label_9->setText(tr2i18n("Encryption:", nullptr));
        tlsRadio->setText(tr2i18n("STARTTLS", nullptr));
        sslRadio->setText(tr2i18n("SSL/TLS", nullptr));
        noRadio->setText(tr2i18n("None", nullptr));
        imapInfo->setText(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'HandelGotDLig'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Sans Serif'; font-weight:600;\">SSL/TLS</span><span style=\" font-family:'Sans Serif';\"> is safe IMAP over port 993;</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Sans Serif'; font-weight:600;\">STARTTLS</span><span style=\" font-family:'Sans Serif';\"> will operate on port 143 and switch to a secure connection directly after connecting;</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0p"
                        "x; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Sans Serif'; font-weight:600;\">None</span><span style=\" font-family:'Sans Serif';\"> will connect to port 143 but not switch to a secure connection. This setting is not recommended.</span></p></body></html>", nullptr));
        label_4->setText(tr2i18n("Port:", nullptr));
        label_10->setText(tr2i18n("Authentication:", nullptr));
        authenticationCombo->setItemText(0, tr2i18n("Clear text", "Authentication method"));
        authenticationCombo->setItemText(1, tr2i18n("LOGIN", "Authentication method"));
        authenticationCombo->setItemText(2, tr2i18n("PLAIN", "Authentication method"));
        authenticationCombo->setItemText(3, tr2i18n("CRAM-MD5", "Authentication method"));
        authenticationCombo->setItemText(4, tr2i18n("DIGEST-MD5", "Authentication method"));
        authenticationCombo->setItemText(5, tr2i18n("NTLM", "Authentication method"));
        authenticationCombo->setItemText(6, tr2i18n("GSSAPI", "Authentication method"));
        authenticationCombo->setItemText(7, tr2i18n("Anonymous", "Authentication method"));

        useProxyCheck->setText(tr2i18n("Connect using the system proxy settings", nullptr));
        testInfo->setText(tr2i18n("Empty", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(advancedTab), tr2i18n("Advanced", nullptr));
        (void)SetupServerView;
    } // retranslateUi

};

namespace Ui {
    class SetupServerView: public Ui_SetupServerView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETUPSERVERVIEW_DESKTOP_H

