/********************************************************************************
** Form generated from reading UI file 'urlconfigurationdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_URLCONFIGURATIONDIALOG_H
#define UI_URLCONFIGURATIONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kpasswordlineedit.h"

QT_BEGIN_NAMESPACE

class Ui_UrlConfigurationDialog
{
public:
    QFormLayout *verticalLayout_2;
    QLabel *remoteProtocol;
    QRadioButton *caldav;
    QRadioButton *carddav;
    QRadioButton *groupdav;
    QLabel *label;
    QLineEdit *remoteUrl;
    QLabel *label1;
    QVBoxLayout *vboxLayout;
    QRadioButton *useDefaultCreds;
    QRadioButton *useSpecificCreds;
    QGroupBox *credentialsGroup;
    QFormLayout *formLayout;
    QLabel *label_4;
    QLineEdit *username;
    QLabel *label_5;
    KPasswordLineEdit *password;
    QLabel *collectionsLabel;
    QTreeView *discoveredUrls;
    QHBoxLayout *hboxLayout;
    QSpacerItem *verticalSpacer;
    QPushButton *fetchButton;
    QButtonGroup *buttonGroup;

    void setupUi(QWidget *UrlConfigurationDialog)
    {
        if (UrlConfigurationDialog->objectName().isEmpty())
            UrlConfigurationDialog->setObjectName("UrlConfigurationDialog");
        UrlConfigurationDialog->resize(800, 698);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(UrlConfigurationDialog->sizePolicy().hasHeightForWidth());
        UrlConfigurationDialog->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QFormLayout(UrlConfigurationDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        remoteProtocol = new QLabel(UrlConfigurationDialog);
        remoteProtocol->setObjectName("remoteProtocol");

        verticalLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, remoteProtocol);

        caldav = new QRadioButton(UrlConfigurationDialog);
        buttonGroup = new QButtonGroup(UrlConfigurationDialog);
        buttonGroup->setObjectName("buttonGroup");
        buttonGroup->addButton(caldav);
        caldav->setObjectName("caldav");
        caldav->setChecked(true);

        verticalLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, caldav);

        carddav = new QRadioButton(UrlConfigurationDialog);
        buttonGroup->addButton(carddav);
        carddav->setObjectName("carddav");

        verticalLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, carddav);

        groupdav = new QRadioButton(UrlConfigurationDialog);
        buttonGroup->addButton(groupdav);
        groupdav->setObjectName("groupdav");

        verticalLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, groupdav);

        label = new QLabel(UrlConfigurationDialog);
        label->setObjectName("label");

        verticalLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label);

        remoteUrl = new QLineEdit(UrlConfigurationDialog);
        remoteUrl->setObjectName("remoteUrl");

        verticalLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, remoteUrl);

        label1 = new QLabel(UrlConfigurationDialog);
        label1->setObjectName("label1");

        verticalLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, label1);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        useDefaultCreds = new QRadioButton(UrlConfigurationDialog);
        useDefaultCreds->setObjectName("useDefaultCreds");
        useDefaultCreds->setChecked(true);

        vboxLayout->addWidget(useDefaultCreds);

        useSpecificCreds = new QRadioButton(UrlConfigurationDialog);
        useSpecificCreds->setObjectName("useSpecificCreds");

        vboxLayout->addWidget(useSpecificCreds);

        credentialsGroup = new QGroupBox(UrlConfigurationDialog);
        credentialsGroup->setObjectName("credentialsGroup");
        credentialsGroup->setFlat(true);
        formLayout = new QFormLayout(credentialsGroup);
        formLayout->setObjectName("formLayout");
        label_4 = new QLabel(credentialsGroup);
        label_4->setObjectName("label_4");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_4);

        username = new QLineEdit(credentialsGroup);
        username->setObjectName("username");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, username);

        label_5 = new QLabel(credentialsGroup);
        label_5->setObjectName("label_5");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_5);

        password = new KPasswordLineEdit(credentialsGroup);
        password->setObjectName("password");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, password);


        vboxLayout->addWidget(credentialsGroup);


        verticalLayout_2->setLayout(4, QFormLayout::ItemRole::FieldRole, vboxLayout);

        collectionsLabel = new QLabel(UrlConfigurationDialog);
        collectionsLabel->setObjectName("collectionsLabel");

        verticalLayout_2->setWidget(5, QFormLayout::ItemRole::SpanningRole, collectionsLabel);

        discoveredUrls = new QTreeView(UrlConfigurationDialog);
        discoveredUrls->setObjectName("discoveredUrls");

        verticalLayout_2->setWidget(6, QFormLayout::ItemRole::SpanningRole, discoveredUrls);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(verticalSpacer);

        fetchButton = new QPushButton(UrlConfigurationDialog);
        fetchButton->setObjectName("fetchButton");

        hboxLayout->addWidget(fetchButton);


        verticalLayout_2->setLayout(7, QFormLayout::ItemRole::FieldRole, hboxLayout);

#if QT_CONFIG(shortcut)
        label_4->setBuddy(username);
        label_5->setBuddy(password);
#endif // QT_CONFIG(shortcut)

        retranslateUi(UrlConfigurationDialog);
        QObject::connect(useSpecificCreds, &QRadioButton::toggled, credentialsGroup, &QGroupBox::setVisible);

        QMetaObject::connectSlotsByName(UrlConfigurationDialog);
    } // setupUi

    void retranslateUi(QWidget *UrlConfigurationDialog)
    {
        remoteProtocol->setText(tr2i18n("Access protocol:", nullptr));
        caldav->setText(tr2i18n("CalDA&V", nullptr));
        carddav->setText(tr2i18n("CardDAV", nullptr));
        groupdav->setText(tr2i18n("GroupDAV", nullptr));
        label->setText(tr2i18n("Remote URL:", nullptr));
        label1->setText(tr2i18n("Access:", nullptr));
        useDefaultCreds->setText(tr2i18n("Use global creden&tials", nullptr));
        useSpecificCreds->setText(tr2i18n("Use specific credentials", nullptr));
#if QT_CONFIG(tooltip)
        label_4->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Username:", nullptr));
#if QT_CONFIG(tooltip)
        label_5->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        label_5->setText(tr2i18n("Password:", nullptr));
        collectionsLabel->setText(tr2i18n("Discovered collections:", nullptr));
        fetchButton->setText(tr2i18n("Fetch", nullptr));
        (void)UrlConfigurationDialog;
    } // retranslateUi

};

namespace Ui {
    class UrlConfigurationDialog: public Ui_UrlConfigurationDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // URLCONFIGURATIONDIALOG_H

