/****************************************************************************
** Meta object code from reading C++ file 'ewssettingsadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "ewssettingsadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ewssettingsadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18EwsSettingsAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto EwsSettingsAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN18EwsSettingsAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EwsSettingsAdaptor",
        "D-Bus Interface",
        "org.kde.Akonadi.Ews.Settings",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Akonadi.Ews.Settings\">\n    <method n"
        "ame=\"save\"/>\n    <method name=\"baseUrl\">\n      <arg directio"
        "n=\"out\" type=\"s\"/>\n    </method>\n    <method name=\"setBaseU"
        "rl\">\n      <arg direction=\"in\" type=\"s\"/>\n    </method>\n  "
        "  <method name=\"username\">\n      <arg direction=\"out\" type=\""
        "s\"/>\n    </method>\n    <method name=\"setUsername\">\n      <ar"
        "g direction=\"in\" type=\"s\"/>\n    </method>\n    <method name=\""
        "domain\">\n      <arg direction=\"out\" type=\"s\"/>\n    </method"
        ">\n    <method name=\"setDomain\">\n      <arg direction=\"in\" ty"
        "pe=\"s\"/>\n    </method>\n    <method name=\"hasDomain\">\n      "
        "<arg direction=\"out\" type=\"b\"/>\n    </method>\n    <method na"
        "me=\"setHasDomain\">\n      <arg direction=\"in\" type=\"b\"/>\n  "
        "  </method>\n    <method name=\"email\">\n      <arg direction=\"o"
        "ut\" type=\"s\"/>\n    </method>\n    <method name=\"setEmail\">\n"
        "      <arg direction=\"in\" type=\"s\"/>\n    </method>\n    <meth"
        "od name=\"autoDiscovery\">\n      <arg direction=\"out\" type=\"b\""
        "/>\n    </method>\n    <method name=\"setAutoDiscovery\">\n      <"
        "arg direction=\"in\" type=\"b\"/>\n    </method>\n    <method name"
        "=\"pollInterval\">\n      <arg direction=\"out\" type=\"d\"/>\n   "
        " </method>\n    <method name=\"setPollInterval\">\n      <arg dire"
        "ction=\"in\" type=\"d\"/>\n    </method>\n    <method name=\"retri"
        "evalMethod\">\n      <arg direction=\"out\" type=\"i\"/>\n    </me"
        "thod>\n    <method name=\"setRetrievalMethod\">\n      <arg direct"
        "ion=\"in\" type=\"i\"/>\n    </method>\n    <method name=\"serverS"
        "ubscription\">\n      <arg direction=\"out\" type=\"b\"/>\n    </m"
        "ethod>\n    <method name=\"setServerSubscription\">\n      <arg di"
        "rection=\"in\" type=\"b\"/>\n    </method>\n    <method name=\"ser"
        "verSubscriptionList\">\n      <arg direction=\"out\" type=\"as\"/>"
        "\n    </method>\n    <method name=\"setServerSubscriptionList\">\n"
        "      <arg direction=\"in\" type=\"as\"/>\n    </method>\n    <met"
        "hod name=\"enableNTLMv2\">\n      <arg direction=\"out\" type=\"b\""
        "/>\n    </method>\n    <method name=\"setEnableNTLMv2\">\n      <a"
        "rg direction=\"in\" type=\"b\"/>\n    </method>\n    <method name="
        "\"userAgent\">\n      <arg direction=\"out\" type=\"s\"/>\n    </m"
        "ethod>\n    <method name=\"setUserAgent\">\n      <arg direction=\""
        "in\" type=\"s\"/>\n    </method>\n    <method name=\"authMode\">\n"
        "      <arg direction=\"out\" type=\"s\"/>\n    </method>\n    <met"
        "hod name=\"setAuthMode\">\n      <arg direction=\"in\" type=\"s\"/"
        ">\n    </method>\n    <method name=\"oAuth2AppId\">\n      <arg di"
        "rection=\"out\" type=\"s\"/>\n    </method>\n    <method name=\"se"
        "tOAuth2AppId\">\n      <arg direction=\"in\" type=\"s\"/>\n    </m"
        "ethod>\n    <method name=\"oAuth2ReturnUri\">\n      <arg directio"
        "n=\"out\" type=\"s\"/>\n    </method>\n    <method name=\"setOAuth"
        "2ReturnUri\">\n      <arg direction=\"in\" type=\"s\"/>\n    </met"
        "hod>\n    <method name=\"pKeyCert\">\n      <arg direction=\"out\""
        " type=\"s\"/>\n    </method>\n    <method name=\"setPKeyCert\">\n "
        "     <arg direction=\"in\" type=\"s\"/>\n    </method>\n    <metho"
        "d name=\"pKeyKey\">\n      <arg direction=\"out\" type=\"s\"/>\n  "
        "  </method>\n    <method name=\"setPKeyKey\">\n      <arg directio"
        "n=\"in\" type=\"s\"/>\n    </method>\n    <method name=\"folderSyn"
        "cState\">\n      <arg direction=\"out\" type=\"s\"/>\n    </method"
        ">\n    <method name=\"setFolderSyncState\">\n      <arg direction="
        "\"in\" type=\"s\"/>\n    </method>\n    <method name=\"eventSubscr"
        "iptionId\">\n      <arg direction=\"out\" type=\"s\"/>\n    </meth"
        "od>\n    <method name=\"setEventSubscriptionId\">\n      <arg dire"
        "ction=\"in\" type=\"s\"/>\n    </method>\n    <method name=\"event"
        "SubscriptionWatermark\">\n      <arg direction=\"out\" type=\"s\"/"
        ">\n    </method>\n    <method name=\"setEventSubscriptionWatermark"
        "\">\n      <arg direction=\"in\" type=\"s\"/>\n    </method>\n  </"
        "interface>\n",
        "authMode",
        "",
        "autoDiscovery",
        "baseUrl",
        "domain",
        "email",
        "enableNTLMv2",
        "eventSubscriptionId",
        "eventSubscriptionWatermark",
        "folderSyncState",
        "hasDomain",
        "oAuth2AppId",
        "oAuth2ReturnUri",
        "pKeyCert",
        "pKeyKey",
        "pollInterval",
        "retrievalMethod",
        "save",
        "serverSubscription",
        "serverSubscriptionList",
        "setAuthMode",
        "in0",
        "setAutoDiscovery",
        "setBaseUrl",
        "setDomain",
        "setEmail",
        "setEnableNTLMv2",
        "setEventSubscriptionId",
        "setEventSubscriptionWatermark",
        "setFolderSyncState",
        "setHasDomain",
        "setOAuth2AppId",
        "setOAuth2ReturnUri",
        "setPKeyCert",
        "setPKeyKey",
        "setPollInterval",
        "setRetrievalMethod",
        "setServerSubscription",
        "setServerSubscriptionList",
        "setUserAgent",
        "setUsername",
        "userAgent",
        "username"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'authMode'
        QtMocHelpers::SlotData<QString()>(5, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'autoDiscovery'
        QtMocHelpers::SlotData<bool()>(7, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'baseUrl'
        QtMocHelpers::SlotData<QString()>(8, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'domain'
        QtMocHelpers::SlotData<QString()>(9, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'email'
        QtMocHelpers::SlotData<QString()>(10, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'enableNTLMv2'
        QtMocHelpers::SlotData<bool()>(11, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'eventSubscriptionId'
        QtMocHelpers::SlotData<QString()>(12, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'eventSubscriptionWatermark'
        QtMocHelpers::SlotData<QString()>(13, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'folderSyncState'
        QtMocHelpers::SlotData<QString()>(14, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'hasDomain'
        QtMocHelpers::SlotData<bool()>(15, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'oAuth2AppId'
        QtMocHelpers::SlotData<QString()>(16, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'oAuth2ReturnUri'
        QtMocHelpers::SlotData<QString()>(17, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'pKeyCert'
        QtMocHelpers::SlotData<QString()>(18, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'pKeyKey'
        QtMocHelpers::SlotData<QString()>(19, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'pollInterval'
        QtMocHelpers::SlotData<double()>(20, 6, QMC::AccessPublic, QMetaType::Double),
        // Slot 'retrievalMethod'
        QtMocHelpers::SlotData<int()>(21, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'serverSubscription'
        QtMocHelpers::SlotData<bool()>(23, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'serverSubscriptionList'
        QtMocHelpers::SlotData<QStringList()>(24, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'setAuthMode'
        QtMocHelpers::SlotData<void(const QString &)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setAutoDiscovery'
        QtMocHelpers::SlotData<void(bool)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setBaseUrl'
        QtMocHelpers::SlotData<void(const QString &)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setDomain'
        QtMocHelpers::SlotData<void(const QString &)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setEmail'
        QtMocHelpers::SlotData<void(const QString &)>(30, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setEnableNTLMv2'
        QtMocHelpers::SlotData<void(bool)>(31, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setEventSubscriptionId'
        QtMocHelpers::SlotData<void(const QString &)>(32, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setEventSubscriptionWatermark'
        QtMocHelpers::SlotData<void(const QString &)>(33, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setFolderSyncState'
        QtMocHelpers::SlotData<void(const QString &)>(34, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setHasDomain'
        QtMocHelpers::SlotData<void(bool)>(35, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setOAuth2AppId'
        QtMocHelpers::SlotData<void(const QString &)>(36, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setOAuth2ReturnUri'
        QtMocHelpers::SlotData<void(const QString &)>(37, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setPKeyCert'
        QtMocHelpers::SlotData<void(const QString &)>(38, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setPKeyKey'
        QtMocHelpers::SlotData<void(const QString &)>(39, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setPollInterval'
        QtMocHelpers::SlotData<void(double)>(40, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 26 },
        }}),
        // Slot 'setRetrievalMethod'
        QtMocHelpers::SlotData<void(int)>(41, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'setServerSubscription'
        QtMocHelpers::SlotData<void(bool)>(42, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setServerSubscriptionList'
        QtMocHelpers::SlotData<void(const QStringList &)>(43, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 26 },
        }}),
        // Slot 'setUserAgent'
        QtMocHelpers::SlotData<void(const QString &)>(44, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setUsername'
        QtMocHelpers::SlotData<void(const QString &)>(45, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'userAgent'
        QtMocHelpers::SlotData<QString()>(46, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'username'
        QtMocHelpers::SlotData<QString()>(47, 6, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<EwsSettingsAdaptor, qt_meta_tag_ZN18EwsSettingsAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject EwsSettingsAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18EwsSettingsAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18EwsSettingsAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18EwsSettingsAdaptorE_t>.metaTypes,
    nullptr
} };

void EwsSettingsAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EwsSettingsAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->authMode();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->autoDiscovery();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->baseUrl();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->domain();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->email();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->enableNTLMv2();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->eventSubscriptionId();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->eventSubscriptionWatermark();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->folderSyncState();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->hasDomain();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->oAuth2AppId();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->oAuth2ReturnUri();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->pKeyCert();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->pKeyKey();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { double _r = _t->pollInterval();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 15: { int _r = _t->retrievalMethod();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->save(); break;
        case 17: { bool _r = _t->serverSubscription();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { QStringList _r = _t->serverSubscriptionList();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->setAuthMode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->setAutoDiscovery((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->setBaseUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->setDomain((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->setEmail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->setEnableNTLMv2((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->setEventSubscriptionId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->setEventSubscriptionWatermark((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->setFolderSyncState((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->setHasDomain((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->setOAuth2AppId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 30: _t->setOAuth2ReturnUri((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->setPKeyCert((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: _t->setPKeyKey((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 33: _t->setPollInterval((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 34: _t->setRetrievalMethod((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->setServerSubscription((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->setServerSubscriptionList((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 37: _t->setUserAgent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 38: _t->setUsername((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 39: { QString _r = _t->userAgent();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 40: { QString _r = _t->username();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *EwsSettingsAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EwsSettingsAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18EwsSettingsAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int EwsSettingsAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 41)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 41;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 41)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 41;
    }
    return _id;
}
QT_WARNING_POP
