// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "contacts_resources_debug.h"


Q_LOGGING_CATEGORY(CONTACTSRESOURCES_LOG, "org.kde.pim.resources_contacts", QtInfoMsg)

