/********************************************************************************
** Form generated from reading UI file 'birthdaysconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BIRTHDAYSCONFIGWIDGET_H
#define UI_BIRTHDAYSCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "Akonadi/TagSelectWidget"

QT_BEGIN_NAMESPACE

class Ui_BirthdaysConfigWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_EnableAlarm;
    QLabel *label;
    QSpinBox *kcfg_AlarmDays;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_FilterOnCategories;
    Akonadi::TagSelectWidget *FilterCategories;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *BirthdaysConfigWidget)
    {
        if (BirthdaysConfigWidget->objectName().isEmpty())
            BirthdaysConfigWidget->setObjectName("BirthdaysConfigWidget");
        BirthdaysConfigWidget->resize(434, 364);
        verticalLayout_2 = new QVBoxLayout(BirthdaysConfigWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        groupBox = new QGroupBox(BirthdaysConfigWidget);
        groupBox->setObjectName("groupBox");
        groupBox->setCheckable(false);
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        kcfg_EnableAlarm = new QCheckBox(groupBox);
        kcfg_EnableAlarm->setObjectName("kcfg_EnableAlarm");

        gridLayout->addWidget(kcfg_EnableAlarm, 0, 0, 1, 1);

        label = new QLabel(groupBox);
        label->setObjectName("label");
        label->setEnabled(false);

        gridLayout->addWidget(label, 1, 0, 1, 1);

        kcfg_AlarmDays = new QSpinBox(groupBox);
        kcfg_AlarmDays->setObjectName("kcfg_AlarmDays");
        kcfg_AlarmDays->setEnabled(false);
        kcfg_AlarmDays->setMaximum(355);

        gridLayout->addWidget(kcfg_AlarmDays, 1, 1, 1, 1);


        verticalLayout_2->addWidget(groupBox);

        groupBox_2 = new QGroupBox(BirthdaysConfigWidget);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout = new QVBoxLayout(groupBox_2);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_FilterOnCategories = new QCheckBox(groupBox_2);
        kcfg_FilterOnCategories->setObjectName("kcfg_FilterOnCategories");

        verticalLayout->addWidget(kcfg_FilterOnCategories);

        FilterCategories = new Akonadi::TagSelectWidget(groupBox_2);
        FilterCategories->setObjectName("FilterCategories");
        FilterCategories->setEnabled(false);

        verticalLayout->addWidget(FilterCategories);


        verticalLayout_2->addWidget(groupBox_2);

        verticalSpacer = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label->setBuddy(kcfg_AlarmDays);
#endif // QT_CONFIG(shortcut)

        retranslateUi(BirthdaysConfigWidget);
        QObject::connect(kcfg_EnableAlarm, &QCheckBox::toggled, label, &QLabel::setEnabled);
        QObject::connect(kcfg_EnableAlarm, &QCheckBox::toggled, kcfg_AlarmDays, &QSpinBox::setEnabled);
        QObject::connect(kcfg_FilterOnCategories, SIGNAL(toggled(bool)), FilterCategories, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(BirthdaysConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *BirthdaysConfigWidget)
    {
        groupBox->setTitle(tr2i18n("Reminder", nullptr));
        kcfg_EnableAlarm->setText(tr2i18n("Set &reminder", nullptr));
        label->setText(tr2i18n("&Remind prior to event:", nullptr));
        kcfg_AlarmDays->setPrefix(QString());
        groupBox_2->setTitle(tr2i18n("Filter", nullptr));
        kcfg_FilterOnCategories->setText(tr2i18n("&Filter by categories", nullptr));
        (void)BirthdaysConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class BirthdaysConfigWidget: public Ui_BirthdaysConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BIRTHDAYSCONFIGWIDGET_H

