/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.MailDispatcher.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SETTINGSADAPTOR_H
#define SETTINGSADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "settings.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Akonadi.MailDispatcher.Settings
 */
class SettingsAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Akonadi.MailDispatcher.Settings")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Akonadi.MailDispatcher.Settings\">\n"
"    <method name=\"save\"/>\n"
"    <method name=\"outbox\">\n"
"      <arg direction=\"out\" type=\"x\"/>\n"
"    </method>\n"
"    <method name=\"setOutbox\">\n"
"      <arg direction=\"in\" type=\"x\"/>\n"
"    </method>\n"
"    <method name=\"sentMail\">\n"
"      <arg direction=\"out\" type=\"x\"/>\n"
"    </method>\n"
"    <method name=\"setSentMail\">\n"
"      <arg direction=\"in\" type=\"x\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    SettingsAdaptor(Settings *parent);
    ~SettingsAdaptor() override;

    inline Settings *parent() const
    { return static_cast<Settings *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    qlonglong outbox();
    void save();
    qlonglong sentMail();
    void setOutbox(qlonglong in0);
    void setSentMail(qlonglong in0);
Q_SIGNALS: // SIGNALS
};

#endif
