/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.Imap.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "settingsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class SettingsAdaptor
 */

SettingsAdaptor::SettingsAdaptor(Settings *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

SettingsAdaptor::~SettingsAdaptor()
{
    // destructor
}

int SettingsAdaptor::accountIdentity()
{
    // handle method call org.kde.Akonadi.Imap.Settings.accountIdentity
    return parent()->accountIdentity();
}

QStringList SettingsAdaptor::activities()
{
    // handle method call org.kde.Akonadi.Imap.Settings.activities
    return parent()->activities();
}

bool SettingsAdaptor::activitiesEnabled()
{
    // handle method call org.kde.Akonadi.Imap.Settings.activitiesEnabled
    return parent()->activitiesEnabled();
}

int SettingsAdaptor::alternateAuthentication()
{
    // handle method call org.kde.Akonadi.Imap.Settings.alternateAuthentication
    return parent()->alternateAuthentication();
}

int SettingsAdaptor::authentication()
{
    // handle method call org.kde.Akonadi.Imap.Settings.authentication
    return parent()->authentication();
}

bool SettingsAdaptor::automaticExpungeEnabled()
{
    // handle method call org.kde.Akonadi.Imap.Settings.automaticExpungeEnabled
    return parent()->automaticExpungeEnabled();
}

bool SettingsAdaptor::disconnectedModeEnabled()
{
    // handle method call org.kde.Akonadi.Imap.Settings.disconnectedModeEnabled
    return parent()->disconnectedModeEnabled();
}

QStringList SettingsAdaptor::idleRidPath()
{
    // handle method call org.kde.Akonadi.Imap.Settings.idleRidPath
    return parent()->idleRidPath();
}

int SettingsAdaptor::imapPort()
{
    // handle method call org.kde.Akonadi.Imap.Settings.imapPort
    return parent()->imapPort();
}

QString SettingsAdaptor::imapServer()
{
    // handle method call org.kde.Akonadi.Imap.Settings.imapServer
    return parent()->imapServer();
}

bool SettingsAdaptor::intervalCheckEnabled()
{
    // handle method call org.kde.Akonadi.Imap.Settings.intervalCheckEnabled
    return parent()->intervalCheckEnabled();
}

int SettingsAdaptor::intervalCheckTime()
{
    // handle method call org.kde.Akonadi.Imap.Settings.intervalCheckTime
    return parent()->intervalCheckTime();
}

QStringList SettingsAdaptor::knownMailBoxes()
{
    // handle method call org.kde.Akonadi.Imap.Settings.knownMailBoxes
    return parent()->knownMailBoxes();
}

QString SettingsAdaptor::name()
{
    // handle method call org.kde.Akonadi.Imap.Settings.name
    return parent()->name();
}

QString SettingsAdaptor::overrideEncryption()
{
    // handle method call org.kde.Akonadi.Imap.Settings.overrideEncryption
    return parent()->overrideEncryption();
}

bool SettingsAdaptor::retrieveMetadataOnFolderListing()
{
    // handle method call org.kde.Akonadi.Imap.Settings.retrieveMetadataOnFolderListing
    return parent()->retrieveMetadataOnFolderListing();
}

QString SettingsAdaptor::safety()
{
    // handle method call org.kde.Akonadi.Imap.Settings.safety
    return parent()->safety();
}

void SettingsAdaptor::save()
{
    // handle method call org.kde.Akonadi.Imap.Settings.save
    parent()->save();
}

int SettingsAdaptor::sessionTimeout()
{
    // handle method call org.kde.Akonadi.Imap.Settings.sessionTimeout
    return parent()->sessionTimeout();
}

void SettingsAdaptor::setAccountIdentity(int in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setAccountIdentity
    parent()->setAccountIdentity(in0);
}

void SettingsAdaptor::setActivities(const QStringList &in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setActivities
    parent()->setActivities(in0);
}

void SettingsAdaptor::setActivitiesEnabled(bool in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setActivitiesEnabled
    parent()->setActivitiesEnabled(in0);
}

void SettingsAdaptor::setAlternateAuthentication(int in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setAlternateAuthentication
    parent()->setAlternateAuthentication(in0);
}

void SettingsAdaptor::setAuthentication(int in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setAuthentication
    parent()->setAuthentication(in0);
}

void SettingsAdaptor::setAutomaticExpungeEnabled(bool in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setAutomaticExpungeEnabled
    parent()->setAutomaticExpungeEnabled(in0);
}

void SettingsAdaptor::setDisconnectedModeEnabled(bool in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setDisconnectedModeEnabled
    parent()->setDisconnectedModeEnabled(in0);
}

void SettingsAdaptor::setIdleRidPath(const QStringList &in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setIdleRidPath
    parent()->setIdleRidPath(in0);
}

void SettingsAdaptor::setImapPort(int in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setImapPort
    parent()->setImapPort(in0);
}

void SettingsAdaptor::setImapServer(const QString &in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setImapServer
    parent()->setImapServer(in0);
}

void SettingsAdaptor::setIntervalCheckEnabled(bool in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setIntervalCheckEnabled
    parent()->setIntervalCheckEnabled(in0);
}

void SettingsAdaptor::setIntervalCheckTime(int in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setIntervalCheckTime
    parent()->setIntervalCheckTime(in0);
}

void SettingsAdaptor::setKnownMailBoxes(const QStringList &in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setKnownMailBoxes
    parent()->setKnownMailBoxes(in0);
}

void SettingsAdaptor::setName(const QString &in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setName
    parent()->setName(in0);
}

void SettingsAdaptor::setOverrideEncryption(const QString &in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setOverrideEncryption
    parent()->setOverrideEncryption(in0);
}

void SettingsAdaptor::setRetrieveMetadataOnFolderListing(bool in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setRetrieveMetadataOnFolderListing
    parent()->setRetrieveMetadataOnFolderListing(in0);
}

void SettingsAdaptor::setSafety(const QString &in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setSafety
    parent()->setSafety(in0);
}

void SettingsAdaptor::setSessionTimeout(int in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setSessionTimeout
    parent()->setSessionTimeout(in0);
}

void SettingsAdaptor::setSieveAlternateUrl(const QString &in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setSieveAlternateUrl
    parent()->setSieveAlternateUrl(in0);
}

void SettingsAdaptor::setSieveCustomAuthentification(const QString &in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setSieveCustomAuthentification
    parent()->setSieveCustomAuthentification(in0);
}

void SettingsAdaptor::setSieveCustomUsername(const QString &in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setSieveCustomUsername
    parent()->setSieveCustomUsername(in0);
}

void SettingsAdaptor::setSievePort(int in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setSievePort
    parent()->setSievePort(in0);
}

void SettingsAdaptor::setSieveReuseConfig(bool in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setSieveReuseConfig
    parent()->setSieveReuseConfig(in0);
}

void SettingsAdaptor::setSieveSupport(bool in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setSieveSupport
    parent()->setSieveSupport(in0);
}

void SettingsAdaptor::setSieveVacationFilename(const QString &in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setSieveVacationFilename
    parent()->setSieveVacationFilename(in0);
}

void SettingsAdaptor::setSubscriptionEnabled(bool in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setSubscriptionEnabled
    parent()->setSubscriptionEnabled(in0);
}

void SettingsAdaptor::setTrashCollection(qlonglong in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setTrashCollection
    parent()->setTrashCollection(in0);
}

void SettingsAdaptor::setTrashCollectionMigrated(bool in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setTrashCollectionMigrated
    parent()->setTrashCollectionMigrated(in0);
}

void SettingsAdaptor::setUseDefaultIdentity(bool in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setUseDefaultIdentity
    parent()->setUseDefaultIdentity(in0);
}

void SettingsAdaptor::setUseProxy(bool in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setUseProxy
    parent()->setUseProxy(in0);
}

void SettingsAdaptor::setUserName(const QString &in0)
{
    // handle method call org.kde.Akonadi.Imap.Settings.setUserName
    parent()->setUserName(in0);
}

QString SettingsAdaptor::sieveAlternateUrl()
{
    // handle method call org.kde.Akonadi.Imap.Settings.sieveAlternateUrl
    return parent()->sieveAlternateUrl();
}

QString SettingsAdaptor::sieveCustomAuthentification()
{
    // handle method call org.kde.Akonadi.Imap.Settings.sieveCustomAuthentification
    return parent()->sieveCustomAuthentification();
}

QString SettingsAdaptor::sieveCustomUsername()
{
    // handle method call org.kde.Akonadi.Imap.Settings.sieveCustomUsername
    return parent()->sieveCustomUsername();
}

int SettingsAdaptor::sievePort()
{
    // handle method call org.kde.Akonadi.Imap.Settings.sievePort
    return parent()->sievePort();
}

bool SettingsAdaptor::sieveReuseConfig()
{
    // handle method call org.kde.Akonadi.Imap.Settings.sieveReuseConfig
    return parent()->sieveReuseConfig();
}

bool SettingsAdaptor::sieveSupport()
{
    // handle method call org.kde.Akonadi.Imap.Settings.sieveSupport
    return parent()->sieveSupport();
}

QString SettingsAdaptor::sieveVacationFilename()
{
    // handle method call org.kde.Akonadi.Imap.Settings.sieveVacationFilename
    return parent()->sieveVacationFilename();
}

bool SettingsAdaptor::subscriptionEnabled()
{
    // handle method call org.kde.Akonadi.Imap.Settings.subscriptionEnabled
    return parent()->subscriptionEnabled();
}

qlonglong SettingsAdaptor::trashCollection()
{
    // handle method call org.kde.Akonadi.Imap.Settings.trashCollection
    return parent()->trashCollection();
}

bool SettingsAdaptor::trashCollectionMigrated()
{
    // handle method call org.kde.Akonadi.Imap.Settings.trashCollectionMigrated
    return parent()->trashCollectionMigrated();
}

bool SettingsAdaptor::useDefaultIdentity()
{
    // handle method call org.kde.Akonadi.Imap.Settings.useDefaultIdentity
    return parent()->useDefaultIdentity();
}

bool SettingsAdaptor::useProxy()
{
    // handle method call org.kde.Akonadi.Imap.Settings.useProxy
    return parent()->useProxy();
}

QString SettingsAdaptor::userName()
{
    // handle method call org.kde.Akonadi.Imap.Settings.userName
    return parent()->userName();
}


#include "moc_settingsadaptor.cpp"
