/********************************************************************************
** Form generated from reading UI file 'vcarddiragentsettingswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VCARDDIRAGENTSETTINGSWIDGET_H
#define UI_VCARDDIRAGENTSETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_VcardDirsAgentSettingsWidget
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *ktabwidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout_4;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    KUrlRequester *kcfg_Path;
    QLabel *label_3;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *kcfg_ReadOnly;
    QLabel *label_2;
    QSpacerItem *verticalSpacer;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout_5;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout_2;
    QLabel *autosaveLabel;
    QSpinBox *kcfg_AutosaveInterval;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *VcardDirsAgentSettingsWidget)
    {
        if (VcardDirsAgentSettingsWidget->objectName().isEmpty())
            VcardDirsAgentSettingsWidget->setObjectName("VcardDirsAgentSettingsWidget");
        VcardDirsAgentSettingsWidget->resize(547, 386);
        verticalLayout = new QVBoxLayout(VcardDirsAgentSettingsWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        ktabwidget = new QTabWidget(VcardDirsAgentSettingsWidget);
        ktabwidget->setObjectName("ktabwidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_4 = new QVBoxLayout(tab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        groupBox_2 = new QGroupBox(tab);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_3 = new QVBoxLayout(groupBox_2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        kcfg_Path = new KUrlRequester(groupBox_2);
        kcfg_Path->setObjectName("kcfg_Path");

        horizontalLayout->addWidget(kcfg_Path);


        verticalLayout_3->addLayout(horizontalLayout);

        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");
        label_3->setWordWrap(true);

        verticalLayout_3->addWidget(label_3);


        verticalLayout_4->addWidget(groupBox_2);

        groupBox = new QGroupBox(tab);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_ReadOnly = new QCheckBox(groupBox);
        kcfg_ReadOnly->setObjectName("kcfg_ReadOnly");

        verticalLayout_2->addWidget(kcfg_ReadOnly);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        verticalLayout_2->addWidget(label_2);


        verticalLayout_4->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(20, 4, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);

        ktabwidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout_5 = new QVBoxLayout(tab_2);
        verticalLayout_5->setObjectName("verticalLayout_5");
        label_4 = new QLabel(tab_2);
        label_4->setObjectName("label_4");
        label_4->setWordWrap(true);

        verticalLayout_5->addWidget(label_4);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        autosaveLabel = new QLabel(tab_2);
        autosaveLabel->setObjectName("autosaveLabel");

        horizontalLayout_2->addWidget(autosaveLabel);

        kcfg_AutosaveInterval = new QSpinBox(tab_2);
        kcfg_AutosaveInterval->setObjectName("kcfg_AutosaveInterval");
        kcfg_AutosaveInterval->setMinimum(0);
        kcfg_AutosaveInterval->setValue(1);

        horizontalLayout_2->addWidget(kcfg_AutosaveInterval);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout_5->addLayout(horizontalLayout_2);

        verticalSpacer_2 = new QSpacerItem(20, 138, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_2);

        ktabwidget->addTab(tab_2, QString());

        verticalLayout->addWidget(ktabwidget);

#if QT_CONFIG(shortcut)
        label->setBuddy(kcfg_Path);
#endif // QT_CONFIG(shortcut)

        retranslateUi(VcardDirsAgentSettingsWidget);
        QObject::connect(kcfg_ReadOnly, &QCheckBox::toggled, kcfg_AutosaveInterval, &QSpinBox::setDisabled);
        QObject::connect(kcfg_ReadOnly, &QCheckBox::toggled, autosaveLabel, &QLabel::setDisabled);

        ktabwidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(VcardDirsAgentSettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *VcardDirsAgentSettingsWidget)
    {
        groupBox_2->setTitle(tr2i18n("Directory Name", nullptr));
        label->setText(tr2i18n("Di&rectory:", nullptr));
        label_3->setText(tr2i18n("Select the directory whose contents should be represented by this resource. If the directory does not exist, it will be created.", nullptr));
        groupBox->setTitle(tr2i18n("Access Rights", nullptr));
        kcfg_ReadOnly->setText(tr2i18n("Read only", nullptr));
        label_2->setText(tr2i18n("If read-only mode is enabled, no changes will be written to the directory selected above. Read-only mode will be automatically enabled if you do not have write access to the directory.", nullptr));
        ktabwidget->setTabText(ktabwidget->indexOf(tab), tr2i18n("Directory", nullptr));
        label_4->setText(tr2i18n("The options on this page allow you to change parameters that balance data safety and consistency against performance. In general you should be careful with changing anything here, the defaults are good enough in most cases.", nullptr));
        autosaveLabel->setText(tr2i18n("Autosave delay:", nullptr));
        ktabwidget->setTabText(ktabwidget->indexOf(tab_2), tr2i18n("Tuning", nullptr));
        (void)VcardDirsAgentSettingsWidget;
    } // retranslateUi

};

namespace Ui {
    class VcardDirsAgentSettingsWidget: public Ui_VcardDirsAgentSettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VCARDDIRAGENTSETTINGSWIDGET_H

