/********************************************************************************
** Form generated from reading UI file 'icaldirsagentsettingswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ICALDIRSAGENTSETTINGSWIDGET_H
#define UI_ICALDIRSAGENTSETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_IcalDirsAgentSettingsWidget
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *ktabwidget;
    QWidget *tab;
    QFormLayout *verticalLayout_4;
    QLabel *label;
    KUrlRequester *kcfg_Path;
    QLabel *pathLabel;
    QCheckBox *kcfg_ReadOnly;
    QLabel *readOnlyLabel;
    QSpacerItem *verticalSpacer;
    QWidget *tab_2;
    QFormLayout *verticalLayout_5;
    QLabel *runingLabel;
    QLabel *autosaveLabel;
    QSpinBox *kcfg_AutosaveInterval;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *IcalDirsAgentSettingsWidget)
    {
        if (IcalDirsAgentSettingsWidget->objectName().isEmpty())
            IcalDirsAgentSettingsWidget->setObjectName("IcalDirsAgentSettingsWidget");
        IcalDirsAgentSettingsWidget->resize(547, 386);
        verticalLayout = new QVBoxLayout(IcalDirsAgentSettingsWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        ktabwidget = new QTabWidget(IcalDirsAgentSettingsWidget);
        ktabwidget->setObjectName("ktabwidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_4 = new QFormLayout(tab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        label = new QLabel(tab);
        label->setObjectName("label");

        verticalLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        kcfg_Path = new KUrlRequester(tab);
        kcfg_Path->setObjectName("kcfg_Path");

        verticalLayout_4->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_Path);

        pathLabel = new QLabel(tab);
        pathLabel->setObjectName("pathLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(pathLabel->sizePolicy().hasHeightForWidth());
        pathLabel->setSizePolicy(sizePolicy);
        pathLabel->setWordWrap(true);

        verticalLayout_4->setWidget(1, QFormLayout::ItemRole::FieldRole, pathLabel);

        kcfg_ReadOnly = new QCheckBox(tab);
        kcfg_ReadOnly->setObjectName("kcfg_ReadOnly");

        verticalLayout_4->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_ReadOnly);

        readOnlyLabel = new QLabel(tab);
        readOnlyLabel->setObjectName("readOnlyLabel");
        sizePolicy.setHeightForWidth(readOnlyLabel->sizePolicy().hasHeightForWidth());
        readOnlyLabel->setSizePolicy(sizePolicy);
        readOnlyLabel->setVisible(true);
        readOnlyLabel->setWordWrap(true);

        verticalLayout_4->setWidget(3, QFormLayout::ItemRole::FieldRole, readOnlyLabel);

        verticalSpacer = new QSpacerItem(20, 4, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->setItem(4, QFormLayout::ItemRole::FieldRole, verticalSpacer);

        ktabwidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout_5 = new QFormLayout(tab_2);
        verticalLayout_5->setObjectName("verticalLayout_5");
        runingLabel = new QLabel(tab_2);
        runingLabel->setObjectName("runingLabel");
        runingLabel->setWordWrap(true);

        verticalLayout_5->setWidget(0, QFormLayout::ItemRole::SpanningRole, runingLabel);

        autosaveLabel = new QLabel(tab_2);
        autosaveLabel->setObjectName("autosaveLabel");

        verticalLayout_5->setWidget(1, QFormLayout::ItemRole::LabelRole, autosaveLabel);

        kcfg_AutosaveInterval = new QSpinBox(tab_2);
        kcfg_AutosaveInterval->setObjectName("kcfg_AutosaveInterval");
        kcfg_AutosaveInterval->setMinimum(0);
        kcfg_AutosaveInterval->setValue(1);

        verticalLayout_5->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_AutosaveInterval);

        verticalSpacer_2 = new QSpacerItem(20, 138, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->setItem(2, QFormLayout::ItemRole::FieldRole, verticalSpacer_2);

        ktabwidget->addTab(tab_2, QString());

        verticalLayout->addWidget(ktabwidget);

#if QT_CONFIG(shortcut)
        label->setBuddy(kcfg_Path);
        autosaveLabel->setBuddy(kcfg_Path);
#endif // QT_CONFIG(shortcut)

        retranslateUi(IcalDirsAgentSettingsWidget);
        QObject::connect(kcfg_ReadOnly, &QCheckBox::toggled, kcfg_AutosaveInterval, &QSpinBox::setDisabled);
        QObject::connect(kcfg_ReadOnly, &QCheckBox::toggled, autosaveLabel, &QLabel::setDisabled);

        ktabwidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(IcalDirsAgentSettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *IcalDirsAgentSettingsWidget)
    {
        label->setText(tr2i18n("Di&rectory:", nullptr));
        pathLabel->setText(tr2i18n("Select the directory whose contents should be represented by this resource. If the directory does not exist, it will be created.", nullptr));
        kcfg_ReadOnly->setText(tr2i18n("Read only", nullptr));
        readOnlyLabel->setText(tr2i18n("When read-only mode is enabled, no changes will be written. Read-only mode is automatically enabled when the selected file does not support write access.", nullptr));
        ktabwidget->setTabText(ktabwidget->indexOf(tab), tr2i18n("Directory", nullptr));
        runingLabel->setText(tr2i18n("The options on this page allow you to change parameters that balance data safety and consistency against performance. In general you should be careful with changing anything here, the defaults are good enough in most cases.", nullptr));
        autosaveLabel->setText(tr2i18n("Autosave delay:", nullptr));
        ktabwidget->setTabText(ktabwidget->indexOf(tab_2), tr2i18n("Tuning", nullptr));
        (void)IcalDirsAgentSettingsWidget;
    } // retranslateUi

};

namespace Ui {
    class IcalDirsAgentSettingsWidget: public Ui_IcalDirsAgentSettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ICALDIRSAGENTSETTINGSWIDGET_H

