/****************************************************************************
** Meta object code from reading C++ file 'sessionpool.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdepim-runtime-26.04.2/resources/imap/sessionpool.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sessionpool.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11SessionPoolE_t {};
} // unnamed namespace

template <> constexpr inline auto SessionPool::qt_create_metaobjectdata<qt_meta_tag_ZN11SessionPoolE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SessionPool",
        "connectionLost",
        "",
        "KIMAP::Session*",
        "session",
        "sessionRequestDone",
        "requestNumber",
        "errorCode",
        "errorString",
        "connectDone",
        "disconnectDone",
        "processPendingRequests",
        "onPasswordRequestDone",
        "resultType",
        "password",
        "onLoginDone",
        "KJob*",
        "job",
        "onCapabilitiesTestDone",
        "onNamespacesTestDone",
        "onIdDone",
        "onSessionDestroyed",
        "ErrorCodes",
        "NoError",
        "PasswordRequestError",
        "ReconnectNeededError",
        "EncryptionError",
        "LoginFailError",
        "CapabilitiesTestError",
        "IncompatibleServerError",
        "NoAvailableSessionError",
        "CouldNotConnectError",
        "CancelledError"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'connectionLost'
        QtMocHelpers::SignalData<void(KIMAP::Session *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sessionRequestDone'
        QtMocHelpers::SignalData<void(qint64, KIMAP::Session *, int, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 6 }, { 0x80000000 | 3, 4 }, { QMetaType::Int, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'sessionRequestDone'
        QtMocHelpers::SignalData<void(qint64, KIMAP::Session *, int)>(5, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::LongLong, 6 }, { 0x80000000 | 3, 4 }, { QMetaType::Int, 7 },
        }}),
        // Signal 'sessionRequestDone'
        QtMocHelpers::SignalData<void(qint64, KIMAP::Session *)>(5, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::LongLong, 6 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'connectDone'
        QtMocHelpers::SignalData<void(int, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'connectDone'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'connectDone'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'disconnectDone'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'processPendingRequests'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPasswordRequestDone'
        QtMocHelpers::SlotData<void(int, const QString &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 13 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'onLoginDone'
        QtMocHelpers::SlotData<void(KJob *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'onCapabilitiesTestDone'
        QtMocHelpers::SlotData<void(KJob *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'onNamespacesTestDone'
        QtMocHelpers::SlotData<void(KJob *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'onIdDone'
        QtMocHelpers::SlotData<void(KJob *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'onSessionDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ErrorCodes'
        QtMocHelpers::EnumData<enum ErrorCodes>(22, 22, QMC::EnumFlags{}).add({
            {   23, ErrorCodes::NoError },
            {   24, ErrorCodes::PasswordRequestError },
            {   25, ErrorCodes::ReconnectNeededError },
            {   26, ErrorCodes::EncryptionError },
            {   27, ErrorCodes::LoginFailError },
            {   28, ErrorCodes::CapabilitiesTestError },
            {   29, ErrorCodes::IncompatibleServerError },
            {   30, ErrorCodes::NoAvailableSessionError },
            {   31, ErrorCodes::CouldNotConnectError },
            {   32, ErrorCodes::CancelledError },
        }),
    };
    return QtMocHelpers::metaObjectData<SessionPool, qt_meta_tag_ZN11SessionPoolE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SessionPool::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SessionPoolE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SessionPoolE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11SessionPoolE_t>.metaTypes,
    nullptr
} };

void SessionPool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SessionPool *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->connectionLost((*reinterpret_cast<std::add_pointer_t<KIMAP::Session*>>(_a[1]))); break;
        case 1: _t->sessionRequestDone((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KIMAP::Session*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 2: _t->sessionRequestDone((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KIMAP::Session*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 3: _t->sessionRequestDone((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KIMAP::Session*>>(_a[2]))); break;
        case 4: _t->connectDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->connectDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->connectDone(); break;
        case 7: _t->disconnectDone(); break;
        case 8: _t->processPendingRequests(); break;
        case 9: _t->onPasswordRequestDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->onLoginDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 11: _t->onCapabilitiesTestDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 12: _t->onNamespacesTestDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 13: _t->onIdDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 14: _t->onSessionDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIMAP::Session* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIMAP::Session* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIMAP::Session* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIMAP::Session* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SessionPool::*)(KIMAP::Session * )>(_a, &SessionPool::connectionLost, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionPool::*)(qint64 , KIMAP::Session * , int , const QString & )>(_a, &SessionPool::sessionRequestDone, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionPool::*)(int , const QString & )>(_a, &SessionPool::connectDone, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionPool::*)()>(_a, &SessionPool::disconnectDone, 7))
            return;
    }
}

const QMetaObject *SessionPool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SessionPool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SessionPoolE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SessionPool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void SessionPool::connectionLost(KIMAP::Session * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void SessionPool::sessionRequestDone(qint64 _t1, KIMAP::Session * _t2, int _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 4
void SessionPool::connectDone(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 7
void SessionPool::disconnectDone()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
