/********************************************************************************
** Form generated from reading UI file 'lockfilepage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LOCKFILEPAGE_H
#define UI_LOCKFILEPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_LockFilePage
{
public:
    QGridLayout *gridLayout_2;
    QLabel *label;
    QGroupBox *kcfg_LockfileMethod;
    QGridLayout *gridLayout;
    QRadioButton *procmail;
    QRadioButton *mutt_dotlock;
    QRadioButton *mutt_dotlock_privileged;
    QRadioButton *none;
    QComboBox *kcfg_Lockfile;
    QLabel *label_2;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *LockFilePage)
    {
        if (LockFilePage->objectName().isEmpty())
            LockFilePage->setObjectName("LockFilePage");
        LockFilePage->resize(317, 369);
        gridLayout_2 = new QGridLayout(LockFilePage);
        gridLayout_2->setObjectName("gridLayout_2");
        label = new QLabel(LockFilePage);
        label->setObjectName("label");
        label->setWordWrap(true);

        gridLayout_2->addWidget(label, 0, 0, 1, 3);

        kcfg_LockfileMethod = new QGroupBox(LockFilePage);
        kcfg_LockfileMethod->setObjectName("kcfg_LockfileMethod");
        gridLayout = new QGridLayout(kcfg_LockfileMethod);
        gridLayout->setObjectName("gridLayout");
        procmail = new QRadioButton(kcfg_LockfileMethod);
        procmail->setObjectName("procmail");
        procmail->setChecked(false);

        gridLayout->addWidget(procmail, 0, 0, 1, 1);

        mutt_dotlock = new QRadioButton(kcfg_LockfileMethod);
        mutt_dotlock->setObjectName("mutt_dotlock");

        gridLayout->addWidget(mutt_dotlock, 1, 0, 1, 1);

        mutt_dotlock_privileged = new QRadioButton(kcfg_LockfileMethod);
        mutt_dotlock_privileged->setObjectName("mutt_dotlock_privileged");

        gridLayout->addWidget(mutt_dotlock_privileged, 2, 0, 1, 2);

        none = new QRadioButton(kcfg_LockfileMethod);
        none->setObjectName("none");
        none->setChecked(true);

        gridLayout->addWidget(none, 3, 0, 1, 2);

        kcfg_Lockfile = new QComboBox(kcfg_LockfileMethod);
        kcfg_Lockfile->addItem(QString());
        kcfg_Lockfile->setObjectName("kcfg_Lockfile");
        kcfg_Lockfile->setEnabled(false);
        kcfg_Lockfile->setEditable(true);

        gridLayout->addWidget(kcfg_Lockfile, 0, 1, 1, 1);

        label_2 = new QLabel(kcfg_LockfileMethod);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        gridLayout->addWidget(label_2, 4, 0, 1, 2);


        gridLayout_2->addWidget(kcfg_LockfileMethod, 1, 0, 1, 3);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 2, 1, 1, 1);

        QWidget::setTabOrder(procmail, kcfg_Lockfile);
        QWidget::setTabOrder(kcfg_Lockfile, mutt_dotlock);
        QWidget::setTabOrder(mutt_dotlock, mutt_dotlock_privileged);
        QWidget::setTabOrder(mutt_dotlock_privileged, none);

        retranslateUi(LockFilePage);
        QObject::connect(procmail, &QRadioButton::toggled, kcfg_Lockfile, &QComboBox::setEnabled);

        QMetaObject::connectSlotsByName(LockFilePage);
    } // setupUi

    void retranslateUi(QWidget *LockFilePage)
    {
        LockFilePage->setWindowTitle(tr2i18n("MBox Settings", nullptr));
        label->setText(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Select a method to lock the mbox file when data is read from or written to the file.</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Note</span>: For some methods you might need to install additional software before they can be used.</p></body></html>", nullptr));
        kcfg_LockfileMethod->setTitle(QString());
        procmail->setText(tr2i18n("Procmail loc&kfile", nullptr));
        mutt_dotlock->setText(tr2i18n("&Mutt dotlock", nullptr));
        mutt_dotlock_privileged->setText(tr2i18n("M&utt dotlock privileged", nullptr));
        none->setText(tr2i18n("Non&e", nullptr));
        kcfg_Lockfile->setItemText(0, tr2i18n(".lock", nullptr));

        label_2->setText(tr2i18n("None, the default configuration, should be safe in most cases.  However, if programs that do not make use of Akonadi are also accessing the configured mbox file, you will need to set an appropriate locking method. Note that if this is the case, the resource and the other programs must all use the same locking method.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class LockFilePage: public Ui_LockFilePage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LOCKFILEPAGE_H

