/********************************************************************************
** Form generated from reading UI file 'settings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_H
#define UI_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    KUrlRequester *kcfg_Path;
    QCheckBox *kcfg_ReadOnly;
    QSpacerItem *verticalSpacer;
    QLabel *statusLabel;

    void setupUi(QWidget *ConfigWidget)
    {
        if (ConfigWidget->objectName().isEmpty())
            ConfigWidget->setObjectName("ConfigWidget");
        ConfigWidget->resize(400, 290);
        verticalLayout = new QVBoxLayout(ConfigWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(ConfigWidget);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_2 = new QVBoxLayout(tab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label = new QLabel(tab);
        label->setObjectName("label");

        verticalLayout_2->addWidget(label);

        kcfg_Path = new KUrlRequester(tab);
        kcfg_Path->setObjectName("kcfg_Path");

        verticalLayout_2->addWidget(kcfg_Path);

        kcfg_ReadOnly = new QCheckBox(tab);
        kcfg_ReadOnly->setObjectName("kcfg_ReadOnly");

        verticalLayout_2->addWidget(kcfg_ReadOnly);

        verticalSpacer = new QSpacerItem(20, 141, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        tabWidget->addTab(tab, QString());

        verticalLayout->addWidget(tabWidget);

        statusLabel = new QLabel(ConfigWidget);
        statusLabel->setObjectName("statusLabel");
        statusLabel->setWordWrap(true);

        verticalLayout->addWidget(statusLabel);


        retranslateUi(ConfigWidget);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *ConfigWidget)
    {
        ConfigWidget->setWindowTitle(tr2i18n("Mail Directory Settings", nullptr));
        label->setText(tr2i18n("Select the folder containing the maildir information:", nullptr));
        kcfg_ReadOnly->setText(tr2i18n("Open in read-only mode", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("Maildir", nullptr));
        statusLabel->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class ConfigWidget: public Ui_ConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGS_H

