/****************************************************************************
** Meta object code from reading C++ file 'settingsadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "settingsadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'settingsadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15SettingsAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto SettingsAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN15SettingsAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SettingsAdaptor",
        "D-Bus Interface",
        "org.kde.Akonadi.Google.Settings",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Akonadi.Google.Settings\">\n    <metho"
        "d name=\"save\"/>\n    <method name=\"account\">\n      <arg direc"
        "tion=\"out\" type=\"s\"/>\n    </method>\n    <method name=\"setAc"
        "count\">\n      <arg direction=\"in\" type=\"s\"/>\n    </method>\n"
        "    <method name=\"accountName\">\n      <arg direction=\"out\" ty"
        "pe=\"s\"/>\n    </method>\n    <method name=\"setAccountName\">\n "
        "     <arg direction=\"in\" type=\"s\"/>\n    </method>\n    <metho"
        "d name=\"accountId\">\n      <arg direction=\"out\" type=\"i\"/>\n"
        "    </method>\n    <method name=\"setAccountId\">\n      <arg dire"
        "ction=\"in\" type=\"i\"/>\n    </method>\n    <method name=\"calen"
        "dars\">\n      <arg direction=\"out\" type=\"as\"/>\n    </method>"
        "\n    <method name=\"setCalendars\">\n      <arg direction=\"in\" "
        "type=\"as\"/>\n    </method>\n    <method name=\"taskLists\">\n   "
        "   <arg direction=\"out\" type=\"as\"/>\n    </method>\n    <metho"
        "d name=\"setTaskLists\">\n      <arg direction=\"in\" type=\"as\"/"
        ">\n    </method>\n    <method name=\"eventsSince\">\n      <arg di"
        "rection=\"out\" type=\"s\"/>\n    </method>\n    <method name=\"se"
        "tEventsSince\">\n      <arg direction=\"in\" type=\"s\"/>\n    </m"
        "ethod>\n    <method name=\"enableIntervalCheck\">\n      <arg dire"
        "ction=\"out\" type=\"b\"/>\n    </method>\n    <method name=\"setE"
        "nableIntervalCheck\">\n      <arg direction=\"in\" type=\"b\"/>\n "
        "   </method>\n    <method name=\"intervalCheckTime\">\n      <arg "
        "direction=\"out\" type=\"i\"/>\n    </method>\n    <method name=\""
        "setIntervalCheckTime\">\n      <arg direction=\"in\" type=\"i\"/>\n"
        "    </method>\n  </interface>\n",
        "account",
        "",
        "accountId",
        "accountName",
        "calendars",
        "enableIntervalCheck",
        "eventsSince",
        "intervalCheckTime",
        "save",
        "setAccount",
        "in0",
        "setAccountId",
        "setAccountName",
        "setCalendars",
        "setEnableIntervalCheck",
        "setEventsSince",
        "setIntervalCheckTime",
        "setTaskLists",
        "taskLists"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'account'
        QtMocHelpers::SlotData<QString()>(5, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'accountId'
        QtMocHelpers::SlotData<int()>(7, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'accountName'
        QtMocHelpers::SlotData<QString()>(8, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'calendars'
        QtMocHelpers::SlotData<QStringList()>(9, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'enableIntervalCheck'
        QtMocHelpers::SlotData<bool()>(10, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'eventsSince'
        QtMocHelpers::SlotData<QString()>(11, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'intervalCheckTime'
        QtMocHelpers::SlotData<int()>(12, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setAccount'
        QtMocHelpers::SlotData<void(const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'setAccountId'
        QtMocHelpers::SlotData<void(int)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'setAccountName'
        QtMocHelpers::SlotData<void(const QString &)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'setCalendars'
        QtMocHelpers::SlotData<void(const QStringList &)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 15 },
        }}),
        // Slot 'setEnableIntervalCheck'
        QtMocHelpers::SlotData<void(bool)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'setEventsSince'
        QtMocHelpers::SlotData<void(const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'setIntervalCheckTime'
        QtMocHelpers::SlotData<void(int)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'setTaskLists'
        QtMocHelpers::SlotData<void(const QStringList &)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 15 },
        }}),
        // Slot 'taskLists'
        QtMocHelpers::SlotData<QStringList()>(23, 6, QMC::AccessPublic, QMetaType::QStringList),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<SettingsAdaptor, qt_meta_tag_ZN15SettingsAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SettingsAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.metaTypes,
    nullptr
} };

void SettingsAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SettingsAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->account();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { int _r = _t->accountId();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->accountName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QStringList _r = _t->calendars();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->enableIntervalCheck();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->eventsSince();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->intervalCheckTime();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->save(); break;
        case 8: _t->setAccount((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->setAccountId((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->setAccountName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->setCalendars((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 12: _t->setEnableIntervalCheck((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setEventsSince((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->setIntervalCheckTime((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->setTaskLists((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 16: { QStringList _r = _t->taskLists();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *SettingsAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SettingsAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int SettingsAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
