// This file is generated by kconfig_compiler_kf6 from etesyncresource.kcfg.
// All changes you do to this file will be lost.

#include "settings.h"

#include <klocalizedstring.h>

Settings::Settings( KSharedConfig::Ptr config )
  : KConfigSkeleton( std::move( config ) )
{
  setCurrentGroup( QStringLiteral( "General" ) );

  mNameItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "name" ), mName );
  mNameItem->setLabel( i18n("name") );
  addItem( mNameItem, QStringLiteral( "name" ) );
  mBaseUrlItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "BaseUrl" ), mBaseUrl );
  mBaseUrlItem->setLabel( i18n("Server URL") );
  mBaseUrlItem->setToolTip( i18n("The URL of the EteSync server, should be something like https://myserver.org/") );
  mBaseUrlItem->setWhatsThis( i18n("The URL of the EteSync server, should be something like https://myserver.org/") );
  addItem( mBaseUrlItem, QStringLiteral( "BaseUrl" ) );
  mUsernameItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Username" ), mUsername );
  mUsernameItem->setLabel( i18nc("the username to login on server", "Username") );
  mUsernameItem->setToolTip( i18n("The username that is used to log into the EteSync server") );
  mUsernameItem->setWhatsThis( i18n("The username that is used to log into the EteSync server") );
  addItem( mUsernameItem, QStringLiteral( "Username" ) );
  mBasePathItem = new KConfigSkeleton::ItemPath( currentGroup(), QStringLiteral( "BasePath" ), mBasePath, QStringLiteral( "$HOME/.local/share/akonadi_etesync_resource" ) );
  mBasePathItem->setLabel( i18n("Path to base directory") );
  addItem( mBasePathItem, QStringLiteral( "BasePath" ) );
}

Settings::~Settings()
{
}

