// This file is generated by kconfig_compiler_kf6 from maildispatcheragent.kcfg.
// All changes you do to this file will be lost.
#ifndef SETTINGS_H
#define SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class Settings : public KConfigSkeleton
{
  public:

    static Settings *self();
    ~Settings() override;

    /**
      Set Outbox collection id
    */
    static
    void setOutbox( qint64 v )
    {
      if (!self()->isOutboxImmutable())
        self()->mOutbox = v;
    }

    /**
      Get Outbox collection id
    */
    static
    qint64 outbox()
    {
      return self()->mOutbox;
    }

    /**
      Is Outbox collection id Immutable
    */
    static
    bool isOutboxImmutable()
    {
      return self()->isImmutable( QStringLiteral( "Outbox" ) );
    }

    /**
      Get Item object corresponding to Outbox()
    */
    ItemLongLong *outboxItem()
    {
      return mOutboxItem;
    }

    /**
      Set Sent Mail collection id
    */
    static
    void setSentMail( qint64 v )
    {
      if (!self()->isSentMailImmutable())
        self()->mSentMail = v;
    }

    /**
      Get Sent Mail collection id
    */
    static
    qint64 sentMail()
    {
      return self()->mSentMail;
    }

    /**
      Is Sent Mail collection id Immutable
    */
    static
    bool isSentMailImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SentMail" ) );
    }

    /**
      Get Item object corresponding to SentMail()
    */
    ItemLongLong *sentMailItem()
    {
      return mSentMailItem;
    }

  protected:
    Settings();
    friend class SettingsHelper;


    // General
    qint64 mOutbox;
    qint64 mSentMail;

  private:
    ItemLongLong *mOutboxItem;
    ItemLongLong *mSentMailItem;
};

#endif

