/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.Google.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SETTINGSADAPTOR_H
#define SETTINGSADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "/build/kdepim-runtime/src/kdepim-runtime-26.04.2/resources/google-groupware/googlesettings.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Akonadi.Google.Settings
 */
class SettingsAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Akonadi.Google.Settings")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Akonadi.Google.Settings\">\n"
"    <method name=\"save\"/>\n"
"    <method name=\"account\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setAccount\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"accountName\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setAccountName\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"accountId\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setAccountId\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"calendars\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"setCalendars\">\n"
"      <arg direction=\"in\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"taskLists\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"setTaskLists\">\n"
"      <arg direction=\"in\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"eventsSince\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setEventsSince\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"enableIntervalCheck\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setEnableIntervalCheck\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"intervalCheckTime\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setIntervalCheckTime\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    SettingsAdaptor(GoogleSettings *parent);
    ~SettingsAdaptor() override;

    inline GoogleSettings *parent() const
    { return static_cast<GoogleSettings *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QString account();
    int accountId();
    QString accountName();
    QStringList calendars();
    bool enableIntervalCheck();
    QString eventsSince();
    int intervalCheckTime();
    void save();
    void setAccount(const QString &in0);
    void setAccountId(int in0);
    void setAccountName(const QString &in0);
    void setCalendars(const QStringList &in0);
    void setEnableIntervalCheck(bool in0);
    void setEventsSince(const QString &in0);
    void setIntervalCheckTime(int in0);
    void setTaskLists(const QStringList &in0);
    QStringList taskLists();
Q_SIGNALS: // SIGNALS
};

#endif
