/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.Birthdays.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "settingsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class SettingsAdaptor
 */

SettingsAdaptor::SettingsAdaptor(Settings *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

SettingsAdaptor::~SettingsAdaptor()
{
    // destructor
}

int SettingsAdaptor::alarmDays()
{
    // handle method call org.kde.Akonadi.Birthdays.Settings.alarmDays
    return parent()->alarmDays();
}

bool SettingsAdaptor::enableAlarm()
{
    // handle method call org.kde.Akonadi.Birthdays.Settings.enableAlarm
    return parent()->enableAlarm();
}

QStringList SettingsAdaptor::filterCategories()
{
    // handle method call org.kde.Akonadi.Birthdays.Settings.filterCategories
    return parent()->filterCategories();
}

bool SettingsAdaptor::filterOnCategories()
{
    // handle method call org.kde.Akonadi.Birthdays.Settings.filterOnCategories
    return parent()->filterOnCategories();
}

void SettingsAdaptor::save()
{
    // handle method call org.kde.Akonadi.Birthdays.Settings.save
    parent()->save();
}

void SettingsAdaptor::setAlarmDays(int in0)
{
    // handle method call org.kde.Akonadi.Birthdays.Settings.setAlarmDays
    parent()->setAlarmDays(in0);
}

void SettingsAdaptor::setEnableAlarm(bool in0)
{
    // handle method call org.kde.Akonadi.Birthdays.Settings.setEnableAlarm
    parent()->setEnableAlarm(in0);
}

void SettingsAdaptor::setFilterCategories(const QStringList &in0)
{
    // handle method call org.kde.Akonadi.Birthdays.Settings.setFilterCategories
    parent()->setFilterCategories(in0);
}

void SettingsAdaptor::setFilterOnCategories(bool in0)
{
    // handle method call org.kde.Akonadi.Birthdays.Settings.setFilterOnCategories
    parent()->setFilterOnCategories(in0);
}


#include "moc_settingsadaptor.cpp"
