/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.POP3.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SETTINGSADAPTOR_H
#define SETTINGSADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "settings.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Akonadi.POP3.Settings
 */
class SettingsAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Akonadi.POP3.Settings")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Akonadi.POP3.Settings\">\n"
"    <method name=\"save\"/>\n"
"    <method name=\"name\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setName\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"unitTestPassword\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setUnitTestPassword\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"login\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setLogin\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"host\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setHost\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"port\">\n"
"      <arg direction=\"out\" type=\"u\"/>\n"
"    </method>\n"
"    <method name=\"setPort\">\n"
"      <arg direction=\"in\" type=\"u\"/>\n"
"    </method>\n"
"    <method name=\"authenticationMethod\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setAuthenticationMethod\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"useSSL\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setUseSSL\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"useTLS\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setUseTLS\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"pipelining\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setPipelining\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"useProxy\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setUseProxy\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"leaveOnServer\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setLeaveOnServer\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"leaveOnServerDays\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setLeaveOnServerDays\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"leaveOnServerCount\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setLeaveOnServerCount\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"leaveOnServerSize\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setLeaveOnServerSize\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"filterOnServer\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setFilterOnServer\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"filterCheckSize\">\n"
"      <arg direction=\"out\" type=\"u\"/>\n"
"    </method>\n"
"    <method name=\"setFilterCheckSize\">\n"
"      <arg direction=\"in\" type=\"u\"/>\n"
"    </method>\n"
"    <method name=\"targetCollection\">\n"
"      <arg direction=\"out\" type=\"x\"/>\n"
"    </method>\n"
"    <method name=\"setTargetCollection\">\n"
"      <arg direction=\"in\" type=\"x\"/>\n"
"    </method>\n"
"    <method name=\"precommand\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setPrecommand\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"intervalCheckEnabled\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setIntervalCheckEnabled\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"intervalCheckInterval\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setIntervalCheckInterval\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"seenUidList\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"setSeenUidList\">\n"
"      <arg direction=\"in\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"seenUidTimeList\">\n"
"      <arg direction=\"out\" type=\"ai\"/>\n"
"      <annotation value=\"QList&lt;int&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </method>\n"
"    <method name=\"setSeenUidTimeList\">\n"
"      <arg direction=\"in\" type=\"ai\"/>\n"
"      <annotation value=\"QList&lt;int&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"    </method>\n"
"    <method name=\"downloadLater\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"setDownloadLater\">\n"
"      <arg direction=\"in\" type=\"as\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    SettingsAdaptor(Settings *parent);
    ~SettingsAdaptor() override;

    inline Settings *parent() const
    { return static_cast<Settings *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    int authenticationMethod();
    QStringList downloadLater();
    uint filterCheckSize();
    bool filterOnServer();
    QString host();
    bool intervalCheckEnabled();
    int intervalCheckInterval();
    bool leaveOnServer();
    int leaveOnServerCount();
    int leaveOnServerDays();
    int leaveOnServerSize();
    QString login();
    QString name();
    bool pipelining();
    uint port();
    QString precommand();
    void save();
    QStringList seenUidList();
    QList<int> seenUidTimeList();
    void setAuthenticationMethod(int in0);
    void setDownloadLater(const QStringList &in0);
    void setFilterCheckSize(uint in0);
    void setFilterOnServer(bool in0);
    void setHost(const QString &in0);
    void setIntervalCheckEnabled(bool in0);
    void setIntervalCheckInterval(int in0);
    void setLeaveOnServer(bool in0);
    void setLeaveOnServerCount(int in0);
    void setLeaveOnServerDays(int in0);
    void setLeaveOnServerSize(int in0);
    void setLogin(const QString &in0);
    void setName(const QString &in0);
    void setPipelining(bool in0);
    void setPort(uint in0);
    void setPrecommand(const QString &in0);
    void setSeenUidList(const QStringList &in0);
    void setSeenUidTimeList(const QList<int> &in0);
    void setTargetCollection(qlonglong in0);
    void setUnitTestPassword(const QString &in0);
    void setUseProxy(bool in0);
    void setUseSSL(bool in0);
    void setUseTLS(bool in0);
    qlonglong targetCollection();
    QString unitTestPassword();
    bool useProxy();
    bool useSSL();
    bool useTLS();
Q_SIGNALS: // SIGNALS
};

#endif
