/****************************************************************************
** Meta object code from reading C++ file 'ewsabstractauth.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kdepim-runtime-26.04.2/resources/ews/ewsclient/auth/ewsabstractauth.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ewsabstractauth.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15EwsAbstractAuthE_t {};
} // unnamed namespace

template <> constexpr inline auto EwsAbstractAuth::qt_create_metaobjectdata<qt_meta_tag_ZN15EwsAbstractAuthE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EwsAbstractAuth",
        "authSucceeded",
        "",
        "authFailed",
        "error",
        "requestAuthFailed",
        "requestWalletPassword",
        "ask",
        "requestWalletMap",
        "setWalletPassword",
        "password",
        "setWalletMap",
        "QMap<QString,QString>",
        "map"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'authSucceeded'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authFailed'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'requestAuthFailed'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestWalletPassword'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'requestWalletMap'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'setWalletPassword'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'setWalletMap'
        QtMocHelpers::SignalData<void(const QMap<QString,QString> &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EwsAbstractAuth, qt_meta_tag_ZN15EwsAbstractAuthE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EwsAbstractAuth::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15EwsAbstractAuthE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15EwsAbstractAuthE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15EwsAbstractAuthE_t>.metaTypes,
    nullptr
} };

void EwsAbstractAuth::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EwsAbstractAuth *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->authSucceeded(); break;
        case 1: _t->authFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->requestAuthFailed(); break;
        case 3: _t->requestWalletPassword((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->requestWalletMap(); break;
        case 5: _t->setWalletPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->setWalletMap((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EwsAbstractAuth::*)()>(_a, &EwsAbstractAuth::authSucceeded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EwsAbstractAuth::*)(const QString & )>(_a, &EwsAbstractAuth::authFailed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (EwsAbstractAuth::*)()>(_a, &EwsAbstractAuth::requestAuthFailed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (EwsAbstractAuth::*)(bool )>(_a, &EwsAbstractAuth::requestWalletPassword, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (EwsAbstractAuth::*)()>(_a, &EwsAbstractAuth::requestWalletMap, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (EwsAbstractAuth::*)(const QString & )>(_a, &EwsAbstractAuth::setWalletPassword, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (EwsAbstractAuth::*)(const QMap<QString,QString> & )>(_a, &EwsAbstractAuth::setWalletMap, 6))
            return;
    }
}

const QMetaObject *EwsAbstractAuth::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EwsAbstractAuth::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15EwsAbstractAuthE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int EwsAbstractAuth::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void EwsAbstractAuth::authSucceeded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EwsAbstractAuth::authFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void EwsAbstractAuth::requestAuthFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void EwsAbstractAuth::requestWalletPassword(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void EwsAbstractAuth::requestWalletMap()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void EwsAbstractAuth::setWalletPassword(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void EwsAbstractAuth::setWalletMap(const QMap<QString,QString> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
