// This file is generated by kconfig_compiler_kf6 from ewsresource.kcfg.
// All changes you do to this file will be lost.

#include "ewssettingsbase.h"

#include <klocalizedstring.h>

EwsSettingsBase::EwsSettingsBase( QObject *parent )
  : KConfigSkeleton()
{
  setParent(parent);
  setCurrentGroup( QStringLiteral( "General" ) );

  mBaseUrlItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "BaseUrl" ), mBaseUrl, QStringLiteral( "https://outlook.office365.com/EWS/Exchange.asmx" ) );
  mBaseUrlItem->setLabel( i18n("Server URL") );
  mBaseUrlItem->setToolTip( i18n("The URL of the Microsoft Exchange server, should be something like https://myserver.org/EWS/Exchange.asmx") );
  mBaseUrlItem->setWhatsThis( i18n("The URL of the Microsoft Exchange server, should be something like https://myserver.org/EWS/Exchange.asmx") );
  addItem( mBaseUrlItem, QStringLiteral( "BaseUrl" ) );
  mUsernameItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Username" ), mUsername );
  mUsernameItem->setLabel( i18nc("The username to login into the server", "Username") );
  mUsernameItem->setToolTip( i18n("The username that is used to log into the Microsoft Exchange server") );
  mUsernameItem->setWhatsThis( i18n("The username that is used to log into the Microsoft Exchange server") );
  addItem( mUsernameItem, QStringLiteral( "Username" ) );
  mDomainItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Domain" ), mDomain );
  mDomainItem->setLabel( i18n("Domain") );
  mDomainItem->setToolTip( i18n("The Active Directory domain the user belongs to") );
  mDomainItem->setWhatsThis( i18n("The Active Directory domain the user belongs to") );
  addItem( mDomainItem, QStringLiteral( "Domain" ) );
  mHasDomainItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HasDomain" ), mHasDomain, true );
  mHasDomainItem->setLabel( i18n("Use a domain name during authentication") );
  addItem( mHasDomainItem, QStringLiteral( "HasDomain" ) );
  mEmailItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Email" ), mEmail );
  mEmailItem->setLabel( i18nc("Account e-mail address", "E-mail") );
  mEmailItem->setToolTip( i18n("The primary e-mail address of this account") );
  mEmailItem->setWhatsThis( i18n("The primary e-mail address of this account") );
  addItem( mEmailItem, QStringLiteral( "Email" ) );
  mAutoDiscoveryItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AutoDiscovery" ), mAutoDiscovery );
  mAutoDiscoveryItem->setLabel( i18n("Server Autodiscovery") );
  mAutoDiscoveryItem->setToolTip( i18n("Attempt to automatically discover Exchange server address") );
  mAutoDiscoveryItem->setWhatsThis( i18n("Attempts to find out the Microsoft Exchange server address relevant to the supplied e-mail address.") );
  addItem( mAutoDiscoveryItem, QStringLiteral( "AutoDiscovery" ) );
  mPollIntervalItem = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "PollInterval" ), mPollInterval );
  mPollIntervalItem->setLabel( i18n("Poll Interval") );
  mPollIntervalItem->setToolTip( i18n("Sets the interval for checking for new mail") );
  mPollIntervalItem->setWhatsThis( i18n("Sets the interval for checking for new mail.") );
  addItem( mPollIntervalItem, QStringLiteral( "PollInterval" ) );
  mRetrievalMethodItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "RetrievalMethod" ), mRetrievalMethod );
  mRetrievalMethodItem->setLabel( i18n("Retrieval") );
  addItem( mRetrievalMethodItem, QStringLiteral( "RetrievalMethod" ) );
  mServerSubscriptionItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ServerSubscription" ), mServerSubscription );
  mServerSubscriptionItem->setLabel( i18n("Enable Server-Side Subscriptions") );
  addItem( mServerSubscriptionItem, QStringLiteral( "ServerSubscription" ) );
  QStringList defaultServerSubscriptionList;
  defaultServerSubscriptionList.append( QString::fromUtf8( "default" ) );

  mServerSubscriptionListItem = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "ServerSubscriptionList" ), mServerSubscriptionList, defaultServerSubscriptionList );
  mServerSubscriptionListItem->setLabel( i18n("List of folders to subscribe to") );
  addItem( mServerSubscriptionListItem, QStringLiteral( "ServerSubscriptionList" ) );
  mEnableNTLMv2Item = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EnableNTLMv2" ), mEnableNTLMv2, true );
  mEnableNTLMv2Item->setLabel( i18n("Enable NTLMv2 authentication") );
  addItem( mEnableNTLMv2Item, QStringLiteral( "EnableNTLMv2" ) );
  mUserAgentItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "UserAgent" ), mUserAgent );
  mUserAgentItem->setLabel( i18n("Forces a non-default User-Agent string") );
  addItem( mUserAgentItem, QStringLiteral( "UserAgent" ) );
  mAuthModeItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AuthMode" ), mAuthMode, QStringLiteral( "username-password" ) );
  mAuthModeItem->setLabel( i18n("AuthMode") );
  addItem( mAuthModeItem, QStringLiteral( "AuthMode" ) );
  mOAuth2AppIdItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "OAuth2AppId" ), mOAuth2AppId, QStringLiteral( "452b289a-7894-41d7-9cd4-d5275739fa27" ) );
  mOAuth2AppIdItem->setLabel( i18n("OAuth2 application identifier") );
  addItem( mOAuth2AppIdItem, QStringLiteral( "OAuth2AppId" ) );
  mOAuth2ReturnUriItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "OAuth2ReturnUri" ), mOAuth2ReturnUri, QStringLiteral( "urn:ietf:wg:oauth:2.0:oob" ) );
  mOAuth2ReturnUriItem->setLabel( i18n("OAuth2 return URI") );
  addItem( mOAuth2ReturnUriItem, QStringLiteral( "OAuth2ReturnUri" ) );
  mPKeyCertItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "PKeyCert" ), mPKeyCert );
  mPKeyCertItem->setLabel( i18n("Path to PKey authentication PEM certificate") );
  addItem( mPKeyCertItem, QStringLiteral( "PKeyCert" ) );
  mPKeyKeyItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "PKeyKey" ), mPKeyKey );
  mPKeyKeyItem->setLabel( i18n("Path to PKey authentication PEM private key") );
  addItem( mPKeyKeyItem, QStringLiteral( "PKeyKey" ) );
  mFolderSyncStateItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "FolderSyncState" ), mFolderSyncState );
  mFolderSyncStateItem->setLabel( i18n("FolderSyncState") );
  addItem( mFolderSyncStateItem, QStringLiteral( "FolderSyncState" ) );
  mEventSubscriptionIdItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "EventSubscriptionId" ), mEventSubscriptionId );
  mEventSubscriptionIdItem->setLabel( i18n("EventSubscriptionId") );
  addItem( mEventSubscriptionIdItem, QStringLiteral( "EventSubscriptionId" ) );
  mEventSubscriptionWatermarkItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "EventSubscriptionWatermark" ), mEventSubscriptionWatermark );
  mEventSubscriptionWatermarkItem->setLabel( i18n("EventSubscriptionWatermark") );
  addItem( mEventSubscriptionWatermarkItem, QStringLiteral( "EventSubscriptionWatermark" ) );
}

EwsSettingsBase::~EwsSettingsBase()
{
}

