/****************************************************************************
** Meta object code from reading C++ file 'singlefileresourcebase.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kdepim-runtime-26.04.2/resources/shared/singlefileresource/singlefileresourcebase.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'singlefileresourcebase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi22SingleFileResourceBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::SingleFileResourceBase::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi22SingleFileResourceBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::SingleFileResourceBase",
        "reloadFile",
        "QFuture<bool>",
        "",
        "readFile",
        "taskContext",
        "writeFile",
        "QVariant",
        "scheduleWrite",
        "handleProgress",
        "KJob*",
        "fileChanged",
        "fileName",
        "slotDownloadJobResult",
        "slotUploadJobResult"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'reloadFile'
        QtMocHelpers::SlotData<QFuture<bool>()>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'readFile'
        QtMocHelpers::SlotData<QFuture<bool>(bool)>(4, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'readFile'
        QtMocHelpers::SlotData<QFuture<bool>()>(4, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2),
        // Slot 'writeFile'
        QtMocHelpers::SlotData<void(bool)>(6, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'writeFile'
        QtMocHelpers::SlotData<void()>(6, 3, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'writeFile'
        QtMocHelpers::SlotData<void(const QVariant &)>(6, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 5 },
        }}),
        // Slot 'scheduleWrite'
        QtMocHelpers::SlotData<void()>(8, 3, QMC::AccessProtected, QMetaType::Void),
        // Slot 'handleProgress'
        QtMocHelpers::SlotData<void(KJob *, unsigned long)>(9, 3, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 10, 3 }, { QMetaType::ULong, 3 },
        }}),
        // Slot 'fileChanged'
        QtMocHelpers::SlotData<void(const QString &)>(11, 3, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'slotDownloadJobResult'
        QtMocHelpers::SlotData<void(KJob *)>(13, 3, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 10, 3 },
        }}),
        // Slot 'slotUploadJobResult'
        QtMocHelpers::SlotData<void(KJob *)>(14, 3, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 10, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SingleFileResourceBase, qt_meta_tag_ZN7Akonadi22SingleFileResourceBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::SingleFileResourceBase::staticMetaObject = { {
    QMetaObject::SuperData::link<ResourceBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi22SingleFileResourceBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi22SingleFileResourceBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi22SingleFileResourceBaseE_t>.metaTypes,
    nullptr
} };

void Akonadi::SingleFileResourceBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SingleFileResourceBase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QFuture<bool> _r = _t->reloadFile();
            if (_a[0]) *reinterpret_cast<QFuture<bool>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QFuture<bool> _r = _t->readFile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QFuture<bool>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QFuture<bool> _r = _t->readFile();
            if (_a[0]) *reinterpret_cast<QFuture<bool>*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->writeFile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->writeFile(); break;
        case 5: _t->writeFile((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 6: _t->scheduleWrite(); break;
        case 7: _t->handleProgress((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2]))); break;
        case 8: _t->fileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->slotDownloadJobResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 10: _t->slotUploadJobResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *Akonadi::SingleFileResourceBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::SingleFileResourceBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi22SingleFileResourceBaseE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "AgentBase::Observer"))
        return static_cast< AgentBase::Observer*>(this);
    return ResourceBase::qt_metacast(_clname);
}

int Akonadi::SingleFileResourceBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ResourceBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
