// This file is generated by kconfig_compiler_kf6 from contactsresource.kcfg.
// All changes you do to this file will be lost.
#ifndef CONTACTSRESOURCESETTINGS_H
#define CONTACTSRESOURCESETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class ContactsResourceSettings : public KConfigSkeleton
{
  public:

    static ContactsResourceSettings *self();
    static void instance(const QString& cfgfilename);
    static void instance(KSharedConfig::Ptr config);
    ~ContactsResourceSettings() override;

    /**
      Set Path to contacts directory
    */
    static
    void setPath( const QString & v )
    {
      if (!self()->isPathImmutable())
        self()->mPath = v;
    }

    /**
      Get Path to contacts directory
    */
    static
    QString path()
    {
      return self()->mPath;
    }

    /**
      Is Path to contacts directory Immutable
    */
    static
    bool isPathImmutable()
    {
      return self()->isImmutable( QStringLiteral( "Path" ) );
    }

    /**
      Set Do not change the actual backend data.
    */
    static
    void setReadOnly( bool v )
    {
      if (!self()->isReadOnlyImmutable())
        self()->mReadOnly = v;
    }

    /**
      Get Do not change the actual backend data.
    */
    static
    bool readOnly()
    {
      return self()->mReadOnly;
    }

    /**
      Is Do not change the actual backend data. Immutable
    */
    static
    bool isReadOnlyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ReadOnly" ) );
    }

    /**
      Set IsConfigured
    */
    static
    void setIsConfigured( bool v )
    {
      if (!self()->isIsConfiguredImmutable())
        self()->mIsConfigured = v;
    }

    /**
      Get IsConfigured
    */
    static
    bool isConfigured()
    {
      return self()->mIsConfigured;
    }

    /**
      Is IsConfigured Immutable
    */
    static
    bool isIsConfiguredImmutable()
    {
      return self()->isImmutable( QStringLiteral( "IsConfigured" ) );
    }

  protected:
    ContactsResourceSettings(KSharedConfig::Ptr config);
    friend class ContactsResourceSettingsHelper;


    // General
    QString mPath;
    bool mReadOnly;
    bool mIsConfigured;
};

#endif

