/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.Ews.Resource.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef EWSRESOURCEINTERFACE_H
#define EWSRESOURCEINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.Akonadi.Ews.Resource
 */
class OrgKdeAkonadiEwsResourceInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.Akonadi.Ews.Resource"; }

public:
    OrgKdeAkonadiEwsResourceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeAkonadiEwsResourceInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> clearCollectionSyncState(int collectionId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(collectionId);
        return asyncCallWithArgumentList(QStringLiteral("clearCollectionSyncState"), argumentList);
    }

    inline QDBusPendingReply<> clearFolderTreeSyncState()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("clearFolderTreeSyncState"), argumentList);
    }

    inline QDBusPendingReply<> sendMessage(const QString &id, const QByteArray &content)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(id) << QVariant::fromValue(content);
        return asyncCallWithArgumentList(QStringLiteral("sendMessage"), argumentList);
    }

    inline QDBusPendingReply<> setInitialReconnectTimeout(int timeout)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(timeout);
        return asyncCallWithArgumentList(QStringLiteral("setInitialReconnectTimeout"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void messageSent(const QString &id, const QString &error);
};

namespace org {
  namespace kde {
    namespace Akonadi {
      namespace Ews {
        using Resource = ::OrgKdeAkonadiEwsResourceInterface;
      }
    }
  }
}

#endif
