/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.NewMailNotifier.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "newmailnotifieradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class NewMailNotifierAdaptor
 */

NewMailNotifierAdaptor::NewMailNotifierAdaptor(NewMailNotifierAgent *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

NewMailNotifierAdaptor::~NewMailNotifierAdaptor()
{
    // destructor
}

bool NewMailNotifierAdaptor::enabledAgent()
{
    // handle method call org.freedesktop.Akonadi.NewMailNotifier.enabledAgent
    return parent()->enabledAgent();
}

void NewMailNotifierAdaptor::printDebug()
{
    // handle method call org.freedesktop.Akonadi.NewMailNotifier.printDebug
    parent()->printDebug();
}

void NewMailNotifierAdaptor::setEnableAgent(bool in0)
{
    // handle method call org.freedesktop.Akonadi.NewMailNotifier.setEnableAgent
    parent()->setEnableAgent(in0);
}

void NewMailNotifierAdaptor::setVerboseMailNotification(bool in0)
{
    // handle method call org.freedesktop.Akonadi.NewMailNotifier.setVerboseMailNotification
    parent()->setVerboseMailNotification(in0);
}

void NewMailNotifierAdaptor::showNotNotificationHistoryDialog(qlonglong windowId)
{
    // handle method call org.freedesktop.Akonadi.NewMailNotifier.showNotNotificationHistoryDialog
    parent()->showNotNotificationHistoryDialog(windowId);
}

bool NewMailNotifierAdaptor::verboseMailNotification()
{
    // handle method call org.freedesktop.Akonadi.NewMailNotifier.verboseMailNotification
    return parent()->verboseMailNotification();
}


#include "moc_newmailnotifieradaptor.cpp"
