// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "mailtransportplugin_akonadi_debug.h"


Q_LOGGING_CATEGORY(MAILTRANSPORT_AKONADI_LOG, "org.kde.pim.mailtransport.akonadiplugin", QtInfoMsg)

