/********************************************************************************
** Form generated from reading UI file 'contactsagentsettingswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONTACTSAGENTSETTINGSWIDGET_H
#define UI_CONTACTSAGENTSETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ContactAgentSettingsWidget
{
public:
    QGridLayout *gridLayout_3;
    QTabWidget *tabWidget;
    QWidget *tab_3;
    QGridLayout *gridLayout_2;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    KUrlRequester *kcfg_Path;
    QLabel *label_3;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *kcfg_ReadOnly;
    QLabel *label_2;

    void setupUi(QWidget *ContactAgentSettingsWidget)
    {
        if (ContactAgentSettingsWidget->objectName().isEmpty())
            ContactAgentSettingsWidget->setObjectName("ContactAgentSettingsWidget");
        ContactAgentSettingsWidget->resize(718, 386);
        gridLayout_3 = new QGridLayout(ContactAgentSettingsWidget);
        gridLayout_3->setObjectName("gridLayout_3");
        tabWidget = new QTabWidget(ContactAgentSettingsWidget);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setDocumentMode(false);
        tabWidget->setTabBarAutoHide(true);
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        gridLayout_2 = new QGridLayout(tab_3);
        gridLayout_2->setObjectName("gridLayout_2");
        groupBox_2 = new QGroupBox(tab_3);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout = new QGridLayout(groupBox_2);
        gridLayout->setObjectName("gridLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        kcfg_Path = new KUrlRequester(groupBox_2);
        kcfg_Path->setObjectName("kcfg_Path");

        horizontalLayout->addWidget(kcfg_Path);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);

        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");
        label_3->setWordWrap(true);

        gridLayout->addWidget(label_3, 1, 0, 1, 1);


        gridLayout_2->addWidget(groupBox_2, 0, 0, 1, 1);

        groupBox = new QGroupBox(tab_3);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_ReadOnly = new QCheckBox(groupBox);
        kcfg_ReadOnly->setObjectName("kcfg_ReadOnly");

        verticalLayout_2->addWidget(kcfg_ReadOnly);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        verticalLayout_2->addWidget(label_2);


        gridLayout_2->addWidget(groupBox, 1, 0, 1, 1);

        tabWidget->addTab(tab_3, QString());

        gridLayout_3->addWidget(tabWidget, 0, 0, 1, 1);

#if QT_CONFIG(shortcut)
        label->setBuddy(kcfg_Path);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ContactAgentSettingsWidget);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ContactAgentSettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *ContactAgentSettingsWidget)
    {
        groupBox_2->setTitle(tr2i18n("Directory Name", nullptr));
        label->setText(tr2i18n("Di&rectory:", nullptr));
        label_3->setText(tr2i18n("Select the directory whose contents should be represented by this resource. If the directory does not exist, it will be created.", nullptr));
        groupBox->setTitle(tr2i18n("Access Rights", nullptr));
        kcfg_ReadOnly->setText(tr2i18n("Read only", "if the access is limited to read-only"));
        label_2->setText(tr2i18n("If read-only mode is enabled, no changes will be written to the directory selected above. Read-only mode will be automatically enabled if you do not have write access to the directory.", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), tr2i18n("Settings", nullptr));
        (void)ContactAgentSettingsWidget;
    } // retranslateUi

};

namespace Ui {
    class ContactAgentSettingsWidget: public Ui_ContactAgentSettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONTACTSAGENTSETTINGSWIDGET_H

