/********************************************************************************
** Form generated from reading UI file 'googlesettingswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GOOGLESETTINGSWIDGET_H
#define UI_GOOGLESETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kdatecombobox.h"

QT_BEGIN_NAMESPACE

class Ui_GoogleSettingsWidget
{
public:
    QFormLayout *verticalLayout_2;
    QLabel *accountTextLabel;
    QLabel *accountLabel;
    QPushButton *configureBtn;
    QCheckBox *enableRefresh;
    QLabel *refreshLabel;
    QSpinBox *refreshSpinBox;
    QLabel *eventsLimitLabel;
    KDateComboBox *eventsLimitCombo;
    QLabel *calendarsLabel;
    QListWidget *calendarsList;
    QHBoxLayout *hboxLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *reloadCalendarsBtn;
    QLabel *taskListsLabel;
    QListWidget *taskListsList;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *horizontalSpacer1;
    QPushButton *reloadTaskListsBtn;

    void setupUi(QWidget *GoogleSettingsDialog)
    {
        if (GoogleSettingsDialog->objectName().isEmpty())
            GoogleSettingsDialog->setObjectName("GoogleSettingsDialog");
        GoogleSettingsDialog->resize(704, 680);
        GoogleSettingsDialog->setMinimumSize(QSize(500, 300));
        verticalLayout_2 = new QFormLayout(GoogleSettingsDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        accountTextLabel = new QLabel(GoogleSettingsDialog);
        accountTextLabel->setObjectName("accountTextLabel");

        verticalLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, accountTextLabel);

        accountLabel = new QLabel(GoogleSettingsDialog);
        accountLabel->setObjectName("accountLabel");

        verticalLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, accountLabel);

        configureBtn = new QPushButton(GoogleSettingsDialog);
        configureBtn->setObjectName("configureBtn");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("configure");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8(""), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        configureBtn->setIcon(icon);

        verticalLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, configureBtn);

        enableRefresh = new QCheckBox(GoogleSettingsDialog);
        enableRefresh->setObjectName("enableRefresh");

        verticalLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, enableRefresh);

        refreshLabel = new QLabel(GoogleSettingsDialog);
        refreshLabel->setObjectName("refreshLabel");

        verticalLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, refreshLabel);

        refreshSpinBox = new QSpinBox(GoogleSettingsDialog);
        refreshSpinBox->setObjectName("refreshSpinBox");
        refreshSpinBox->setMinimum(10);
        refreshSpinBox->setMaximum(720);
        refreshSpinBox->setValue(30);

        verticalLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, refreshSpinBox);

        eventsLimitLabel = new QLabel(GoogleSettingsDialog);
        eventsLimitLabel->setObjectName("eventsLimitLabel");

        verticalLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, eventsLimitLabel);

        eventsLimitCombo = new KDateComboBox(GoogleSettingsDialog);
        eventsLimitCombo->setObjectName("eventsLimitCombo");

        verticalLayout_2->setWidget(4, QFormLayout::ItemRole::FieldRole, eventsLimitCombo);

        calendarsLabel = new QLabel(GoogleSettingsDialog);
        calendarsLabel->setObjectName("calendarsLabel");
        calendarsLabel->setAlignment(Qt::AlignLeft|Qt::AlignTrailing|Qt::AlignVCenter);

        verticalLayout_2->setWidget(5, QFormLayout::ItemRole::LabelRole, calendarsLabel);

        calendarsList = new QListWidget(GoogleSettingsDialog);
        calendarsList->setObjectName("calendarsList");

        verticalLayout_2->setWidget(6, QFormLayout::ItemRole::SpanningRole, calendarsList);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(horizontalSpacer);

        reloadCalendarsBtn = new QPushButton(GoogleSettingsDialog);
        reloadCalendarsBtn->setObjectName("reloadCalendarsBtn");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("view-refresh")));
        reloadCalendarsBtn->setIcon(icon1);

        hboxLayout->addWidget(reloadCalendarsBtn);


        verticalLayout_2->setLayout(7, QFormLayout::ItemRole::FieldRole, hboxLayout);

        taskListsLabel = new QLabel(GoogleSettingsDialog);
        taskListsLabel->setObjectName("taskListsLabel");
        taskListsLabel->setAlignment(Qt::AlignLeft|Qt::AlignTrailing|Qt::AlignVCenter);

        verticalLayout_2->setWidget(8, QFormLayout::ItemRole::LabelRole, taskListsLabel);

        taskListsList = new QListWidget(GoogleSettingsDialog);
        taskListsList->setObjectName("taskListsList");

        verticalLayout_2->setWidget(9, QFormLayout::ItemRole::SpanningRole, taskListsList);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        horizontalSpacer1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(horizontalSpacer1);

        reloadTaskListsBtn = new QPushButton(GoogleSettingsDialog);
        reloadTaskListsBtn->setObjectName("reloadTaskListsBtn");
        reloadTaskListsBtn->setIcon(icon1);

        hboxLayout1->addWidget(reloadTaskListsBtn);


        verticalLayout_2->setLayout(10, QFormLayout::ItemRole::FieldRole, hboxLayout1);

#if QT_CONFIG(shortcut)
        refreshLabel->setBuddy(refreshSpinBox);
        eventsLimitLabel->setBuddy(eventsLimitCombo);
        calendarsLabel->setBuddy(calendarsList);
        taskListsLabel->setBuddy(taskListsList);
#endif // QT_CONFIG(shortcut)

        retranslateUi(GoogleSettingsDialog);
        QObject::connect(enableRefresh, &QCheckBox::toggled, refreshSpinBox, &QSpinBox::setEnabled);

        QMetaObject::connectSlotsByName(GoogleSettingsDialog);
    } // setupUi

    void retranslateUi(QWidget *GoogleSettingsDialog)
    {
        accountTextLabel->setText(tr2i18n("Account:", nullptr));
        accountLabel->setText(tr2i18n("<b>Not configured</b>", nullptr));
        configureBtn->setText(tr2i18n("Configure\342\200\246", nullptr));
        enableRefresh->setText(tr2i18n("Enable interval refresh", nullptr));
        refreshLabel->setText(tr2i18n("Refresh interval:", nullptr));
        eventsLimitLabel->setText(tr2i18n("Fetch only events since:", nullptr));
        calendarsLabel->setText(tr2i18n("Enabled Calendars:", nullptr));
        reloadCalendarsBtn->setText(tr2i18n("Reload", nullptr));
        taskListsLabel->setText(tr2i18n("Enabled Tasklists:", nullptr));
        reloadTaskListsBtn->setText(tr2i18n("Reload", nullptr));
        (void)GoogleSettingsDialog;
    } // retranslateUi

};

namespace Ui {
    class GoogleSettingsWidget: public Ui_GoogleSettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GOOGLESETTINGSWIDGET_H

