// This file is generated by kconfig_compiler_kf6 from settings.kcfg.
// All changes you do to this file will be lost.

#include "settingsbase.h"

SettingsBase::SettingsBase( KSharedConfig::Ptr config )
  : KConfigSkeleton( std::move( config ) )
{
  setCurrentGroup( QStringLiteral( "General" ) );

  mNameItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "name" ), mName );
  addItem( mNameItem, QStringLiteral( "name" ) );
  mUnitTestPasswordItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "unitTestPassword" ), mUnitTestPassword );
  addItem( mUnitTestPasswordItem, QStringLiteral( "unitTestPassword" ) );
  mLoginItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "login" ), mLogin );
  addItem( mLoginItem, QStringLiteral( "login" ) );
  mHostItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "host" ), mHost );
  addItem( mHostItem, QStringLiteral( "host" ) );
  mPortItem = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "port" ), mPort, 110 );
  addItem( mPortItem, QStringLiteral( "port" ) );
  mAuthenticationMethodItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "authenticationMethod" ), mAuthenticationMethod, 7 );
  addItem( mAuthenticationMethodItem, QStringLiteral( "authenticationMethod" ) );
  mUseSSLItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "useSSL" ), mUseSSL, false );
  addItem( mUseSSLItem, QStringLiteral( "useSSL" ) );
  mUseTLSItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "useTLS" ), mUseTLS, false );
  addItem( mUseTLSItem, QStringLiteral( "useTLS" ) );
  mPipeliningItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "pipelining" ), mPipelining, false );
  addItem( mPipeliningItem, QStringLiteral( "pipelining" ) );
  mUseProxyItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "useProxy" ), mUseProxy, false );
  addItem( mUseProxyItem, QStringLiteral( "useProxy" ) );
  mLeaveOnServerItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "leaveOnServer" ), mLeaveOnServer, false );
  addItem( mLeaveOnServerItem, QStringLiteral( "leaveOnServer" ) );
  mLeaveOnServerDaysItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "leaveOnServerDays" ), mLeaveOnServerDays, -1 );
  addItem( mLeaveOnServerDaysItem, QStringLiteral( "leaveOnServerDays" ) );
  mLeaveOnServerCountItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "leaveOnServerCount" ), mLeaveOnServerCount, -1 );
  addItem( mLeaveOnServerCountItem, QStringLiteral( "leaveOnServerCount" ) );
  mLeaveOnServerSizeItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "leaveOnServerSize" ), mLeaveOnServerSize, -1 );
  addItem( mLeaveOnServerSizeItem, QStringLiteral( "leaveOnServerSize" ) );
  mFilterOnServerItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "filterOnServer" ), mFilterOnServer, false );
  addItem( mFilterOnServerItem, QStringLiteral( "filterOnServer" ) );
  mFilterCheckSizeItem = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "filterCheckSize" ), mFilterCheckSize, 50000 );
  addItem( mFilterCheckSizeItem, QStringLiteral( "filterCheckSize" ) );
  mTargetCollectionItem = new KConfigSkeleton::ItemLongLong( currentGroup(), QStringLiteral( "targetCollection" ), mTargetCollection, -1 );
  addItem( mTargetCollectionItem, QStringLiteral( "targetCollection" ) );
  mPrecommandItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "precommand" ), mPrecommand );
  addItem( mPrecommandItem, QStringLiteral( "precommand" ) );
  mIntervalCheckEnabledItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "intervalCheckEnabled" ), mIntervalCheckEnabled, false );
  addItem( mIntervalCheckEnabledItem, QStringLiteral( "intervalCheckEnabled" ) );
  mIntervalCheckIntervalItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "intervalCheckInterval" ), mIntervalCheckInterval, 5 );
  addItem( mIntervalCheckIntervalItem, QStringLiteral( "intervalCheckInterval" ) );

  setCurrentGroup( QStringLiteral( "LeaveOnServer" ) );

  mSeenUidListItem = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "seenUidList" ), mSeenUidList );
  addItem( mSeenUidListItem, QStringLiteral( "seenUidList" ) );
  QList<int> defaultseenUidTimeList;

  mSeenUidTimeListItem = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "seenUidTimeList" ), mSeenUidTimeList, defaultseenUidTimeList );
  addItem( mSeenUidTimeListItem, QStringLiteral( "seenUidTimeList" ) );
  mDownloadLaterItem = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "downloadLater" ), mDownloadLater );
  addItem( mDownloadLaterItem, QStringLiteral( "downloadLater" ) );
}

SettingsBase::~SettingsBase()
{
}

