/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.VCard.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef VCARDSETTINGSADAPTOR_H
#define VCARDSETTINGSADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "settings.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Akonadi.VCard.Settings
 */
class VCardSettingsAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Akonadi.VCard.Settings")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Akonadi.VCard.Settings\">\n"
"    <method name=\"save\"/>\n"
"    <method name=\"path\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setPath\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"displayName\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setDisplayName\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"readOnly\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setReadOnly\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"monitorFile\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setMonitorFile\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"periodicUpdate\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setPeriodicUpdate\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"updatePeriod\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setUpdatePeriod\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    VCardSettingsAdaptor(Akonadi_VCard_Resource::Settings *parent);
    ~VCardSettingsAdaptor() override;

    inline Akonadi_VCard_Resource::Settings *parent() const
    { return static_cast<Akonadi_VCard_Resource::Settings *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QString displayName();
    bool monitorFile();
    QString path();
    bool periodicUpdate();
    bool readOnly();
    void save();
    void setDisplayName(const QString &in0);
    void setMonitorFile(bool in0);
    void setPath(const QString &in0);
    void setPeriodicUpdate(bool in0);
    void setReadOnly(bool in0);
    void setUpdatePeriod(int in0);
    int updatePeriod();
Q_SIGNALS: // SIGNALS
};

#endif
