/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.Ews.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "ewssettingsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class EwsSettingsAdaptor
 */

EwsSettingsAdaptor::EwsSettingsAdaptor(EwsSettings *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

EwsSettingsAdaptor::~EwsSettingsAdaptor()
{
    // destructor
}

QString EwsSettingsAdaptor::authMode()
{
    // handle method call org.kde.Akonadi.Ews.Settings.authMode
    return parent()->authMode();
}

bool EwsSettingsAdaptor::autoDiscovery()
{
    // handle method call org.kde.Akonadi.Ews.Settings.autoDiscovery
    return parent()->autoDiscovery();
}

QString EwsSettingsAdaptor::baseUrl()
{
    // handle method call org.kde.Akonadi.Ews.Settings.baseUrl
    return parent()->baseUrl();
}

QString EwsSettingsAdaptor::domain()
{
    // handle method call org.kde.Akonadi.Ews.Settings.domain
    return parent()->domain();
}

QString EwsSettingsAdaptor::email()
{
    // handle method call org.kde.Akonadi.Ews.Settings.email
    return parent()->email();
}

bool EwsSettingsAdaptor::enableNTLMv2()
{
    // handle method call org.kde.Akonadi.Ews.Settings.enableNTLMv2
    return parent()->enableNTLMv2();
}

QString EwsSettingsAdaptor::eventSubscriptionId()
{
    // handle method call org.kde.Akonadi.Ews.Settings.eventSubscriptionId
    return parent()->eventSubscriptionId();
}

QString EwsSettingsAdaptor::eventSubscriptionWatermark()
{
    // handle method call org.kde.Akonadi.Ews.Settings.eventSubscriptionWatermark
    return parent()->eventSubscriptionWatermark();
}

QString EwsSettingsAdaptor::folderSyncState()
{
    // handle method call org.kde.Akonadi.Ews.Settings.folderSyncState
    return parent()->folderSyncState();
}

bool EwsSettingsAdaptor::hasDomain()
{
    // handle method call org.kde.Akonadi.Ews.Settings.hasDomain
    return parent()->hasDomain();
}

QString EwsSettingsAdaptor::oAuth2AppId()
{
    // handle method call org.kde.Akonadi.Ews.Settings.oAuth2AppId
    return parent()->oAuth2AppId();
}

QString EwsSettingsAdaptor::oAuth2ReturnUri()
{
    // handle method call org.kde.Akonadi.Ews.Settings.oAuth2ReturnUri
    return parent()->oAuth2ReturnUri();
}

QString EwsSettingsAdaptor::pKeyCert()
{
    // handle method call org.kde.Akonadi.Ews.Settings.pKeyCert
    return parent()->pKeyCert();
}

QString EwsSettingsAdaptor::pKeyKey()
{
    // handle method call org.kde.Akonadi.Ews.Settings.pKeyKey
    return parent()->pKeyKey();
}

double EwsSettingsAdaptor::pollInterval()
{
    // handle method call org.kde.Akonadi.Ews.Settings.pollInterval
    return parent()->pollInterval();
}

int EwsSettingsAdaptor::retrievalMethod()
{
    // handle method call org.kde.Akonadi.Ews.Settings.retrievalMethod
    return parent()->retrievalMethod();
}

void EwsSettingsAdaptor::save()
{
    // handle method call org.kde.Akonadi.Ews.Settings.save
    parent()->save();
}

bool EwsSettingsAdaptor::serverSubscription()
{
    // handle method call org.kde.Akonadi.Ews.Settings.serverSubscription
    return parent()->serverSubscription();
}

QStringList EwsSettingsAdaptor::serverSubscriptionList()
{
    // handle method call org.kde.Akonadi.Ews.Settings.serverSubscriptionList
    return parent()->serverSubscriptionList();
}

void EwsSettingsAdaptor::setAuthMode(const QString &in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setAuthMode
    parent()->setAuthMode(in0);
}

void EwsSettingsAdaptor::setAutoDiscovery(bool in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setAutoDiscovery
    parent()->setAutoDiscovery(in0);
}

void EwsSettingsAdaptor::setBaseUrl(const QString &in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setBaseUrl
    parent()->setBaseUrl(in0);
}

void EwsSettingsAdaptor::setDomain(const QString &in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setDomain
    parent()->setDomain(in0);
}

void EwsSettingsAdaptor::setEmail(const QString &in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setEmail
    parent()->setEmail(in0);
}

void EwsSettingsAdaptor::setEnableNTLMv2(bool in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setEnableNTLMv2
    parent()->setEnableNTLMv2(in0);
}

void EwsSettingsAdaptor::setEventSubscriptionId(const QString &in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setEventSubscriptionId
    parent()->setEventSubscriptionId(in0);
}

void EwsSettingsAdaptor::setEventSubscriptionWatermark(const QString &in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setEventSubscriptionWatermark
    parent()->setEventSubscriptionWatermark(in0);
}

void EwsSettingsAdaptor::setFolderSyncState(const QString &in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setFolderSyncState
    parent()->setFolderSyncState(in0);
}

void EwsSettingsAdaptor::setHasDomain(bool in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setHasDomain
    parent()->setHasDomain(in0);
}

void EwsSettingsAdaptor::setOAuth2AppId(const QString &in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setOAuth2AppId
    parent()->setOAuth2AppId(in0);
}

void EwsSettingsAdaptor::setOAuth2ReturnUri(const QString &in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setOAuth2ReturnUri
    parent()->setOAuth2ReturnUri(in0);
}

void EwsSettingsAdaptor::setPKeyCert(const QString &in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setPKeyCert
    parent()->setPKeyCert(in0);
}

void EwsSettingsAdaptor::setPKeyKey(const QString &in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setPKeyKey
    parent()->setPKeyKey(in0);
}

void EwsSettingsAdaptor::setPollInterval(double in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setPollInterval
    parent()->setPollInterval(in0);
}

void EwsSettingsAdaptor::setRetrievalMethod(int in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setRetrievalMethod
    parent()->setRetrievalMethod(in0);
}

void EwsSettingsAdaptor::setServerSubscription(bool in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setServerSubscription
    parent()->setServerSubscription(in0);
}

void EwsSettingsAdaptor::setServerSubscriptionList(const QStringList &in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setServerSubscriptionList
    parent()->setServerSubscriptionList(in0);
}

void EwsSettingsAdaptor::setUserAgent(const QString &in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setUserAgent
    parent()->setUserAgent(in0);
}

void EwsSettingsAdaptor::setUsername(const QString &in0)
{
    // handle method call org.kde.Akonadi.Ews.Settings.setUsername
    parent()->setUsername(in0);
}

QString EwsSettingsAdaptor::userAgent()
{
    // handle method call org.kde.Akonadi.Ews.Settings.userAgent
    return parent()->userAgent();
}

QString EwsSettingsAdaptor::username()
{
    // handle method call org.kde.Akonadi.Ews.Settings.username
    return parent()->username();
}


#include "moc_ewssettingsadaptor.cpp"
