/****************************************************************************
** Meta object code from reading C++ file 'imapresourcebase.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdepim-runtime-26.04.2/resources/imap/imapresourcebase.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'imapresourcebase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16ImapResourceBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto ImapResourceBase::qt_create_metaobjectdata<qt_meta_tag_ZN16ImapResourceBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ImapResourceBase",
        "D-Bus Interface",
        "org.kde.Akonadi.ImapResourceBase",
        "requestManualExpunge",
        "",
        "collectionId",
        "serverCapabilities",
        "dumpResourceToString",
        "startIdleIfNeeded",
        "startIdle",
        "abortActivity",
        "retrieveCollections",
        "retrieveCollectionAttributes",
        "Akonadi::Collection",
        "col",
        "retrieveItems",
        "retrieveItem",
        "Akonadi::Item",
        "item",
        "QSet<QByteArray>",
        "parts",
        "delayedInit",
        "reconnect",
        "doSearch",
        "QVariant",
        "arg",
        "scheduleConnectionAttempt",
        "startConnect",
        "onConnectDone",
        "errorCode",
        "errorMessage",
        "onConnectionLost",
        "KIMAP::Session*",
        "session",
        "onIdleCollectionFetchDone",
        "KJob*",
        "job",
        "onExpungeCollectionFetchDone",
        "triggerCollectionExpunge",
        "collectionVariant",
        "taskDestroyed",
        "task",
        "showError",
        "message",
        "clearStatusMessage",
        "updateResourceName",
        "onCollectionModifyDone"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'requestManualExpunge'
        QtMocHelpers::SlotData<void(qint64)>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::LongLong, 5 },
        }}),
        // Slot 'serverCapabilities'
        QtMocHelpers::SlotData<QStringList() const>(6, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'dumpResourceToString'
        QtMocHelpers::SlotData<QString() const>(7, 4, QMC::AccessPublic, QMetaType::QString),
        // Slot 'startIdleIfNeeded'
        QtMocHelpers::SlotData<void()>(8, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'startIdle'
        QtMocHelpers::SlotData<void()>(9, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'abortActivity'
        QtMocHelpers::SlotData<void()>(10, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'retrieveCollections'
        QtMocHelpers::SlotData<void()>(11, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'retrieveCollectionAttributes'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(12, 4, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'retrieveItems'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(15, 4, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'retrieveItem'
        QtMocHelpers::SlotData<bool(const Akonadi::Item &, const QSet<QByteArray> &)>(16, 4, QMC::AccessProtected, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'delayedInit'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'reconnect'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'doSearch'
        QtMocHelpers::SlotData<void(const QVariant &)>(23, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'scheduleConnectionAttempt'
        QtMocHelpers::SlotData<void()>(26, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'startConnect'
        QtMocHelpers::SlotData<void(const QVariant &)>(27, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 4 },
        }}),
        // Slot 'onConnectDone'
        QtMocHelpers::SlotData<void(int, const QString &)>(28, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 29 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'onConnectionLost'
        QtMocHelpers::SlotData<void(KIMAP::Session *)>(31, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'onIdleCollectionFetchDone'
        QtMocHelpers::SlotData<void(KJob *)>(34, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'onExpungeCollectionFetchDone'
        QtMocHelpers::SlotData<void(KJob *)>(37, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'triggerCollectionExpunge'
        QtMocHelpers::SlotData<void(const QVariant &)>(38, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 39 },
        }}),
        // Slot 'taskDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(40, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 41 },
        }}),
        // Slot 'showError'
        QtMocHelpers::SlotData<void(const QString &)>(42, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 43 },
        }}),
        // Slot 'clearStatusMessage'
        QtMocHelpers::SlotData<void()>(44, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateResourceName'
        QtMocHelpers::SlotData<void()>(45, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onCollectionModifyDone'
        QtMocHelpers::SlotData<void(KJob *)>(46, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ImapResourceBase, qt_meta_tag_ZN16ImapResourceBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ImapResourceBase::staticMetaObject = { {
    QMetaObject::SuperData::link<Akonadi::ResourceWidgetBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ImapResourceBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ImapResourceBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16ImapResourceBaseE_t>.metaTypes,
    nullptr
} };

void ImapResourceBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImapResourceBase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestManualExpunge((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 1: { QStringList _r = _t->serverCapabilities();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->dumpResourceToString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->startIdleIfNeeded(); break;
        case 4: _t->startIdle(); break;
        case 5: _t->abortActivity(); break;
        case 6: _t->retrieveCollections(); break;
        case 7: _t->retrieveCollectionAttributes((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 8: _t->retrieveItems((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 9: { bool _r = _t->retrieveItem((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->delayedInit(); break;
        case 11: _t->reconnect(); break;
        case 12: _t->doSearch((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 13: _t->scheduleConnectionAttempt(); break;
        case 14: _t->startConnect((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 15: _t->onConnectDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->onConnectionLost((*reinterpret_cast<std::add_pointer_t<KIMAP::Session*>>(_a[1]))); break;
        case 17: _t->onIdleCollectionFetchDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 18: _t->onExpungeCollectionFetchDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 19: _t->triggerCollectionExpunge((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 20: _t->taskDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 21: _t->showError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->clearStatusMessage(); break;
        case 23: _t->updateResourceName(); break;
        case 24: _t->onCollectionModifyDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *ImapResourceBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImapResourceBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ImapResourceBaseE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Akonadi::AgentBase::ObserverV3"))
        return static_cast< Akonadi::AgentBase::ObserverV3*>(this);
    if (!strcmp(_clname, "Akonadi::AgentSearchInterface"))
        return static_cast< Akonadi::AgentSearchInterface*>(this);
    return Akonadi::ResourceWidgetBase::qt_metacast(_clname);
}

int ImapResourceBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Akonadi::ResourceWidgetBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    return _id;
}
QT_WARNING_POP
