/****************************************************************************
** Meta object code from reading C++ file 'settingsadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "settingsadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'settingsadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15SettingsAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto SettingsAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN15SettingsAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SettingsAdaptor",
        "D-Bus Interface",
        "org.kde.Akonadi.Imap.Settings",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Akonadi.Imap.Settings\">\n    <method "
        "name=\"save\"/>\n    <method name=\"name\">\n      <arg direction="
        "\"out\" type=\"s\"/>\n    </method>\n    <method name=\"setName\">"
        "\n      <arg direction=\"in\" type=\"s\"/>\n    </method>\n    <me"
        "thod name=\"imapServer\">\n      <arg direction=\"out\" type=\"s\""
        "/>\n    </method>\n    <method name=\"setImapServer\">\n      <arg"
        " direction=\"in\" type=\"s\"/>\n    </method>\n    <method name=\""
        "imapPort\">\n      <arg direction=\"out\" type=\"i\"/>\n    </meth"
        "od>\n    <method name=\"setImapPort\">\n      <arg direction=\"in\""
        " type=\"i\"/>\n    </method>\n    <method name=\"userName\">\n    "
        "  <arg direction=\"out\" type=\"s\"/>\n    </method>\n    <method "
        "name=\"setUserName\">\n      <arg direction=\"in\" type=\"s\"/>\n "
        "   </method>\n    <method name=\"safety\">\n      <arg direction=\""
        "out\" type=\"s\"/>\n    </method>\n    <method name=\"setSafety\">"
        "\n      <arg direction=\"in\" type=\"s\"/>\n    </method>\n    <me"
        "thod name=\"overrideEncryption\">\n      <arg direction=\"out\" ty"
        "pe=\"s\"/>\n    </method>\n    <method name=\"setOverrideEncryptio"
        "n\">\n      <arg direction=\"in\" type=\"s\"/>\n    </method>\n   "
        " <method name=\"authentication\">\n      <arg direction=\"out\" ty"
        "pe=\"i\"/>\n    </method>\n    <method name=\"setAuthentication\">"
        "\n      <arg direction=\"in\" type=\"i\"/>\n    </method>\n    <me"
        "thod name=\"subscriptionEnabled\">\n      <arg direction=\"out\" t"
        "ype=\"b\"/>\n    </method>\n    <method name=\"setSubscriptionEnab"
        "led\">\n      <arg direction=\"in\" type=\"b\"/>\n    </method>\n "
        "   <method name=\"sessionTimeout\">\n      <arg direction=\"out\" "
        "type=\"i\"/>\n    </method>\n    <method name=\"setSessionTimeout\""
        ">\n      <arg direction=\"in\" type=\"i\"/>\n    </method>\n    <m"
        "ethod name=\"useProxy\">\n      <arg direction=\"out\" type=\"b\"/"
        ">\n    </method>\n    <method name=\"setUseProxy\">\n      <arg di"
        "rection=\"in\" type=\"b\"/>\n    </method>\n    <method name=\"dis"
        "connectedModeEnabled\">\n      <arg direction=\"out\" type=\"b\"/>"
        "\n    </method>\n    <method name=\"setDisconnectedModeEnabled\">\n"
        "      <arg direction=\"in\" type=\"b\"/>\n    </method>\n    <meth"
        "od name=\"intervalCheckEnabled\">\n      <arg direction=\"out\" ty"
        "pe=\"b\"/>\n    </method>\n    <method name=\"setIntervalCheckEnab"
        "led\">\n      <arg direction=\"in\" type=\"b\"/>\n    </method>\n "
        "   <method name=\"intervalCheckTime\">\n      <arg direction=\"out"
        "\" type=\"i\"/>\n    </method>\n    <method name=\"setIntervalChec"
        "kTime\">\n      <arg direction=\"in\" type=\"i\"/>\n    </method>\n"
        "    <method name=\"retrieveMetadataOnFolderListing\">\n      <arg "
        "direction=\"out\" type=\"b\"/>\n    </method>\n    <method name=\""
        "setRetrieveMetadataOnFolderListing\">\n      <arg direction=\"in\""
        " type=\"b\"/>\n    </method>\n    <method name=\"automaticExpungeE"
        "nabled\">\n      <arg direction=\"out\" type=\"b\"/>\n    </method"
        ">\n    <method name=\"setAutomaticExpungeEnabled\">\n      <arg di"
        "rection=\"in\" type=\"b\"/>\n    </method>\n    <method name=\"tra"
        "shCollection\">\n      <arg direction=\"out\" type=\"x\"/>\n    </"
        "method>\n    <method name=\"setTrashCollection\">\n      <arg dire"
        "ction=\"in\" type=\"x\"/>\n    </method>\n    <method name=\"trash"
        "CollectionMigrated\">\n      <arg direction=\"out\" type=\"b\"/>\n"
        "    </method>\n    <method name=\"setTrashCollectionMigrated\">\n "
        "     <arg direction=\"in\" type=\"b\"/>\n    </method>\n    <metho"
        "d name=\"useDefaultIdentity\">\n      <arg direction=\"out\" type="
        "\"b\"/>\n    </method>\n    <method name=\"setUseDefaultIdentity\""
        ">\n      <arg direction=\"in\" type=\"b\"/>\n    </method>\n    <m"
        "ethod name=\"accountIdentity\">\n      <arg direction=\"out\" type"
        "=\"i\"/>\n    </method>\n    <method name=\"setAccountIdentity\">\n"
        "      <arg direction=\"in\" type=\"i\"/>\n    </method>\n    <meth"
        "od name=\"knownMailBoxes\">\n      <arg direction=\"out\" type=\"a"
        "s\"/>\n    </method>\n    <method name=\"setKnownMailBoxes\">\n   "
        "   <arg direction=\"in\" type=\"as\"/>\n    </method>\n    <method"
        " name=\"idleRidPath\">\n      <arg direction=\"out\" type=\"as\"/>"
        "\n    </method>\n    <method name=\"setIdleRidPath\">\n      <arg "
        "direction=\"in\" type=\"as\"/>\n    </method>\n    <method name=\""
        "sieveSupport\">\n      <arg direction=\"out\" type=\"b\"/>\n    </"
        "method>\n    <method name=\"setSieveSupport\">\n      <arg directi"
        "on=\"in\" type=\"b\"/>\n    </method>\n    <method name=\"sieveReu"
        "seConfig\">\n      <arg direction=\"out\" type=\"b\"/>\n    </meth"
        "od>\n    <method name=\"setSieveReuseConfig\">\n      <arg directi"
        "on=\"in\" type=\"b\"/>\n    </method>\n    <method name=\"sievePor"
        "t\">\n      <arg direction=\"out\" type=\"i\"/>\n    </method>\n  "
        "  <method name=\"setSievePort\">\n      <arg direction=\"in\" type"
        "=\"i\"/>\n    </method>\n    <method name=\"sieveAlternateUrl\">\n"
        "      <arg direction=\"out\" type=\"s\"/>\n    </method>\n    <met"
        "hod name=\"setSieveAlternateUrl\">\n      <arg direction=\"in\" ty"
        "pe=\"s\"/>\n    </method>\n    <method name=\"alternateAuthenticat"
        "ion\">\n      <arg direction=\"out\" type=\"i\"/>\n    </method>\n"
        "    <method name=\"setAlternateAuthentication\">\n      <arg direc"
        "tion=\"in\" type=\"i\"/>\n    </method>\n    <method name=\"sieveV"
        "acationFilename\">\n      <arg direction=\"out\" type=\"s\"/>\n   "
        " </method>\n    <method name=\"setSieveVacationFilename\">\n      "
        "<arg direction=\"in\" type=\"s\"/>\n    </method>\n    <method nam"
        "e=\"sieveCustomUsername\">\n      <arg direction=\"out\" type=\"s\""
        "/>\n    </method>\n    <method name=\"setSieveCustomUsername\">\n "
        "     <arg direction=\"in\" type=\"s\"/>\n    </method>\n    <metho"
        "d name=\"sieveCustomAuthentification\">\n      <arg direction=\"ou"
        "t\" type=\"s\"/>\n    </method>\n    <method name=\"setSieveCustom"
        "Authentification\">\n      <arg direction=\"in\" type=\"s\"/>\n   "
        " </method>\n    <method name=\"activitiesEnabled\">\n      <arg di"
        "rection=\"out\" type=\"b\"/>\n    </method>\n    <method name=\"se"
        "tActivitiesEnabled\">\n      <arg direction=\"in\" type=\"b\"/>\n "
        "   </method>\n    <method name=\"activities\">\n      <arg directi"
        "on=\"out\" type=\"as\"/>\n    </method>\n    <method name=\"setAct"
        "ivities\">\n      <arg direction=\"in\" type=\"as\"/>\n    </metho"
        "d>\n  </interface>\n",
        "accountIdentity",
        "",
        "activities",
        "activitiesEnabled",
        "alternateAuthentication",
        "authentication",
        "automaticExpungeEnabled",
        "disconnectedModeEnabled",
        "idleRidPath",
        "imapPort",
        "imapServer",
        "intervalCheckEnabled",
        "intervalCheckTime",
        "knownMailBoxes",
        "name",
        "overrideEncryption",
        "retrieveMetadataOnFolderListing",
        "safety",
        "save",
        "sessionTimeout",
        "setAccountIdentity",
        "in0",
        "setActivities",
        "setActivitiesEnabled",
        "setAlternateAuthentication",
        "setAuthentication",
        "setAutomaticExpungeEnabled",
        "setDisconnectedModeEnabled",
        "setIdleRidPath",
        "setImapPort",
        "setImapServer",
        "setIntervalCheckEnabled",
        "setIntervalCheckTime",
        "setKnownMailBoxes",
        "setName",
        "setOverrideEncryption",
        "setRetrieveMetadataOnFolderListing",
        "setSafety",
        "setSessionTimeout",
        "setSieveAlternateUrl",
        "setSieveCustomAuthentification",
        "setSieveCustomUsername",
        "setSievePort",
        "setSieveReuseConfig",
        "setSieveSupport",
        "setSieveVacationFilename",
        "setSubscriptionEnabled",
        "setTrashCollection",
        "setTrashCollectionMigrated",
        "setUseDefaultIdentity",
        "setUseProxy",
        "setUserName",
        "sieveAlternateUrl",
        "sieveCustomAuthentification",
        "sieveCustomUsername",
        "sievePort",
        "sieveReuseConfig",
        "sieveSupport",
        "sieveVacationFilename",
        "subscriptionEnabled",
        "trashCollection",
        "trashCollectionMigrated",
        "useDefaultIdentity",
        "useProxy",
        "userName"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'accountIdentity'
        QtMocHelpers::SlotData<int()>(5, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'activities'
        QtMocHelpers::SlotData<QStringList()>(7, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'activitiesEnabled'
        QtMocHelpers::SlotData<bool()>(8, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'alternateAuthentication'
        QtMocHelpers::SlotData<int()>(9, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'authentication'
        QtMocHelpers::SlotData<int()>(10, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'automaticExpungeEnabled'
        QtMocHelpers::SlotData<bool()>(11, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'disconnectedModeEnabled'
        QtMocHelpers::SlotData<bool()>(12, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'idleRidPath'
        QtMocHelpers::SlotData<QStringList()>(13, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'imapPort'
        QtMocHelpers::SlotData<int()>(14, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'imapServer'
        QtMocHelpers::SlotData<QString()>(15, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'intervalCheckEnabled'
        QtMocHelpers::SlotData<bool()>(16, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'intervalCheckTime'
        QtMocHelpers::SlotData<int()>(17, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'knownMailBoxes'
        QtMocHelpers::SlotData<QStringList()>(18, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'name'
        QtMocHelpers::SlotData<QString()>(19, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'overrideEncryption'
        QtMocHelpers::SlotData<QString()>(20, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'retrieveMetadataOnFolderListing'
        QtMocHelpers::SlotData<bool()>(21, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'safety'
        QtMocHelpers::SlotData<QString()>(22, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sessionTimeout'
        QtMocHelpers::SlotData<int()>(24, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setAccountIdentity'
        QtMocHelpers::SlotData<void(int)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'setActivities'
        QtMocHelpers::SlotData<void(const QStringList &)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 26 },
        }}),
        // Slot 'setActivitiesEnabled'
        QtMocHelpers::SlotData<void(bool)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setAlternateAuthentication'
        QtMocHelpers::SlotData<void(int)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'setAuthentication'
        QtMocHelpers::SlotData<void(int)>(30, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'setAutomaticExpungeEnabled'
        QtMocHelpers::SlotData<void(bool)>(31, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setDisconnectedModeEnabled'
        QtMocHelpers::SlotData<void(bool)>(32, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setIdleRidPath'
        QtMocHelpers::SlotData<void(const QStringList &)>(33, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 26 },
        }}),
        // Slot 'setImapPort'
        QtMocHelpers::SlotData<void(int)>(34, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'setImapServer'
        QtMocHelpers::SlotData<void(const QString &)>(35, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setIntervalCheckEnabled'
        QtMocHelpers::SlotData<void(bool)>(36, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setIntervalCheckTime'
        QtMocHelpers::SlotData<void(int)>(37, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'setKnownMailBoxes'
        QtMocHelpers::SlotData<void(const QStringList &)>(38, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 26 },
        }}),
        // Slot 'setName'
        QtMocHelpers::SlotData<void(const QString &)>(39, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setOverrideEncryption'
        QtMocHelpers::SlotData<void(const QString &)>(40, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setRetrieveMetadataOnFolderListing'
        QtMocHelpers::SlotData<void(bool)>(41, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setSafety'
        QtMocHelpers::SlotData<void(const QString &)>(42, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setSessionTimeout'
        QtMocHelpers::SlotData<void(int)>(43, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'setSieveAlternateUrl'
        QtMocHelpers::SlotData<void(const QString &)>(44, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setSieveCustomAuthentification'
        QtMocHelpers::SlotData<void(const QString &)>(45, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setSieveCustomUsername'
        QtMocHelpers::SlotData<void(const QString &)>(46, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setSievePort'
        QtMocHelpers::SlotData<void(int)>(47, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'setSieveReuseConfig'
        QtMocHelpers::SlotData<void(bool)>(48, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setSieveSupport'
        QtMocHelpers::SlotData<void(bool)>(49, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setSieveVacationFilename'
        QtMocHelpers::SlotData<void(const QString &)>(50, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setSubscriptionEnabled'
        QtMocHelpers::SlotData<void(bool)>(51, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setTrashCollection'
        QtMocHelpers::SlotData<void(qlonglong)>(52, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 26 },
        }}),
        // Slot 'setTrashCollectionMigrated'
        QtMocHelpers::SlotData<void(bool)>(53, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setUseDefaultIdentity'
        QtMocHelpers::SlotData<void(bool)>(54, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setUseProxy'
        QtMocHelpers::SlotData<void(bool)>(55, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setUserName'
        QtMocHelpers::SlotData<void(const QString &)>(56, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'sieveAlternateUrl'
        QtMocHelpers::SlotData<QString()>(57, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'sieveCustomAuthentification'
        QtMocHelpers::SlotData<QString()>(58, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'sieveCustomUsername'
        QtMocHelpers::SlotData<QString()>(59, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'sievePort'
        QtMocHelpers::SlotData<int()>(60, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'sieveReuseConfig'
        QtMocHelpers::SlotData<bool()>(61, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'sieveSupport'
        QtMocHelpers::SlotData<bool()>(62, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'sieveVacationFilename'
        QtMocHelpers::SlotData<QString()>(63, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'subscriptionEnabled'
        QtMocHelpers::SlotData<bool()>(64, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'trashCollection'
        QtMocHelpers::SlotData<qlonglong()>(65, 6, QMC::AccessPublic, QMetaType::LongLong),
        // Slot 'trashCollectionMigrated'
        QtMocHelpers::SlotData<bool()>(66, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'useDefaultIdentity'
        QtMocHelpers::SlotData<bool()>(67, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'useProxy'
        QtMocHelpers::SlotData<bool()>(68, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'userName'
        QtMocHelpers::SlotData<QString()>(69, 6, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<SettingsAdaptor, qt_meta_tag_ZN15SettingsAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SettingsAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.metaTypes,
    nullptr
} };

void SettingsAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SettingsAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { int _r = _t->accountIdentity();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 1: { QStringList _r = _t->activities();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->activitiesEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { int _r = _t->alternateAuthentication();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 4: { int _r = _t->authentication();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->automaticExpungeEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->disconnectedModeEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { QStringList _r = _t->idleRidPath();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 8: { int _r = _t->imapPort();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->imapServer();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->intervalCheckEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { int _r = _t->intervalCheckTime();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 12: { QStringList _r = _t->knownMailBoxes();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->name();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->overrideEncryption();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->retrieveMetadataOnFolderListing();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { QString _r = _t->safety();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->save(); break;
        case 18: { int _r = _t->sessionTimeout();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->setAccountIdentity((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->setActivities((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 21: _t->setActivitiesEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->setAlternateAuthentication((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->setAuthentication((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->setAutomaticExpungeEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->setDisconnectedModeEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->setIdleRidPath((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 27: _t->setImapPort((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->setImapServer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->setIntervalCheckEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->setIntervalCheckTime((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 31: _t->setKnownMailBoxes((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 32: _t->setName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 33: _t->setOverrideEncryption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 34: _t->setRetrieveMetadataOnFolderListing((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->setSafety((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 36: _t->setSessionTimeout((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 37: _t->setSieveAlternateUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 38: _t->setSieveCustomAuthentification((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 39: _t->setSieveCustomUsername((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 40: _t->setSievePort((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 41: _t->setSieveReuseConfig((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 42: _t->setSieveSupport((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 43: _t->setSieveVacationFilename((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 44: _t->setSubscriptionEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 45: _t->setTrashCollection((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 46: _t->setTrashCollectionMigrated((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 47: _t->setUseDefaultIdentity((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 48: _t->setUseProxy((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 49: _t->setUserName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 50: { QString _r = _t->sieveAlternateUrl();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 51: { QString _r = _t->sieveCustomAuthentification();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 52: { QString _r = _t->sieveCustomUsername();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 53: { int _r = _t->sievePort();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 54: { bool _r = _t->sieveReuseConfig();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 55: { bool _r = _t->sieveSupport();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 56: { QString _r = _t->sieveVacationFilename();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 57: { bool _r = _t->subscriptionEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 58: { qlonglong _r = _t->trashCollection();
            if (_a[0]) *reinterpret_cast<qlonglong*>(_a[0]) = std::move(_r); }  break;
        case 59: { bool _r = _t->trashCollectionMigrated();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 60: { bool _r = _t->useDefaultIdentity();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 61: { bool _r = _t->useProxy();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 62: { QString _r = _t->userName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *SettingsAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SettingsAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SettingsAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int SettingsAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 63)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 63;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 63)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 63;
    }
    return _id;
}
QT_WARNING_POP
