/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was com.microsoft.identity.Broker1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef BROKER1_H
#define BROKER1_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface com.microsoft.identity.Broker1
 */
class ComMicrosoftIdentityBroker1Interface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "com.microsoft.identity.Broker1"; }

public:
    ComMicrosoftIdentityBroker1Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~ComMicrosoftIdentityBroker1Interface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QString> acquirePrtSsoCookie(const QString &protocol_version, const QString &correlation_id, const QString &request_json)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(protocol_version) << QVariant::fromValue(correlation_id) << QVariant::fromValue(request_json);
        return asyncCallWithArgumentList(QStringLiteral("acquirePrtSsoCookie"), argumentList);
    }

    inline QDBusPendingReply<QString> acquireTokenInteractively(const QString &protocol_version, const QString &correlation_id, const QString &request_json)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(protocol_version) << QVariant::fromValue(correlation_id) << QVariant::fromValue(request_json);
        return asyncCallWithArgumentList(QStringLiteral("acquireTokenInteractively"), argumentList);
    }

    inline QDBusPendingReply<QString> acquireTokenSilently(const QString &protocol_version, const QString &correlation_id, const QString &request_json)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(protocol_version) << QVariant::fromValue(correlation_id) << QVariant::fromValue(request_json);
        return asyncCallWithArgumentList(QStringLiteral("acquireTokenSilently"), argumentList);
    }

    inline QDBusPendingReply<QString> cancelInteractiveFlow(const QString &protocol_version, const QString &correlation_id, const QString &request_json)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(protocol_version) << QVariant::fromValue(correlation_id) << QVariant::fromValue(request_json);
        return asyncCallWithArgumentList(QStringLiteral("cancelInteractiveFlow"), argumentList);
    }

    inline QDBusPendingReply<QString> generateSignedHttpRequest(const QString &protocol_version, const QString &correlation_id, const QString &request_json)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(protocol_version) << QVariant::fromValue(correlation_id) << QVariant::fromValue(request_json);
        return asyncCallWithArgumentList(QStringLiteral("generateSignedHttpRequest"), argumentList);
    }

    inline QDBusPendingReply<QString> getAccounts(const QString &protocol_version, const QString &correlation_id, const QString &request_json)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(protocol_version) << QVariant::fromValue(correlation_id) << QVariant::fromValue(request_json);
        return asyncCallWithArgumentList(QStringLiteral("getAccounts"), argumentList);
    }

    inline QDBusPendingReply<QString> getLinuxBrokerVersion(const QString &protocol_version, const QString &correlation_id, const QString &request_json)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(protocol_version) << QVariant::fromValue(correlation_id) << QVariant::fromValue(request_json);
        return asyncCallWithArgumentList(QStringLiteral("getLinuxBrokerVersion"), argumentList);
    }

    inline QDBusPendingReply<QString> removeAccount(const QString &protocol_version, const QString &correlation_id, const QString &request_json)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(protocol_version) << QVariant::fromValue(correlation_id) << QVariant::fromValue(request_json);
        return asyncCallWithArgumentList(QStringLiteral("removeAccount"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace com {
  namespace microsoft {
    namespace identity {
      using Broker1 = ::ComMicrosoftIdentityBroker1Interface;
    }
  }
}

#endif
