/********************************************************************************
** Form generated from reading UI file 'configwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGWIDGET_H
#define UI_CONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ConfigWidget
{
public:
    QFormLayout *verticalLayout;
    QLabel *label_BaseUrl;
    QLineEdit *kcfg_BaseUrl;
    QLabel *label_Username;
    QLineEdit *kcfg_Username;
    QLabel *label_Password;
    QLineEdit *kcfg_Password;
    QPushButton *checkConnectionButton;

    void setupUi(QWidget *ConfigWidget)
    {
        if (ConfigWidget->objectName().isEmpty())
            ConfigWidget->setObjectName("ConfigWidget");
        ConfigWidget->resize(410, 202);
        verticalLayout = new QFormLayout(ConfigWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        label_BaseUrl = new QLabel(ConfigWidget);
        label_BaseUrl->setObjectName("label_BaseUrl");

        verticalLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_BaseUrl);

        kcfg_BaseUrl = new QLineEdit(ConfigWidget);
        kcfg_BaseUrl->setObjectName("kcfg_BaseUrl");
        kcfg_BaseUrl->setPlaceholderText(QString::fromUtf8("https://myserver.org"));

        verticalLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_BaseUrl);

        label_Username = new QLabel(ConfigWidget);
        label_Username->setObjectName("label_Username");

        verticalLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_Username);

        kcfg_Username = new QLineEdit(ConfigWidget);
        kcfg_Username->setObjectName("kcfg_Username");

        verticalLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_Username);

        label_Password = new QLabel(ConfigWidget);
        label_Password->setObjectName("label_Password");

        verticalLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_Password);

        kcfg_Password = new QLineEdit(ConfigWidget);
        kcfg_Password->setObjectName("kcfg_Password");
        kcfg_Password->setEchoMode(QLineEdit::Password);

        verticalLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_Password);

        checkConnectionButton = new QPushButton(ConfigWidget);
        checkConnectionButton->setObjectName("checkConnectionButton");
        checkConnectionButton->setEnabled(false);

        verticalLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, checkConnectionButton);

#if QT_CONFIG(shortcut)
        label_BaseUrl->setBuddy(kcfg_BaseUrl);
        label_Username->setBuddy(kcfg_Username);
        label_Password->setBuddy(kcfg_Password);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ConfigWidget);

        QMetaObject::connectSlotsByName(ConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *ConfigWidget)
    {
        label_BaseUrl->setText(tr2i18n("Server URL:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_BaseUrl->setToolTip(tr2i18n("The URL of the Open-Xchange server, should be something like https://myserver.org/", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_BaseUrl->setWhatsThis(tr2i18n("The URL of the Open-Xchange server, should be something like https://myserver.org/", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_Username->setText(tr2i18n("Username:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_Username->setToolTip(tr2i18n("The username that is used to log into the Open-Xchange server", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_Username->setWhatsThis(tr2i18n("The username that is used to log into the Open-Xchange server", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_Password->setText(tr2i18n("Password:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_Password->setToolTip(tr2i18n("The password that is used to log into the Open-Xchange server", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_Password->setWhatsThis(tr2i18n("The password that is used to log into the Open-Xchange server", nullptr));
#endif // QT_CONFIG(whatsthis)
        checkConnectionButton->setText(tr2i18n("Test Connection\342\200\246", nullptr));
        (void)ConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class ConfigWidget: public Ui_ConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGWIDGET_H

