// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "ewscli_failedreq_debug.h"


Q_LOGGING_CATEGORY(EWSCLI_FAILEDREQUEST_LOG, "org.kde.pim.ews.client.failedrequest", QtWarningMsg)

