/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.POP3.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "settingsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class SettingsAdaptor
 */

SettingsAdaptor::SettingsAdaptor(Settings *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

SettingsAdaptor::~SettingsAdaptor()
{
    // destructor
}

int SettingsAdaptor::authenticationMethod()
{
    // handle method call org.kde.Akonadi.POP3.Settings.authenticationMethod
    return parent()->authenticationMethod();
}

QStringList SettingsAdaptor::downloadLater()
{
    // handle method call org.kde.Akonadi.POP3.Settings.downloadLater
    return parent()->downloadLater();
}

uint SettingsAdaptor::filterCheckSize()
{
    // handle method call org.kde.Akonadi.POP3.Settings.filterCheckSize
    return parent()->filterCheckSize();
}

bool SettingsAdaptor::filterOnServer()
{
    // handle method call org.kde.Akonadi.POP3.Settings.filterOnServer
    return parent()->filterOnServer();
}

QString SettingsAdaptor::host()
{
    // handle method call org.kde.Akonadi.POP3.Settings.host
    return parent()->host();
}

bool SettingsAdaptor::intervalCheckEnabled()
{
    // handle method call org.kde.Akonadi.POP3.Settings.intervalCheckEnabled
    return parent()->intervalCheckEnabled();
}

int SettingsAdaptor::intervalCheckInterval()
{
    // handle method call org.kde.Akonadi.POP3.Settings.intervalCheckInterval
    return parent()->intervalCheckInterval();
}

bool SettingsAdaptor::leaveOnServer()
{
    // handle method call org.kde.Akonadi.POP3.Settings.leaveOnServer
    return parent()->leaveOnServer();
}

int SettingsAdaptor::leaveOnServerCount()
{
    // handle method call org.kde.Akonadi.POP3.Settings.leaveOnServerCount
    return parent()->leaveOnServerCount();
}

int SettingsAdaptor::leaveOnServerDays()
{
    // handle method call org.kde.Akonadi.POP3.Settings.leaveOnServerDays
    return parent()->leaveOnServerDays();
}

int SettingsAdaptor::leaveOnServerSize()
{
    // handle method call org.kde.Akonadi.POP3.Settings.leaveOnServerSize
    return parent()->leaveOnServerSize();
}

QString SettingsAdaptor::login()
{
    // handle method call org.kde.Akonadi.POP3.Settings.login
    return parent()->login();
}

QString SettingsAdaptor::name()
{
    // handle method call org.kde.Akonadi.POP3.Settings.name
    return parent()->name();
}

bool SettingsAdaptor::pipelining()
{
    // handle method call org.kde.Akonadi.POP3.Settings.pipelining
    return parent()->pipelining();
}

uint SettingsAdaptor::port()
{
    // handle method call org.kde.Akonadi.POP3.Settings.port
    return parent()->port();
}

QString SettingsAdaptor::precommand()
{
    // handle method call org.kde.Akonadi.POP3.Settings.precommand
    return parent()->precommand();
}

void SettingsAdaptor::save()
{
    // handle method call org.kde.Akonadi.POP3.Settings.save
    parent()->save();
}

QStringList SettingsAdaptor::seenUidList()
{
    // handle method call org.kde.Akonadi.POP3.Settings.seenUidList
    return parent()->seenUidList();
}

QList<int> SettingsAdaptor::seenUidTimeList()
{
    // handle method call org.kde.Akonadi.POP3.Settings.seenUidTimeList
    return parent()->seenUidTimeList();
}

void SettingsAdaptor::setAuthenticationMethod(int in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setAuthenticationMethod
    parent()->setAuthenticationMethod(in0);
}

void SettingsAdaptor::setDownloadLater(const QStringList &in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setDownloadLater
    parent()->setDownloadLater(in0);
}

void SettingsAdaptor::setFilterCheckSize(uint in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setFilterCheckSize
    parent()->setFilterCheckSize(in0);
}

void SettingsAdaptor::setFilterOnServer(bool in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setFilterOnServer
    parent()->setFilterOnServer(in0);
}

void SettingsAdaptor::setHost(const QString &in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setHost
    parent()->setHost(in0);
}

void SettingsAdaptor::setIntervalCheckEnabled(bool in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setIntervalCheckEnabled
    parent()->setIntervalCheckEnabled(in0);
}

void SettingsAdaptor::setIntervalCheckInterval(int in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setIntervalCheckInterval
    parent()->setIntervalCheckInterval(in0);
}

void SettingsAdaptor::setLeaveOnServer(bool in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setLeaveOnServer
    parent()->setLeaveOnServer(in0);
}

void SettingsAdaptor::setLeaveOnServerCount(int in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setLeaveOnServerCount
    parent()->setLeaveOnServerCount(in0);
}

void SettingsAdaptor::setLeaveOnServerDays(int in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setLeaveOnServerDays
    parent()->setLeaveOnServerDays(in0);
}

void SettingsAdaptor::setLeaveOnServerSize(int in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setLeaveOnServerSize
    parent()->setLeaveOnServerSize(in0);
}

void SettingsAdaptor::setLogin(const QString &in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setLogin
    parent()->setLogin(in0);
}

void SettingsAdaptor::setName(const QString &in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setName
    parent()->setName(in0);
}

void SettingsAdaptor::setPipelining(bool in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setPipelining
    parent()->setPipelining(in0);
}

void SettingsAdaptor::setPort(uint in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setPort
    parent()->setPort(in0);
}

void SettingsAdaptor::setPrecommand(const QString &in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setPrecommand
    parent()->setPrecommand(in0);
}

void SettingsAdaptor::setSeenUidList(const QStringList &in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setSeenUidList
    parent()->setSeenUidList(in0);
}

void SettingsAdaptor::setSeenUidTimeList(const QList<int> &in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setSeenUidTimeList
    parent()->setSeenUidTimeList(in0);
}

void SettingsAdaptor::setTargetCollection(qlonglong in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setTargetCollection
    parent()->setTargetCollection(in0);
}

void SettingsAdaptor::setUnitTestPassword(const QString &in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setUnitTestPassword
    parent()->setUnitTestPassword(in0);
}

void SettingsAdaptor::setUseProxy(bool in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setUseProxy
    parent()->setUseProxy(in0);
}

void SettingsAdaptor::setUseSSL(bool in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setUseSSL
    parent()->setUseSSL(in0);
}

void SettingsAdaptor::setUseTLS(bool in0)
{
    // handle method call org.kde.Akonadi.POP3.Settings.setUseTLS
    parent()->setUseTLS(in0);
}

qlonglong SettingsAdaptor::targetCollection()
{
    // handle method call org.kde.Akonadi.POP3.Settings.targetCollection
    return parent()->targetCollection();
}

QString SettingsAdaptor::unitTestPassword()
{
    // handle method call org.kde.Akonadi.POP3.Settings.unitTestPassword
    return parent()->unitTestPassword();
}

bool SettingsAdaptor::useProxy()
{
    // handle method call org.kde.Akonadi.POP3.Settings.useProxy
    return parent()->useProxy();
}

bool SettingsAdaptor::useSSL()
{
    // handle method call org.kde.Akonadi.POP3.Settings.useSSL
    return parent()->useSSL();
}

bool SettingsAdaptor::useTLS()
{
    // handle method call org.kde.Akonadi.POP3.Settings.useTLS
    return parent()->useTLS();
}


#include "moc_settingsadaptor.cpp"
